C ********************************************************************
C * BANDPLOT - Plotting and interpolation of energy bands            *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  BANDPLOT                                                        *
C *                                                                  *
C *  Usage......: Plots bands along symmetry lines interpolated by   *
C *               BFIT.                                              *
C *               Uses PGPLOT graphics subroutine library.           *
C *                                                                  *
C *  Author.....: Martin Braendle (mbs)                              *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Institute for anorg. + phys. Chemistry             *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: 28.04.92                                           *
C *  Revision...: 19.08.92/mbs, 04.09.92/mbs, 27.04.93/mbs,          *
C *               24.04.94/mbs, 06.09.94/mbs, 18.11.94/mbs,          *
C *               01.07.97/mbs                                       * 
C *  Remarks....: Device specific constants see file 'sizes'.        *
C *               Major revision: Inclusion of bandfitting procedure *
C *               and generation of symmetry information.            *
C *               Major revision: Change of part 1 because of inclu- *
C *               sion of wavefunction symmetry analysis in EHMACC.  *
C *               Major revision for use with PGPLOT graphics        *
C *               subroutine library.                                *
C *               Calls to NAG and GKS routines commented out.       *
C *               Operation system specific implementation: Look for *
C *               "AIX", "VMS", "MS-Windows", "Windows NT".          *
C *                                                                  *
C *  Called from: -                                                  *
C *                                                                  *
C *  Calls......: BPENER,BPAXES,BPBAND,BPGRPH,BPRAW,BPSELC,BPBSRT,   *
C *               BPSRT2,BPSYML                                      *
C *               MS-Windows, Windows NT, AIX version: BPCOPY        *
C *               PGPLOT routines: PGOPEN,PGSLCT,PGASK,PGSCR,PGPAP,  *
C *               PGSVP,PGSWIN,PGSLW,PGEND                           *
C *                                                                  *
C ********************************************************************
C
C MS-Windows version: Comment PROGRAM statement.
C VMS,AIX and Windows NT version: Uncomment PROGRAM statement.
C
      PROGRAM BANDPL
C
C MS-Windows version: Uncomment SUBROUTINE statement.
C VMS, AIX and Windows NT version: Comment SUBROUTINE statement.
C
C      SUBROUTINE GKSAPP
C
C NAG/GKS version.
C
C      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
C
C PGPLOT version.
C
      IMPLICIT REAL(A-H,O-Z)
 
      INCLUDE 'sizes'
 
      DIMENSION    VPXSCT(MAXSYM+1),X(MAXK),Y(MAXK),
     .             ERAW(MAXBA,MAXK),EBUFF(MAXBA,MAXK),ILINE(MXSYME),
     .             XK(MAXK,3),XKTMP(3),KPOINT(MAXK),IOP(MAXK),
     .             ILINOP(MAXK,MXSYME),ISYMRE(MXSYME),IORD(MAXBA,MAXK),
     .             ILINPT(MXSYME),IDUMM1(MXSYME+1)
      CHARACTER    CHIN*1,CTEMP*2,CDUMMY*80
      CHARACTER*32 CSYMRE(MAXBA,MAXK)
      LOGICAL      PLTROT,FSYMEX,FNEWLI
C
C NAG/GKS version.
C
C      REAL         WLINE
C
C PGPLOT version.
C
      INTEGER      PGOPEN
      LOGICAL      FPGASK
      DATA FPGASK/.FALSE./
C
C Vertical plotting.
C
      VPXFUL=VVXFUL
      VPYFUL=VVYFUL
      VPXAXW=VVXAXW
      VPYAXH=VVYAXH
      VPXOFF=VVXOFF
      VPYOFF=VVYOFF
C
C Initialize plotinterface and device and set main viewport.
C
C NAG/GKS version/begin comment.
C
C      CALL NAGGKS(13)
C      CALL J06WAF
C
C AIX GKSCO (PHIGS) version: Uncomment following three lines.
C VMS and MS-Windows version: Comment following three lines.
C
C     CALL GSDS(1,0,1)
C     CALL GSCR(1,0,1.0,1.0,1.0)
C     CALL GSCR(1,1,0.0,0.0,0.0)
C
C     CALL J06WCF(0.0,VPXFUL,0.0,VPYFUL)
C
C NAG/GKS version/end comment.
C
C PGPLOT version.
C 
      IDEVSC=PGOPEN(WDEVIC)
      CALL PGSLCT(IDEVSC)
      CALL PGASK(FPGASK)
      CALL PGSCR(0,1.,1.,1.)
      CALL PGSCR(1,0.,0.,0.)
      CALL PGPAP(7.5,1.0)
      CALL PGSVP(0.0,VPXFUL,0.0,VPYFUL)

      WRITE (6,10)
   10 FORMAT(/,' *************************************************',/,
     .         ' *                 B A N D P L O T               *',/,
     .         ' *             Release September 1997            *',/,
     .         ' * --------------------------------------------- *',/,
     .         ' *  Plotting and interpolation of energy bands   *',/,
     .         ' *              along symmetry lines             *',/,
     .         ' *                 Martin Braendle               *',/,
     .         ' *   Department of Chemistry and Biochemistry    *',/,
     .         ' *        University of Bern, Switzerland        *',/,
     .         ' *                                               *',/,
     .         ' *          (C) 1997 by Gion Calzaferri          *',/,
     .         ' *  BANDPLOT comes with absolutely no warranty.  *',/,
     .         ' * This is free software and you are welcome to  *',/,
     .         ' *   redistribute it under certain conditions.   *',/,
     .         ' *  For details see GNU General Public License.  *',/,
     .         ' *************************************************',/,
     .2X)

C
C Unit  1: Energies and energy gradient file.
C Unit  2: Contains interpolated bands along symmetry lines.
C Unit  3: Contains symmetry data.
C Unit  4: Output of new symmetry data.
C Unit 14: .EH1-file
C Unit 15: .BPL-file
C
C MS-Windows version: Add FILE='fort.x', x=unit number.
C VMS and AIX version: Remove FILE='fort.x'.
C
   20 OPEN(UNIT=1,FORM='FORMATTED',STATUS='OLD',ERR=1470,FILE='fort.1')
C   20 OPEN (UNIT=1,FORM='FORMATTED',STATUS='OLD',ERR=1470)
      OPEN(UNIT=14,FORM='FORMATTED',STATUS='OLD',ERR=1470,
     .     FILE='fort.14')
C      OPEN (UNIT=14,FORM='FORMATTED',STATUS='OLD',ERR=1470)
C
C If interpolated bands do not exist, first symmetry information must
C be generated for interpolation.
C
C MS-Windows version: Add FILE='fort.2'.
C VMS and AIX version: Remove FILE='fort.2'.
C
      OPEN(UNIT=2,FORM='FORMATTED',STATUS='OLD',ERR=90,FILE='fort.2')
C      OPEN(UNIT=2,FORM='FORMATTED',STATUS='OLD',ERR=90)
C
C Interpolated bands do exist.
C
      READ(2,'(I2)') NSYM
      WRITE(6,40)
   40 FORMAT(' (1) Display interpolated bands',/,
     .       ' (2) Change .BIN information and interpolate bands',/,
     .       ' (3) Interpolate bands',//,
     .       ' (0) Exit',/)
 
   50 WRITE(6,'('' Selection: '',$)')
      READ(5,'(I2)',ERR=50) ISEL
 
      IF ((ISEL .LT. 0) .OR. (ISEL .GT. 3)) GOTO 50
 
      IF (ISEL .EQ. 0) GOTO 1460
      IF (ISEL .EQ. 1) GOTO 1310
      IF (ISEL .EQ. 3) GOTO 1280
C
C ---------------------------------------------------------------------
C
C PART 1: Change symmetry information and interpolate bands.
C
C .BIN-file exists and wants to be changed.
C
C MS-Windows version: Add FILE='fort.3'.
C VMS and AIX version: Remove FILE='fort.3'.
C
      OPEN(UNIT=3,STATUS='OLD',FILE='fort.3')
C      OPEN (UNIT=3,STATUS='OLD')
      FSYMEX=.TRUE.
      READ(3,'(3I4)') NBTOT,NNOFIT,NBFIT
      GOTO 100
C
C .BIN-file does not exist.
C
   90 FSYMEX=.FALSE.
C
C Determine number total number of k-points and symmetry lines.
C
  100 WRITE(6,110)
  110 FORMAT(/,' Read/change symmetry information and interpolate ',
     .         'bands',/,
     .         ' -------------------------------------------------',
     .         '-----',/)
 
      READ(14,'(6I6)') NKTOT,NBTOT
      CLOSE (14)
 
      WRITE(6,'('' Total number of k points: '',I4,/,
     .      '' Total number of bands:    '',I4)') NKTOT,NBTOT
 
      IF (.NOT. FSYMEX) THEN
  140   WRITE(6,'('' Number of lower bands not to be interpolated: '',
     .        $)')
        READ(5,'(I4)',ERR=140) NNOFIT
        IF (NNOFIT .LT. 0) GOTO 140
 
  170   WRITE(6,'('' Number of bands to be interpolated:           '',
     .        $)')
        READ(5,'(I4)',ERR=170) NBFIT
        IF ((NBFIT .LE. 0) .OR. (NBFIT .GT. (NBTOT-NNOFIT))) GOTO 170
      ENDIF
C
C MS-Windows version: Add FILE='fort.4'.
C VMS and AIX version: Remove FILE='fort.4'.
C
      OPEN(UNIT=4,STATUS='NEW',FILE='fort.4')
C      OPEN (UNIT=4,STATUS='NEW')
      WRITE(4,'(3I4)') NBTOT,NNOFIT,NBFIT
 
      NSYMT=0
      DO I=1,NKTOT
        READ(1,'(A80)') CDUMMY
        DO 240 J=1,3
          READ(1,'(12I3)') ILINET,(IDUMM1(K),K=1,MXSYME+1)
          IF (NSYMT .GT. 0) THEN
            DO K=1,NSYMT
              IF ((ILINET .EQ. ILINE(K)) .OR. (ILINET .EQ. 0)) GOTO 240
            END DO
          ENDIF
          NSYMT=NSYMT+1
          ILINE(NSYMT)=ILINET
  240   CONTINUE
        DO J=1,NBTOT
          READ(1,'(A80)') CDUMMY
        END DO
      END DO
 
      WRITE(6,'('' Total number of different symmetry lines: '',I2,/)') 
     .      NSYMT
 
      NSYM=0
  280 WRITE(6,'('' Symmetry line labels: '',10I3,/)') 
     .      (ILINE(I),I=1,NSYMT)
 
  300 WRITE(6,'('' Choose label of line (0=exit and interpolate '',/,
     .      '' all previously chosen lines): '',$)')
      READ(5,'(I2)',ERR=300) ILABEL
      IF (ILABEL .EQ. 0) GOTO 1270
 
      DO I=1,NSYMT
        IF (ILABEL .EQ. ILINE(I)) GOTO 340
      END DO
      GOTO 280
C
C If .BIN exists, first search through the file if symmetry proper-
C ties have been still defined for the chosen symmetry line.
C
  340 NSYM=NSYM+1
      FNEWLI=.TRUE.
      IF (FSYMEX) THEN
        REWIND 3
        READ(3,'(A80)') CDUMMY
  350   READ(3,'(6I3)',END=420) ILABL2,NK,ISYMMS,ISYMME,IUSEEN,IUSESY
C
C ISYMMS: =0: start k-point of symmetry line symmorphic, else nonsym-
C             morphic
C ISYMME: =0: end k-point of symmetry line symmorphic, else nonsymmor-
C             phic
C IUSEEN: =0: neither use start and end point derivatives
C         =1: use start point derivatives
C         =2: use end point derivatives
C         =3: use both start and end point derivatives
C IUSESY: =0: use symmorphic point derivatives
C
        IDIREC=1
        IKSTRT=1
        IKEND=NK
        IF (ILABL2 .EQ. ILABEL) THEN
          WRITE(6,'('' Use .BIN information for line '',I2,
     .          '' (default=yes): '',$)') ILABEL
          READ(5,'(A1)') CHIN
          IF ((INDEX(CHIN,'N') .NE. 1) .AND. (INDEX(CHIN,'n') .NE. 1))
     .    THEN
            FNEWLI=.FALSE.
            GOTO 420
          ENDIF
        ENDIF
        DO I=1,NK
          DO J=1,NBTOT/20+2
            READ(3,'(A80)') CDUMMY
          END DO
        END DO
        GOTO 350
      ENDIF
 
  420 IF (FNEWLI) THEN
        REWIND 1
C
C Search k points belonging to symmetry line ILABEL and sort them in
C ascending order.
C
        NK=0
        DO I=1,NKTOT
          READ(1,'(3F10.7)') (XKTMP(J),J=1,3)
          IDIFF=0
          DO J=1,3
            READ(1,'(12I3)') ILINET,IOPT,(ILINPT(K),K=1,MXSYME)
            IF (ILINET .EQ. ILABEL) GOTO 450
          END DO
          GOTO 520
  450     IF (J .LT. 3) THEN
            IDIFF=3-J
          ENDIF
          NK=NK+1
          IOP(NK)=IOPT
          DO J=1,MXSYME
            ILINOP(NK,J)=ILINPT(J)
          END DO
 
          IF (NK .EQ. 1) THEN
            JFOUND=NK
          ELSE
            DO J1=1,NK-1
              IF (XKTMP(1) .LT. XK(J1,1)) THEN
                JFOUND=J1
                GOTO 500
              ELSE IF (XKTMP(1) .EQ. XK(J1,1)) THEN
                DO J2=J1,NK-1
                  IF (XKTMP(1) .EQ. XK(J2,1)) THEN
                    IF (XKTMP(2) .LT. XK(J2,2)) THEN
                      JFOUND=J2
                      GOTO 500
                    ELSE IF (XKTMP(2) .EQ. XK(J2,2)) THEN
                      DO J3=J2,NK-1
                        IF (XKTMP(2) .EQ. XK(J3,2)) THEN
                          IF (XKTMP(3) .LT. XK(J3,3)) THEN
                            JFOUND=J3
                            GOTO 500
                          ENDIF
                        ELSE
                        ENDIF
                      END DO
                      JFOUND=NK
                      GOTO 500
                    ELSE
                    ENDIF
                  ELSE
                    JFOUND=J2
                    GOTO 500
                  ENDIF
                END DO
              ELSE
              ENDIF
            END DO
            JFOUND=NK
          ENDIF
 
  500     IF (JFOUND .LT. NK) THEN
            DO J=NK,JFOUND+1,-1
              KPOINT(J)=KPOINT(J-1)
              XK(J,1)=XK(J-1,1)
              XK(J,2)=XK(J-1,2)
              XK(J,3)=XK(J-1,3)
            END DO
          ENDIF
          KPOINT(JFOUND)=I
          XK(JFOUND,1)=XKTMP(1)
          XK(JFOUND,2)=XKTMP(2)
          XK(JFOUND,3)=XKTMP(3)
 
  520     DO J=1,NBTOT+IDIFF
            READ(1,'(A80)') CDUMMY
          END DO
        END DO
 
        IDIREC=1
        IKSTRT=1
        IKEND=NK
 
        WRITE(6,'('' Line '',I2,'': '',I2,'' k-points.'',/,
     .            '' Lowest k-point  ('',3F10.5,''),'',/,
     .            '' Highest k-point ('',3F10.5,'').'',/)')
     .        ILABEL,NK,(XK(1,J),J=1,3),(XK(NK,J),J=1,3)
  570   WRITE(6,'('' k points in ascending or descending order? '',
     .        ''(A/D) '',$)')
        READ(5,'(A1)',ERR=570) CHIN
 
        IF ((INDEX(CHIN,'D') .GT. 0) .OR. (INDEX(CHIN,'d') .GT. 0))
     .  THEN
          IDIREC=-1
          IKSTRT=NK
          IKEND=1
        ENDIF
      ENDIF
C
C Read symmetry line.
C
      NKOLD=NKTOT+1
      DO I=IKSTRT,IKEND,IDIREC
        IF (FSYMEX .AND. ( .NOT. FNEWLI)) THEN
          READ(3,'(I4)') KPOINT(I)
          NRLINE=NBTOT/20
          IRLINE=0
          DO J=1,NRLINE
            READ(3,'(20I4)') (IORD(IRLINE*20+K,I),K=1,20)
            IRLINE=IRLINE+1
          END DO
          READ(3,'(20I4)') (IORD(IRLINE*20+K,I),K=1,NBTOT-20*IRLINE)
        ENDIF
 
        IDIFF=KPOINT(I)-NKOLD-1
        IF (IDIFF .LT. 0) THEN
          REWIND 1
          IDIFF=KPOINT(I)-1
        ENDIF
        IF (IDIFF .GT. 0) THEN
C
C Skipping of k points.
C
          DO J=1,IDIFF
            DO K=1,NBTOT+4
              READ(1,'(A80)') CDUMMY
            END DO
          END DO
        ENDIF
C
C Read energies, derivatives, and symmetry information, if needed.
C
        IF (.NOT. FNEWLI) THEN
          READ(1,'(3F10.7)') (XK(I,J),J=1,3)
          DO J=1,3
            READ(1,'(A80)') CDUMMY
          END DO
        ELSE
          DO J=1,4
            READ(1,'(A80)') CDUMMY
          END DO
        ENDIF
        IF (NNOFIT .GT. 0) THEN
          DO J=1,NNOFIT
            IORD(J,I)=0
            READ(1,'(A80)') CDUMMY
          END DO
        ENDIF
        DO J=NNOFIT+1,NNOFIT+NBFIT
          IF (FNEWLI) THEN
            IORD(J,I)=J
          ENDIF
          READ(1,'(4F10.5,I4,10I3)') ERAW(J,I),DUMMY1,DUMMY2,DUMMY3,
     .                               IDUMMY,(ISYMRE(K),K=1,MXSYME)
          IF (FNEWLI) THEN
            DO K=1,LEN(CSYMRE(J,I))
              CSYMRE(J,I)(K:K)=' '
            END DO
            IPOS=1
            DO K=1,IOP(I)
              WRITE(CTEMP,'(I2)') ISYMRE(ILINOP(I,K))
              CSYMRE(J,I)(IPOS:IPOS+1)=CTEMP
              IPOS=IPOS+2
            END DO
          ENDIF
        END DO
        IF (NNOFIT+NBFIT .LT. NBTOT) THEN
          DO J=NNOFIT+NBFIT+1,NBTOT
            IORD(J,I)=0
            READ(1,'(A80)') CDUMMY
          END DO
        ENDIF
        NKOLD=KPOINT(I)
      END DO
 
      IF (FNEWLI) CALL BPBSRT(IORD,IKSTRT,IKEND,IDIREC,NNOFIT,NBFIT,
     .                        CSYMRE)
 
      CALL BPSRT2(ERAW,EBUFF,IORD,NNOFIT,NBFIT,NBTOT,NK)
C
C Determine k-length of symmetry line
C
      DELX=XK(NK,1)-XK(1,1)
      DELY=XK(NK,2)-XK(1,2)
      DELZ=XK(NK,3)-XK(1,3)
      XLEN=SQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)
C
C Project k-points of symmetry line.
C
      DO K=IKSTRT,IKEND,IDIREC
        DELX=XK(K,1)-XK(IKSTRT,1)
        DELY=XK(K,2)-XK(IKSTRT,2)
        DELZ=XK(K,3)-XK(IKSTRT,3)
        X(K)=SQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)
        WRITE(6,'('' Read k-point: '',3F10.5,'', length: '',F10.5)') 
     .       (XK(K,I),I=1,3),X(K)
      END DO
C
C Find energy range of all bands to be interpolated.
C
      ELOW=1000.0
      EHIGH=-ELOW
      DO K=1,NK
        ELOW=MIN(ELOW,ERAW(NNOFIT+1,K))
        EHIGH=MAX(EHIGH,ERAW(NNOFIT+NBFIT,K))
      END DO
      EMIN=ELOW
      EMAX=EHIGH
C
C (Re-)draw bands.
C
      WRITE(6,'(/,'' Displaying bands of symmetry line '',I2,
     .      '' ...'',/)') ILABEL
C
C NAG/GKS version.
C
C  810 CALL J06WDF
C
C PGPLOT version.
C
  810 CALL PGPAGE
      CALL BPAXES(VPXOFF,VPYOFF,VPXSCT,VPXAXW,VPYAXH,1)
      CALL BPRAW(X,Y,ERAW,EMIN,EMAX,XLEN,VPXOFF,VPYOFF,VPXAXW,VPYAXH,
     .           NK,NNOFIT,NBFIT,IDIREC)
 
      WRITE(6,'(/,'' (1) Change energy range'',/,
     .         '' (2) Change crossing of bands'',/,
     .         '' (3) Copy one symmetry set to another'',/,
     .         '' (4) Get back original noncrossed state'',/,
     .         '' (5) Exit'',/)')
  830 WRITE(6,'('' Selection: '',$)')
      READ(5,'(I1)',ERR=830) ISEL
      IF ((ISEL .LT. 1) .OR. (ISEL .GT. 5)) GOTO 830
C
C Change energy range
C
      IF (ISEL .EQ. 1) THEN
        CALL BPENER(EMIN,EMAX)
        IF (EMIN .LT. ELOW) EMIN=ELOW
        IF (EMAX .GT. EHIGH) EMAX=EHIGH
C
C Cross bands.
C
      ELSE IF (ISEL .EQ. 2) THEN
C
C NAG/GKS version.
C
C        WRITE(6,'('' Select first band. Click on any marker.'')')
C
C PGPLOT version.
C
        WRITE(6,'('' Select first band. Put cross with mouse on '',
     .        ''marker, then type a key'')')
        CALL BPSELC(X,EBUFF,EMIN,EMAX,XLEN,VPXOFF,VPYOFF,VPXAXW,
     .              VPYAXH,NK,NNOFIT,NBFIT,IBAND1,KCHANG)
        WRITE(6,'('' Band '',I4,'' selected.'')') IORD(IBAND1,KCHANG)
C
C NAG/GKS version.
C  
        WRITE(6,'('' Choose second band.'',/,'' Click on marker, from '',
     .            ''which on bands should be crossed.'')')
C
C PGPLOT version.
C
        WRITE(6,'('' Choose second band.'',/,'' Put cross on marker, '',
     .            ''from which on bands should be crossed,'',/,
     .            '' then type a key.'')')

C
C MS-Windows version: Uncomment call to BPRAW.
C VMS, AIX, Windows NT version: Comment call to BPRAW
C
C        CALL BPRAW(X,Y,ERAW,EMIN,EMAX,XLEN,VPXOFF,VPYOFF,VPXAXW,VPYAXH,
C     .             NK,NNOFIT,NBFIT,IDIREC)
        CALL BPSELC(X,EBUFF,EMIN,EMAX,XLEN,VPXOFF,VPYOFF,VPXAXW,
     .              VPYAXH,NK,NNOFIT,NBFIT,IBAND2,KCHANG)
        WRITE(6,'('' Band '',I4,'' selected. Crossing at k-point '',I2,
     .            ''.'')') IORD(IBAND2,KCHANG),KCHANG
        DO K=KCHANG,IKEND,IDIREC
          ITEMP=IORD(IBAND1,K)
          IORD(IBAND1,K)=IORD(IBAND2,K)
          IORD(IBAND2,K)=ITEMP
          TEMP=ERAW(IORD(IBAND1,K),K)
          ERAW(IORD(IBAND1,K),K)=ERAW(IORD(IBAND2,K),K)
          ERAW(IORD(IBAND2,K),K)=TEMP
        END DO
C
C Copy one symmetry set to another.
C
      ELSE IF (ISEL .EQ. 3) THEN
  900   WRITE(6,'('' Enter k-point number to copy symmetry info from '',
     .        ''(min=1, max='',I2,''): '',$)') NK
        READ(5,'(I3)',ERR=900) IKFROM
        IF ((IKFROM .LT. 1) .OR. (IKFROM .GT. NK)) GOTO 900
  930   WRITE(6,'('' Enter k-point number to copy symmetry info to '',
     .        ''(min=1, max='',I2,''): '',$)') NK
        READ(5,'(I3)',ERR=930) IKTO
        IF ((IKTO .LT. 1) .OR. (IKTO .GT. NK)) GOTO 930
 
  950   WRITE(6,'('' Lower band  (min='',I3,'', max='',I3,''): '',$)') 
     .        NNOFIT+1,NNOFIT+NBFIT
        READ(5,'(I3)',ERR=950) JCOPYS
        IF (JCOPYS .LT. (NNOFIT+1)) GOTO 950
 
  970   WRITE(6,'('' Higher band (min='',I3,'', max='',I3,''): '',$)') 
     .        NNOFIT+1,NNOFIT+NBFIT
        READ(5,'(I3)',ERR=970) JCOPYE
        IF (JCOPYE .GT. (NNOFIT+NBFIT)) GOTO 970
 
        DO J=JCOPYS,JCOPYE
          CSYMRE(J,IKTO)=CSYMRE(J,IKFROM)
        END DO
        DO I=NNOFIT+1,NNOFIT+NBFIT
          DO J=1,NK
            IORD(I,J)=I
          END DO
        END DO
        CALL BPBSRT(IORD,IKSTRT,IKEND,IDIREC,NNOFIT,NBFIT,CSYMRE)
        CALL BPSRT2(ERAW,EBUFF,IORD,NNOFIT,NBFIT,NBTOT,NK)
C
C Uncross bands.
C
      ELSE IF (ISEL .EQ. 4) THEN
        WRITE(6,'(/,'' Enter region to uncross.'',/)')
 1010   WRITE(6,'('' Lower band:  '',$)')
        READ(5,'(I4)',ERR=1010) JLO
        IF ((JLO .LT. NNOFIT+1) .OR. (JLO .GT. NNOFIT+NBFIT)) GOTO 1010
 1040   WRITE(6,'('' Higher band: '',$)')
        READ(5,'(I4)',ERR=1040) JHI
        IF ((JHI .LT. JLO) .OR. (JHI .GT. NNOFIT+NBFIT)) GOTO 1040
 
        DO K=1,NK
          DO J=JLO,JHI
            IBAND1=J
            IBAND2=IORD(J,K)
            IORD(IBAND1,K)=IBAND1
            IORD(IBAND2,K)=IBAND2
            ERAW(IBAND1,K)=EBUFF(IBAND1,K)
            ERAW(IBAND2,K)=EBUFF(IBAND2,K)
          END DO
        END DO
C
C Exit.
C
      ELSE
        IF (FNEWLI) THEN
          WRITE(6,'('' Enter if bands at end of line '',I2,'' are'',/,
     .              ''   (0) symmorphic (derivative=0)'',/,
     .              ''   (1) nonsymmorphic (nonzero derivative)'',/)') 
     .          ILABEL
 1090     WRITE(6,'('' Selection: '',$)')
          READ(5,'(I1)',ERR=1090) ISYMME
          IF ((ISYMME .LT. 0) .OR. (ISYMME .GT. 1)) GOTO 1090
 
          WRITE(6,'('' Enter if the beginning of the line '',I2,'' is'',
     .            /,''   (0) symmorphic'',/,
     .              ''   (1) nonsymmorphic'',/)') ILABEL
 1130     WRITE(6,'('' Selection: '',$)')
          READ(5,'(I1)',ERR=1130) ISYMMS
          IF ((ISYMMS .LT. 0) .OR. (ISYMMS .GT. 1)) GOTO 1130
 
          WRITE(6,'(/,'' The derivatives should NOT be used as '',
     .                ''interpolation procedure information at'',/,
     .           '' (because they are zero or incorrect due to the '',
     .           '' degeneracy at the zone boundary)'',/,
     .           ''  (0) both left and right hand end points (def.)'',/,
     .           ''  (1) the left hand end point'',/,
     .           ''  (2) the right hand end point'',/,
     .           ''  (3) neither end point'',/)')
 1160     WRITE(6,'('' Selection: '',$)')
          READ(5,'(I1)',ERR=1160) IUSEEN
          IF ((IUSEEN .LT. 0) .OR. (IUSEEN .GT. 3)) GOTO 1160
 
          IUSESY=0
          IF (ISYMMS+ISYMME .GT. 0) THEN
            IUSESY=1
 1190       WRITE(6,'(/,'' Are you including the nonsymmorphic k '',
     .                ''points default=yes)? '',$)')
            READ(5,'(A1)',ERR=1190) CHIN
            IF ((INDEX(CHIN,'N') .GT. 0) .OR. (INDEX(CHIN,'n') .GT. 0))
     .      IUSESY=0
          ENDIF
        ENDIF
 
        WRITE(4,'(6I3)') ILABEL,NK,ISYMMS,ISYMME,IUSEEN,IUSESY
 
        DO K=IKSTRT,IKEND,IDIREC
          WRITE(4,'(I4)') KPOINT(K)
          NRLINE=NBTOT/20
          IRLINE=0
          IF (NRLINE .GT. 0) THEN
            DO J=1,NRLINE
              WRITE(4,'(20I4)') (IORD(IRLINE*20+L,K),L=1,20)
              IRLINE=IRLINE+1
            END DO
          ENDIF
          IF ((NBTOT-IRLINE*20) .GT. 0) THEN
            WRITE(4,'(20I4)') (IORD(IRLINE*20+L,K),L=1,NBTOT-IRLINE*20)
          ENDIF
        END DO
      ENDIF
      IF (ISEL .LT. 5) GOTO 810
      GOTO 280
 
 1270 CONTINUE
C
C MS-Windows and AIX version: Uncomment call to BPCOPY.
C VMS version: Comment call to BPCOPY.
C
      CALL BPCOPY(FSYMEX)
      CLOSE(3)
C
C MS-Windows and AIX version: Add STATUS='DELETE' to OPEN statement.
C VMS version: Remove STATUS='DELETE' from OPEN statement.
C
      CLOSE(4,STATUS='DELETE')
C      CLOSE(4)
C
C Interpolate bands.
C
 1280 CLOSE (1)
      CLOSE (2)
      WRITE(6,'(//,'' Interpolating bands ...'')')
      CALL BFIT(NSYM)
      WRITE(6,'(//)')
      GOTO 20
C
C ---------------------------------------------------------------------
C
C PART 2: Display interpolated bands
C
C UNIT 2: Outputfile of Bandfit, contains interpolated band data,
C         will be opened and closed in BPBAND
C UNIT 3: Inputfile for Bandfit, contains symmetry data
C
C MS-Windows version: Add FILE='fort.2'.
C VMS and AIX version: Remove FILE='fort.2'.
C
 1310 OPEN (UNIT=2,STATUS='OLD',FORM='FORMATTED',FILE='fort.2')
C 1310 OPEN (UNIT=2,STATUS='OLD',FORM='FORMATTED')
      REWIND 2
      READ(2,'(I2)') NSYM
      CLOSE (2)
 
 1330 WRITE(6,'('' Number of symmetry lines (default='',I2,''): '',$)')
     .      NSYM
      READ(5,'(I2)',ERR=1310) NSYM1
      IF ((NSYM1 .LT. 0) .OR. (NSYM1 .GT. NSYM)) GOTO 1330
      IF (NSYM1 .EQ. 0) NSYM1=NSYM
      IF (NSYM1 .GT. 3) THEN
C
C Horizontal plotting.
C
        PLTROT=.FALSE.
        VPXFUL=VHXFUL
        VPYFUL=VHYFUL
        VPXAXW=VHXAXW
        VPYAXH=VHYAXH
        VPXOFF=VHXOFF
        VPYOFF=VHYOFF
      ENDIF
C
C Initialize device and set main viewport.
C
C NAG/GKS version.
C
C      CALL J06WAF
C      CALL J06WCF(0.0,VPXFUL,0.0,VPYFUL)
C      CALL J06WDF
C
C PGPLOT version.
C
      CALL PGSVP(0.0,VPXFUL,0.0,VPYFUL)
      CALL PGPAGE
C
C Set line width scale factor. (GKS routine)
C
C NAG/GKS version.
C
C      WLINE=3.0
C      CALL GSLWSC(WLINE)
C
C PGPLOT version.
C
       IWLINE=3
       CALL PGSLW(IWLINE)
C
C Get x axis section lengths in viewport coordinates.
C

      IF (NSYM1 .GT. 1) THEN
 1360   WRITE(6,'(/,'' Equal symmetry line lengths? (default=Y) '',$)')
        READ(5,'(A1)',ERR=1360) CHIN
        IF (INDEX('Nn',CHIN) .GT. 0) THEN
          CALL BPSYML(VPXSCT,VPXAXW,NSYM1)
        ELSE
          DO I=1,NSYM1+1
C
C NAG/GKS version.
C
C            VPXSCT(I)=DBLE(I-1)*VPXAXW/DBLE(NSYM1)
C
C PGPLOT version.
C
            VPXSCT(I)=REAL(I-1)*VPXAXW/REAL(NSYM1)
          END DO
        ENDIF
      ELSE
        VPXAXW=VPXAXW*2.0/3.0
        VPXSCT(1)=0.0
        VPXSCT(2)=VPXAXW
      ENDIF
C
C Inquire minimum and maximum energy for plotting.
C
      CALL BPENER(EMIN,EMAX)
C
C Plot axes and energy bands.
C
      CALL BPAXES(VPXOFF,VPYOFF,VPXSCT,VPXAXW,VPYAXH,NSYM1)
      CALL BPBAND(VPXOFF,VPYOFF,VPXSCT,VPYAXH,EMIN,EMAX,NSYM1,IFAIL)
      IF (IFAIL .NE. 0) GOTO 1470
C
C Optionally add ticks, borders, labels, axis titles. Maybe generate
C a final plotfile.
C
      CALL BPGRPH(VPXOFF,VPYOFF,VPXFUL,VPYFUL,VPXSCT,VPXAXW,
     .            VPYAXH,EMIN,EMAX,NSYM1,IFAIL)
C
C Terminate plotting on the current device.
C
C NAG/GKS version.
C
C 1460 CALL J06WZF
C
C PGPLOT version.
C      
1460  CALL PGEND
      STOP
C
C Error messages.
C
 1470 WRITE(6,1480)
 1480 FORMAT(' Inputfiles name.EH1 or name.EHE could not be opened.')
      STOP
      END
