C ********************************************************************
C * BANDPLOT - Plotting and interpolation of energy bands            *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  BFIT                                                            *
C *                                                                  *
C *  Usage......: Interpolates bands along symmetry lines using the  *
C *               interpolation procedure of Kertesz and Hughbanks   *
C *               (Phys Rev B, 1981).                                *
C *                                                                  *
C *  Authors....: Sunil Wijeyesekera, Chong Zheng                    *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Institute for Inorg. and Phys. Chemistry           *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: -                                                  *
C *  Revision...: 14.02.92/mbs (Martin Braendle), 20.08.92/mbs,      *
C *               31.08.92/mbs, 27.04.93/mbs, 01.07.97/mbs           *
C *  Remarks....: Routine KSORT replaced by EREAD.                   *
C *               File handling must be adjusted for different       *
C *               operating systems. Look for "VMS", "AIX",          *
C *               "MS-Windows", or "Windows NT".                     *
C *               Changed for use with PGPLOT graphics library.      *
C *                                                                  *
C *  Called from: BANDPL,BPOPEN                                      *
C *                                                                  *
C *  Calls......: TSORT,EREAD,DOS                                    *
C *                                                                  *
C ********************************************************************

      SUBROUTINE BFIT(NSYM)
C
C NAG/GKS version.
C
C      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C PGPLOT version.
C
      IMPLICIT REAL (A-H,O-Z)
      INCLUDE 'sizes'

      PARAMETER (MAXBA1=MAXBA+1)
C
C Meaning of variables:
C
C EIN: Energy buffer: Lower MAXK holds energies, higher MAXK holds
C      k weighted energy derivatives.
C NK:  Number of k points per actual symmetry line ISYM
C KIN: Ratios of k points over end point of actual symmetry line ISYM
C

      DIMENSION IND(2,MAXK),INFD(MAXK),R(MAXBA1),ISF(MAXBA),KPOINT(MAXK)
      DIMENSION IDEV(4)
      DIMENSION T(2*MAXK,2*MAXK),TI(2*MAXK,2*MAXK),WORK(2*MAXK),
     .          G(MAXBA),C(MAXBA),EIN(2*MAXK,MAXBA),AEND(MAXSTA,MAXBA),
     .          EV(MAXBA1),AS(MAXSTA,2*MAXK),Q(MAXPTS,MAXBA)
C
C NAG/GKS version.
C
C      DOUBLE PRECISION LAM(2*MAXK),MV(MAXSTA),KIN(MAXK)
C
C PGPLOT version.
C
      REAL    LAM(2*MAXK),MV(MAXSTA),KIN(MAXK)

      DATA ISF/MAXBA*0/,INFD/MAXK*0/
      DATA IDEV/9,10,11,12/
C
C NAG/GKS version, VMS.
C
C      CALL BPOPEN(IDEV(1),'FORMATTED','OLD',' ') 
C      CALL BPOPEN(IDEV(2),'FORMATTED','OLD',' ')
C      CALL BPOPEN(IDEV(3),'FORMATTED','NEW',' ')
C      CALL BPOPEN(IDEV(4),'UNFORMATTED','SCRATCH',' ')
C
C MS-Windows and AIX version: Uncomment the 3 following OPEN 
C statements.
C VMS version: Comment the 3 following OPEN statements.
C
C      OPEN (UNIT=9,FORM='FORMATTED',STATUS='OLD',FILE='fort.3')
C      OPEN (UNIT=10,FORM='FORMATTED',STATUS='OLD',FILE='fort.1')
C      OPEN (UNIT=11,FORM='FORMATTED',STATUS='NEW',FILE='fort.2')
C
C PGPLOT version and NAG/GKS version, MS-Windows and AIX. 
C Since it's not clear which UNIT is used by the PGPLOT driver,
C search for free units.
C
      CALL BPOPEN(IDEV(1),'FORMATTED','OLD','fort.3') 
      CALL BPOPEN(IDEV(2),'FORMATTED','OLD','fort.1')
      CALL BPOPEN(IDEV(3),'FORMATTED','NEW','fort.2')
      CALL BPOPEN(IDEV(4),'UNFORMATTED','SCRATCH',' ')
 
      REWIND IDEV(3)

      NDIM=1
      NDX=2

      READ(IDEV(1),'(3I4)') NBTOT,NNOFIT,NBFIT
      IF (NNOFIT .EQ. 0) NNOFIT=1
      IF (NBFIT .EQ. 0) NBFIT=1

      WRITE(IDEV(3),'(I2)') NSYM

      DO 10 ISYM=1,NSYM
        READ(IDEV(1),'(6I3)',ERR=10) ILABEL,NK,NSYMMS,NSYMME,IUSEEN,
     .                               IUSESY
        CALL TSORT(KPOINT,NBTOT,NK,IDEV)
        CALL EREAD(KIN,EIN,KPOINT,NBTOT,NNOFIT,NBFIT,NK,ILABEL,NSYMME,
     .             IDEV(2))
C
C INFD=Significant derivatives...   see Kertesz and Hughbanks
C
        DO K=1,NK
          INFD(K)=0
        END DO
        IF ((IUSEEN .EQ. 2) .OR. (IUSEEN .EQ. 0)) INFD(NK)=1
        IF ((IUSEEN .EQ. 1) .OR. (IUSEEN .EQ. 0)) INFD(1)=1
C
C Nonsymmorphic
C
        IF ((NSYMME .NE. 0) .AND. (IUSESY .NE. 0)) INFD(NK)=1
        IF ((NSYMMS .NE. 0) .AND. (IUSESY .NE. 0)) INFD(1)=1
        INF=0
        DO K=1,NK
          INF=INF+INFD(K)
        END DO
C
C N4 is the number of significant pieces of information
C
        N4=NK*NDX-INF
        SIGN=1.0
        DO K=1,NK
          READ(IDEV(4)) (ISF(IW),IW=1,NBFIT)
          IF (ISF(1) .NE. 0) THEN
C
C Sort energies and energy derivatives.
C
            DO I=1,NBFIT
              G(I)=EIN(K,I)
              C(I)=EIN(NK+K,I)*SIGN
            END DO

            DO I=1,NBFIT
              EIN(K,I)=G(ISF(I))
              EIN(NK+K,I)=C(ISF(I))
            END DO
          ENDIF
        END DO

        REWIND IDEV(4)
        K1=NK+1
        K2=NK
        DO K=1,NK
          K2=K2+1
          IF (INFD(K) .NE. 1) THEN
            DO  I=1,NBFIT
              EIN(K1,I)=EIN(K2,I)
            END DO
            K1=K1+1
          ENDIF
        END DO

        CALL DOS(IND,INFD,R,Q,T,TI,LAM,WORK,G,C,AEND,EV,MV,KIN,EIN,AS,
     .           NBFIT,NK,N4,NSYMME,INF,NDIM,NDX,IDEV(3))
10    CONTINUE

      DO I=1,4
        CLOSE(IDEV(I))
      END DO
      
      RETURN
      END