C ********************************************************************
C * BANDPLOT - Plotting and interpolation of energy bands            *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  DINV                                                            *
C *                                                                  *
C *  Routine of BFIT                                                 *
C *                                                                  *
C *  Usage......: inverts matrix A to C using Gauss elimination pro- *
C *               cedure.                                            *
C *                                                                  *
C *  Authors....: Sunil Wijeyesekera, Chong Zheng                    *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Institute for anorg. + phys. Chemistry             *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: -                                                  *
C *  Revision...: 17.02.92/mbs, 01.07.97/mbs (Martin Braendle)       *
C *  Remarks....: -                                                  *
C *                                                                  *
C *  Called from: INV                                                *
C *                                                                  *
C *  Calls......: -                                                  *
C *                                                                  *
C ********************************************************************

      SUBROUTINE DINV(A,C,W,N)
C
C NAG/GKS version.
C
C      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C      DOUBLE PRECISION MAX
C
C PGPLOT version.
C
      IMPLICIT REAL (A-H,O-Z)
      REAL MAX
      DIMENSION A(N,N),C(N,N),W(N)

C
C Matrix C is the inverse of an N by N matrix A.
C Set C to the identity matrix
C
      DO I=1,N
        C(I,I)=1.D0
        I1=I+1
        DO J=I1,N
          C(I,J)=0.D0
          C(J,I)=0.D0
        END DO
      END DO
C
C Scale rows of input matrix. W(N)=scaling factors.
C
      DO L=1,N
        W(L)=0.0
        DO I=1,N
          IF (ABS(A(L,I)) .GE. W(L)) W(L)=ABS(A(L,I))
        END DO
        MAX=W(L)
        IF (MAX .LE. 1.E-10) WRITE(6,'(/,'' This matrix is null.'')')
        DO I=1,N
          A(L,I)=A(L,I)/MAX
        END DO
      END DO
C      WRITE(6,10) W
C   10 FORMAT(' Scaling factors for rows are:',/,8F10.5)
C
C Partial pivot and test for singular matrix
C
      L=1
   20 MAX=0.0
      DO 30 I=L,N
        IF (ABS(A(I,L)) .LE. MAX) GOTO 30
        MAX=ABS(A(I,L))
        IA=I
   30 CONTINUE
      IF (MAX .LE. 1.E-10) THEN
        WRITE(6,40) MAX
   40   FORMAT(/,' This matrix is noninvertible.',/,'  MAX is ',D20.5)
        STOP
      ENDIF
      DO J=1,N
        C(L,J)=C(L,J)+C(IA,J)
        A(L,J)=A(L,J)+A(IA,J)
      END DO 
C
C Gauss elimination
C
      D=A(L,L)
      DO J=1,N
        C(L,J)=C(L,J)/D
        A(L,J)=A(L,J)/D
      END DO
      DO I=1,N
        IF (I .NE. L) THEN
          B=A(I,L)
          DO J=1,N
            A(I,J)=A(I,J)-B*A(L,J)
            C(I,J)=C(I,J)-B*C(L,J)
          END DO
        ENDIF
      END DO

      IF (L .GE. N) GOTO 50
      L=L+1
      GOTO 20
C
C Divide columns of output matrix by W(L)
C
   50 DO L=1,N
        DO I=1,N
          C(I,L)=C(I,L)/W(L)
        END DO
      END DO

      RETURN
      END