C ********************************************************************
C * CEDiT - Crystal Electronic Dipole-induced Transitions            *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  SUBROUTINE PODELE                                               *
C *                                                                  *
C *  Routine of EDiT/CEDiT                                           *
C *  version for IBM-PC MS-DOS, Microsoft FORTRAN and                *
C *              IBM-RISC UNIX, AIX XL FORTRAN                       * 
C *                                                                  *
C *  Usage......: Calculates the <p|O|d> transition elements.        *
C *                                                                  *
C *  Authors....: Ruedi Rytz                                         *
C *                                                                  *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Institute for anorg. + phys. Chemistry             *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: August 1992                                        *
C *  Revision...: -                                                  *
C *                                                                  *
C *  Remarks....: -                                                  *
C *                                                                  *
C *  Called from: OBDIAG                                             *
C *                                                                  *
C *  Calls......: ABFNS                                              *
C *               LOVLAP                                             *
C *               PDOVL                                              *
C *               SDOVL                                              *
C *               DDOVL                                              *
C *                                                                  *
C ********************************************************************

      SUBROUTINE PODELE (M, HQZ, N2, SK1, SK21, SK22, C1,
     .                   C2, R, PTR, DTR, LDIST, POL, CURRI,
     .                   CURRJ)

      IMPLICIT NONE

        DOUBLE PRECISION M
        INTEGER          HQZ, N2
        DOUBLE PRECISION SK1, SK21, SK22, C1, C2, R, PTR(9), DTR(25)
        DOUBLE PRECISION LDIST
        CHARACTER*1      POL
        INTEGER          CURRI, CURRJ

C CONST
      INCLUDE 'pconst.inc'

C VAR
      INTEGER L1, L2, ML, N1, MAX
      DOUBLE PRECISION  A(20), B(20), A1(20), B1(20), PDO1(3,5) 
      DOUBLE PRECISION  PDO2(3,5) 
      DOUBLE PRECISION  PDOS1, PDOS2, PDOP1, PDOP2, SDOS1, SDOS2
      DOUBLE PRECISION  DDOS1, DDOS2, DDOP1, DDOP2, DDOD1, DDOD2 
      DOUBLE PRECISION  SDO1(5), SDO2(5), DDO1(5,5), DDO2(5,5)
      DOUBLE PRECISION  NORM1, NORM2

      INCLUDE 'pfns.inc'
      INCLUDE 'pnorm.inc'

C BEGIN

C Berechne zuerst den normalen p-d-Overlap

      N1 = HQZ
      L1 = 1
      L2 = 2
      ML = 0
      MAX = N1 + N2

      CALL ABFNS(A, B, SK1, SK21, R, MAX)
      CALL ABFNS(A1, B1, SK1, SK22, R, MAX)

      CALL LOVLAP(PDOS1, A, B, SK1, SK21, R, L1, L2,
     .            ML, N1, N2)

      CALL LOVLAP(PDOS2, A1, B1, SK1, SK22, R, L1, L2,
     .            ML, N1, N2)

      PDOS1 = -PDOS1
      PDOS2 = -PDOS2 

      ML = 1 

      CALL LOVLAP(PDOP1, A, B, SK1, SK21, R, L1, L2,
     .            ML, N1, N2)

      CALL LOVLAP(PDOP2, A1, B1, SK1, SK22, R, L1, L2,
     .            ML, N1, N2)

      CALL PDOVL(PDO1, PDOS1, PDOP1, PTR, DTR)
      CALL PDOVL(PDO2, PDOS2, PDOP2, PTR, DTR)

C Berechne nun den s-d-Overlap nachdem man den Operator auf das
C p-Orbital angewandt hat.

      N1 = N1 + 1
      L1 = 0
      ML = 0
      MAX = N1 + N2

      CALL ABFNS(A, B, SK1, SK21, R, MAX)
      CALL LOVLAP(SDOS1, A, B, SK1, SK21, R, L1, L2,
     .            ML, N1, N2)
 
      CALL ABFNS(A1, B1, SK1, SK22, R, MAX)
      CALL LOVLAP(SDOS2, A1, B1, SK1, SK22, R, L1, L2,
     .            ML, N1, N2)

      CALL SDOVL(SDO1, SDOS1, DTR)
      CALL SDOVL(SDO2, SDOS2, DTR)

C Berechne nun den d-d-Overlap nachdem man den Operator auf das
C p-Orbital angewandt hat.

      L1 = 2

      ML = 0
      CALL LOVLAP(DDOS1, A, B, SK1, SK21, R, L1, L2,
     .            ML, N1, N2)
      CALL LOVLAP(DDOS2, A1, B1, SK1, SK22, R, L1, L2,
     .            ML, N1, N2)
      ML = 1
      CALL LOVLAP(DDOP1, A, B, SK1, SK21, R, L1, L2,
     .            ML, N1, N2)
      CALL LOVLAP(DDOP2, A1, B1, SK1, SK22, R, L1, L2,
     .            ML, N1, N2)

      DDOP1 = -DDOP1
      DDOP2 = -DDOP2

      ML = 2
      CALL LOVLAP(DDOD1, A, B, SK1, SK21, R, L1, L2,
     .            ML, N1, N2)
      CALL LOVLAP(DDOD2, A1, B1, SK1, SK22, R, L1, L2,
     .            ML, N1, N2)
    
      CALL DDOVL(DDO1, DDOS1, DDOP1, DDOD1, DTR)
      CALL DDOVL(DDO2, DDOS2, DDOP2, DDOD2, DTR)

      IF (CURRI .EQ. 2) THEN

        IF (POL .EQ. 'X') THEN
          M = M * (C1 * I2XX(DDO1(1,CURRJ-4), DDO1(2,CURRJ-4),
     .                       SDO1(CURRJ-4), PDO1(1,CURRJ-4)) +
     .             C2 * I2XX(DDO2(1,CURRJ-4), DDO2(2,CURRJ-4),
     .                       SDO2(CURRJ-4), PDO2(1,CURRJ-4)))
        ELSEIF (POL .EQ. 'Y') THEN
          M = M * (C1 * XY(DDO1(3,CURRJ-4), PDO1(1,CURRJ-4)) +
     .             C2 * XY(DDO2(3,CURRJ-4), PDO2(1,CURRJ-4)))
        ELSE 
          M = M * (C1 * XY(DDO1(4,CURRJ-4), PDO1(1,CURRJ-4)) +
     .             C2 * XY(DDO2(4,CURRJ-4), PDO2(1,CURRJ-4)))
        ENDIF

      ELSEIF (CURRI .EQ. 3) THEN

        IF (POL .EQ. 'X') THEN
          M = M * (C1 * XY(DDO1(3,CURRJ-4), PDO1(2,CURRJ-4)) +
     .             C2 * XY(DDO2(3,CURRJ-4), PDO2(2,CURRJ-4)))
        ELSEIF (POL .EQ. 'Y') THEN
          M = M * (C1 * I3XX(DDO1(1,CURRJ-4), DDO1(2,CURRJ-4),
     .                       SDO1(CURRJ-4), PDO1(2,CURRJ-4)) +
     .             C2 * I3XX(DDO2(1,CURRJ-4), DDO2(2,CURRJ-4),
     .                       SDO2(CURRJ-4), PDO2(2,CURRJ-4)))
        ELSE 
          M = M * (C1 * XY(DDO1(5,CURRJ-4), PDO1(2,CURRJ-4)) +
     .             C2 * XY(DDO2(5,CURRJ-4), PDO2(2,CURRJ-4)))
        ENDIF
 
      ELSE
      
        IF (POL .EQ. 'X') THEN
          M = M * (C1 * XY(DDO1(4,CURRJ-4), PDO1(3,CURRJ-4)) + 
     .             C2 * XY(DDO2(4,CURRJ-4), PDO2(3,CURRJ-4))) 
        ELSEIF (POL .EQ. 'Y') THEN
          M = M * (C1 * XY(DDO1(5,CURRJ-4), PDO1(3,CURRJ-4)) +
     .             C2 * XY(DDO2(5,CURRJ-4), PDO2(3,CURRJ-4)))
        ELSE
          M = M * (C1 * I4XX(DDO1(2,CURRJ-4), SDO1(CURRJ-4), 
     .                       PDO1(3,CURRJ-4)) +
     .             C2 * I4XX(DDO2(2,CURRJ-4), SDO2(CURRJ-4),
     .                       PDO2(3,CURRJ-4)))
        ENDIF

      ENDIF

      RETURN
      END 
C END
