C ********************************************************************
C * DOSPLOT -  Plots density of states (DOS)                         *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  DPTICA                                                          *
C *                                                                  *
C *  Routine of DPPLOT                                               *
C *                                                                  *
C *  Usage......: Draws labelled and ticed axes.                     *
C *                                                                  *
C *  Author.....: Martin Braendle (mbs) c/o                          *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Institute for anorg. + phys. Chemistry             *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: 28.04.92                                           *
C *  Revision...: 12.02.93/mbs,19.06.97/mbs                          *
C *  Remarks....: Routine simplified for vertical and horizontal     *
C *               axes./mbs                                          *
C *               Major revision for use with PGPLOT graphics        *
C *               subroutine library.                                *
C *                                                                  *
C *  Called from: DOSPLT,DPGRPH                                      *
C *                                                                  *
C *  Calls......: PGPLOT routines PGBOX,PGSWIN,PGSVP,PGSCI,PGSCF     *
C *                                                                  *
C ********************************************************************

      SUBROUTINE DPTICA(VPXOFF,VPYOFF,VPXAXW,VPYAXH,RMIN,RMAX,RANGE,
     .                  TCMIN,TCMAX,THRU,TICDIS,TICDS2,ITICSD,INUM,
     .                  IAXIS)
C
C NAG/GKS version.
C
C      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
C
C PGPLOT version.
C
      IMPLICIT REAL(A-H,O-Z)

      INCLUDE 'sizes' 

      CHARACTER   CDUMMY(1)
      CHARACTER*8 AXSTRH,AXSTRV

      PARAMETER (MARGIN=0,IPEN=1,IVERT=2)
C
C NAG/GKS version.
C
C      PARAMETER(IFONT=IHELV)
C
C PGPLOT version.
C
      PARAMETER(IFONT=2)

      VPXEND=VPXOFF+VPXAXW
      VPYEND=VPYOFF+VPYAXH
C
C Select pen and font.
C
C NAG/GKS version.
C      
C      CALL J06YMF(IPEN)
C      CALL J06YSF(IFONT)
C
C PGPLOT version.
C
      CALL PGSCI(IPEN)
      CALL PGSCF(IFONT)
C
C Vertical axis.
C
      IF (IAXIS .EQ. IVERT) THEN
C
C NAG/GKS version.
C Set data range and viewport. Data range must be widened so that all
C labels will be fully visible.
C
C        DRMIN=RMIN-RANGE/VPYAXH*VPYOFF
C        DRMAX=RMAX+RANGE/VPYAXH*(1.0-VPYEND)
C        CALL J06WBF(0.0,1.0,DRMIN,DRMAX,MARGIN)
C        CALL J06WCF(0.0,1.0,0.0,1.0)
C
C PGPLOT version.
C Uses viewport settings for placement of axes.
C
        CALL PGSWIN(THRU,1.0,TCMIN,TCMAX)
        YSTART=VPYOFF+(TCMIN-RMIN)/RANGE*VPYAXH
        YEND=VPYOFF+(TCMAX-RMIN)/RANGE*VPYAXH
        CALL PGSVP(THRU,1.0,YSTART,YEND)
        AXSTRH='  '
        AXSTRV='AB'
        IF (THRU .EQ. VPXOFF) AXSTRV='ABN'
C
C Horizontal axis.
C
      ELSE
C
C Set data range and viewport. 
C
C NAG/GKS version. Data range must be widened so that all
C labels will be fully visible.
C
C        DRMIN=RMIN-RANGE/VPXAXW*VPXOFF
C        DRMAX=RMAX+RANGE/VPXAXW*(1.0-VPXEND)
C        CALL J06WBF(DRMIN,DRMAX,0.0,1.0,MARGIN)
C        CALL J06WCF(0.0,1.0,0.0,1.0)
C
C PGPLOT version.
C Uses viewport settings for placement of axes.
C
        CALL PGSWIN(TCMIN,TCMAX,THRU,1.0)
        XSTART=VPXOFF+(TCMIN-RMIN)/RANGE*VPXAXW
        XEND=VPXOFF+(TCMAX-RMIN)/RANGE*VPXAXW
        CALL PGSVP(XSTART,XEND,THRU,1.0)
        AXSTRH='AB'
        AXSTRV='  '
        IF (THRU .EQ. VPYOFF) AXSTRH='ABN'
      ENDIF
C
C Draw labeled axis.
C
C NAG/GKS version.
C
C      ILABS=0
C      NLABEL=1
C      NUMINT=0
C      IF ((ITICSD .EQ. 1) .OR. (ITICSD .EQ. 3)) THEN
C        ITICK=1
C        IF ((INUM .EQ. 1) .AND. (TICDS2 .GT. 0.0)) THEN
C          CALL J06AQF(IAXIS,RMIN,TCMAX,THRU,TICDS2,TCMIN,NUMINT,
C     .                ITICK,INUM,ILABS,CDUMMY,NLABEL)
C        ENDIF
C        INUM=0
C        CALL J06AQF(IAXIS,RMIN,TCMAX,THRU,TICDIS,TCMIN,NUMINT,ITICK,
C     .              INUM,ILABS,CDUMMY,NLABEL)
C      ENDIF
C      IF ((ITICSD .EQ. 2) .OR. (ITICSD .EQ. 3)) THEN
C        ITICK=-1
C        IF ((INUM .EQ. 1) .AND. (TICDS2 .GT. 0.0)) THEN
C          CALL J06AQF(IAXIS,RMIN,TCMAX,THRU,TICDS2,TCMIN,NUMINT,
C     .                ITICK,INUM,ILABS,CDUMMY,NLABEL)
C        ENDIF
C        INUM=0
C        CALL J06AQF(IAXIS,RMIN,TCMAX,THRU,TICDIS,TCMIN,NUMINT,ITICK,
C     .              INUM,ILABS,CDUMMY,NLABEL)
C      ENDIF
C
C   Output polyline buffer.
C
C      CALL J06YAF(0.0D0,0.0D0)
C
C PGPLOT version.
C
      IF (TICDS2 .GT. 0.0) THEN
        ISTICS=NINT(TICDS2/TICDIS)
      ENDIF
      IF ((ITICSD .EQ. 1) .OR. (ITICSD .EQ. 3)) THEN
        CALL PGBOX(AXSTRH//'ITS',TICDS2,ISTICS,AXSTRV//'ITSV',TICDS2,
     .             ISTICS)
      ENDIF
      IF ((ITICSD .EQ. 2) .OR. (ITICSD .EQ. 3)) THEN
        CALL PGBOX(AXSTRH//'NTS',TICDS2,ISTICS,AXSTRV//'TSV',TICDS2,
     .             ISTICS)
      ENDIF 
      RETURN
      END