C ********************************************************************
C * EHMACC - Extended Hueckel Molecular and Crystal Calculations     *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  BLOCK DATA                                                      *
C *                                                                  *
C *  Routine of EHMACC                                               *
C *                                                                  *
C *  Usage......: Defines the atomic parameters (i.e., the number of *
C *               valence electrons, the valence shell ionization    *
C *               potentials, the Slater type orbital exponents, and *
C *               the weighting coefficients), which were taken from *
C *               the table collected by S. Alvarez, Dept. de        *
C *               Quimica Inorganica, Univ. de Barcelona, Spain      *
C *                                                                  *
C *  Authors....: M.-H. Whangbo, Dept of Chem, North Carolina State  *
C *               University, Raleigh N.C.,                          *
C *               modified by M. Evain, Dept of Chemistry, North     *
C *               Carolina State University, Raleigh N.C.            *
C *  Date.......: 1981                                               *
C *  Revision...: Dec. 1987, 24.12.92/mbs (Martin Braendle c/o       *
C *               Calzaferri group, Inst. f. Inorg. and Phys. Chem., *
C *               Freiestr. 3, CH-3012 Berne)                        *
C *  Remarks....: -                                                  *
C *                                                                  *
C ********************************************************************

      BLOCK DATA
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      INCLUDE 'sizes'
      
      COMMON /AELCON/AOOCC(NATMMX,4),USECON(NATMMX)
      LOGICAL USECON

      COMMON /BDATA/ NSD(103),NPD(103),NDD(103),NFD(103),COULSD(103),
     . EXPSS(103),EXPSD1(103),EXPSD2(103),CSD1(103),CSD2(103),
     . COULPD(103),EXPPS(103),EXPPD1(103),EXPPD2(103),CPD1(103),
     . CPD2(103),COULDD(103),EXPDS(103),EXPDD1(103),EXPDD2(103),
     . CDD1(103),CDD2(103),COULFD(103),EXPFS(103),EXPFD1(103),
     . EXPFD2(103),CFD1(103),CFD2(103)
      COMMON /BDATA1/ IVELD(103)
      COMMON /BDATA2/ SYMBD(103)
      CHARACTER*2 SYMBD

      DATA USECON/NATMMX*.FALSE./

      DATA (SYMBD(I),I=1,103) /' H','HE','LI','BE',' B',' C',' N',' O',
     .' F','NE','NA','MG','AL','SI',' P',' S','CL','AR',' K','CA','SC',
     .'TI',' V','CR','MN','FE','CO','NI','CU','ZN','GA','GE','AS','SE',
     .'BR','KR','RB','SR',' Y','ZR','NB','MO','TC','RU','RH','PD','AG',
     .'CD','IN','SN','SB','TE',' I','XE','CS','BA','LA','CE','PR','ND',
     .'PM','SM','EU','GD','TB','DY','HO','ER','TM','YB','LU','HF','TA',
     .' W','RE','OS','IR','PT','AU','HG','TL','PB','BI','PO','AT','RN',
     .'FR','RA','AC','TH','PA',' U','NP','PU','AM','CM','BK','CF','ES',
     .'FM','MD','NO','LR'/
C
C
C ********************* valence electrons ************************
C
C                                H HE LI BE  B  C  N  O  F NE
C     NA MG AL SI  P  S CL AR  K CA SC TI  V CR MN FE CO NI CU ZN
C     GA GE AS SE BR KR RB SR  Y ZR NB MO TC RU RH PD AG CD IN SN
C     SB TE  I XE CS BA LA CE PR ND PM SM EU GD TB DY HO ER TM YB
C     LU HF TA  W RE OS IR PT AU HG TL PB BI PO AT RN FR RA AC TH
C     PA  U NP PU AM CM BK CF ES FM MD NO LR
      DATA (IVELD(I),I=1,103) /1,2,1,2,3,4,5,6,7,8,1,2,3,4,5,6,7,8,1,2,
     . 3,4,5,6,7,8,9,10,11,2,3,4,5,6,7,8,1,2,3,4,5,6,7,8,9,10,11,12,3,4,
     . 5,6,7,8,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,4,5,6,7,8,9,10,
     . 11,12,3,4,5,6,7,8,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17/
C
C *******************  valence orbitals  *****************************
C
C         s:
C                            H HE LI BE  B  C  N  O  F NE
C     NA MG AL SI  P  S CL AR  K CA SC TI  V CR MN FE CO NI CU ZN
C     GA GE AS SE BR KR RB SR  Y ZR NB MO TC RU RH PD AG CD IN SN
C     SB TE  I XE CS BA LA CE PR ND PM SM EU GD TB DY HO ER TM YB
C     LU HF TA  W RE OS IR PT AU HG TL PB BI PO AT RN FR RA AC TH
C     PA  U NP PU AM CM BK CF ES FM MD NO LR
      DATA (NSD(I),I=1,103) /1,1,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,4,4,4,
     . 4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,
     . 5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
     . 6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7/
C
C
C         P:
C                            H HE LI BE  B  C  N  O  F NE
C     NA MG AL SI  P  S CL AR  K CA SC TI  V CR MN FE CO NI CU ZN
C     GA GE AS SE BR KR RB SR  Y ZR NB MO TC RU RH PD AG CD IN SN
C     SB TE  I XE CS BA LA CE PR ND PM SM EU GD TB DY HO ER TM YB
C     LU HF TA  W RE OS IR PT AU HG TL PB BI PO AT RN FR RA AC TH
C     PA  U NP PU AM CM BK CF ES FM MD NO LR
      DATA (NPD(I),I=1,103) /0,0,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,4,4,4,
     . 4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,
     . 5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
     . 6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7/
C
C
C          d:
C                            H HE LI BE  B  C  N  O  F NE
C     NA MG AL SI  P  S CL AR  K CA SC TI  V CR MN FE CO NI CU ZN
C     GA GE AS SE BR KR RB SR  Y ZR NB MO TC RU RH PD AG CD IN SN
C     SB TE  I XE CS BA LA CE PR ND PM SM EU GD TB DY HO ER TM YB
C     LU HF TA  W RE OS IR PT AU HG TL PB BI PO AT RN FR RA AC TH
C     PA  U NP PU AM CM BK CF ES FM MD NO LR
      DATA (NDD(I),I=1,103) /0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,
     . 3,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,4,4,4,4,4,4,4,4,4,4,0,0,0,0,0,
     . 0,0,0,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,0,0,0,0,0,
     . 0,0,0,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6/
C
C
C           f:
C                            H HE LI BE  B  C  N  O  F NE
C     NA MG AL SI  P  S CL AR  K CA SC TI  V CR MN FE CO NI CU ZN
C     GA GE AS SE BR KR RB SR  Y ZR NB MO TC RU RH PD AG CD IN SN
C     SB TE  I XE CS BA LA CE PR ND PM SM EU GD TB DY HO ER TM YB
C     LU HF TA  W RE OS IR PT AU HG TL PB BI PO AT RN FR RA AC TH
C     PA  U NP PU AM CM BK CF ES FM MD NO LR
      DATA (NFD(I),I=1,103) /0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
     . 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
     . 0,0,0,0,4,4,4,4,4,4,4,4,4,4,4,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
     . 0,0,0,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5/
C
C
C ******************** VSIP's of s,p,d and f *********************
C
C    s:
C
C                               H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (COULSD(I),I=1,69) /-13.600,-23.400,-5.400,-10.000,-15.200,-
     . 21.400,-26.000,-32.300,-40.000,-43.200,-5.100,-9.000,-12.300,-
     . 17.300,-18.600,-20.000,-26.300,-0.000,-4.340,-7.000,-8.870,-
     . 8.970,-8.810,-8.660,-9.750,-9.100,-9.210,-9.170,-11.400,-12.410,-
     . 14.580,-16.000,-16.220,-20.500,-22.070,-0.000,-4.180,-6.620,-
     . 0.000,-8.000,-10.100,-8.340,-10.070,-10.400,-8.090,-7.320,-0.000,
     . -0.000,-12.600,-16.160,-18.800,-20.800,-18.000,-0.000,-3.880,-
     . 0.000,-7.670,-0.000,-0.000,-0.000,-0.000,-4.860,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000/
C                                YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (COULSD(I),I=70,103) /-5.350,-6.050,-0.000,-10.100,-8.260,-
     . 9.360,-8.170,-11.360,-9.077,-10.920,-13.680,-11.600,-15.700,-
     . 15.190,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-5.390,-0.000,-
     . 5.500,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000/
C
C
C    p:
C
C                               H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (COULPD(I),I=1,69) /-0.000,-0.000,-3.500,-6.000,-8.500,-
     . 11.400,-13.400,-14.800,-18.100,-20.000,-3.000,-4.500,-6.500,-
     . 9.200,-14.000,-13.300,-14.200,-0.000,-2.730,-4.000,-2.750,-5.440,
     . -5.520,-5.240,-5.890,-5.320,-5.290,-5.150,-6.060,-6.530,-6.750,-
     . 9.000,-12.160,-14.400,-13.100,-0.000,-2.600,-3.920,-0.000,-5.400,
     . -6.860,-5.240,-5.400,-6.870,-4.570,-3.750,-0.000,-0.000,-6.190,-
     . 8.320,-11.700,-13.200,-12.700,-0.000,-2.490,-0.000,-5.010,-0.000,
     . -0.000,-0.000,-0.000,-4.860,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000/
C                                YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (COULPD(I),I=70,103) /-5.350,-6.050,-0.000,-6.860,-5.170,-
     . 5.960,-4.810,-4.500,-5.475,-5.550,-8.470,-5.800,-8.000,-7.790,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-5.390,-0.000,-5.500,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000/
C
C
C    d:
C
C                               H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (COULDD(I),I=1,69) /-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-8.510,-10.810,-11.000,-
     . 11.220,-11.670,-12.600,-13.180,-13.490,-14.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-10.200,-
     . 12.100,-10.500,-12.820,-14.900,-12.500,-12.020,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-8.210,-
     . 0.000,-0.000,-0.000,-0.000,-6.060,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000/
C                                YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (COULDD(I),I=70,103) /-5.210,-5.120,-0.000,-12.100,-10.370,-
     . 12.660,-11.840,-12.170,-12.590,-15.076,-17.500,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-10.110,-0.000,-
     . 9.190,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000/
C
C
C    f:
C
C                               H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (COULFD(I),I=1,69) /-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-11.280,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000/
C                                YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (COULFD(I),I=70,103) /-13.860,-22.400,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-9.640,-0.000,-10.620,-
     . 0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-0.000,-
     . 0.000,-0.000/
C
C ********************************************************************
C ***************  Slater exponents and coefficients *****************
C ********************************************************************
C
C ****** s orbitals ******
C
C
C      s single zeta exponent
C
C                              H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (EXPSS(I),I=1,69) /1.3000,1.6880,0.6500,0.9750,1.3000,
     . 1.6250,1.9500,2.2750,2.4250,2.8790,0.7330,1.1000,1.1670,1.3830,
     . 1.7500,2.1220,2.1830,0.0000,0.8740,1.2000,1.3000,1.0750,1.3000,
     . 1.7000,0.9700,1.9000,2.0000,1.8250,2.2000,2.0100,1.7700,2.1600,
     . 2.2300,2.4400,2.5880,0.0000,0.9970,1.2140,0.0000,1.8170,1.8900,
     . 1.9600,2.0180,2.0800,2.1350,2.1900,0.0000,0.0000,1.9030,2.1200,
     . 2.3230,2.5100,2.6790,0.0000,1.0600,0.0000,2.1400,0.0000,0.0000,
     . 0.0000,0.0000,1.4000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000/
C                                YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (EXPSS(I),I=70,103) /1.5400,1.6660,0.0000,2.2800,2.3410,
     . 2.3980,2.4520,2.5000,2.5540,2.6020,2.6490,2.3000,2.3500,2.5600,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,1.8340,0.0000,1.9140,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000/
C
C
C
C      s double zeta exponent #1
C
C                               H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (EXPSD1(I),I=1,69) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 1.8310,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,2.6620,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000/
C                                 YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (EXPSD1(I),I=70,103) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000/
C
C
C
C      s double zeta exponent #2
C
C                               H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (EXPSD2(I),I=1,69) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 1.1530,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,1.6880,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000/
C                                 YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (EXPSD2(I),I=70,103) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000/
C
C
C
C      s double zeta coefficient #1
C
C                            H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (CSD1(I),I=1,69) /0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.76160,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.55640,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000/
C                              YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (CSD1(I),I=70,103) /0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000/
C
C
C
C      s double zeta coefficient #2
C
C                            H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (CSD2(I),I=1,69) /0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.26300,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.48730,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000/
C                              YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (CSD2(I),I=70,103) /0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000/
C
C
C
C
C ****** p orbitals ******
C
C
C      p single zeta exponent
C
C                              H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (EXPPS(I),I=1,69) /0.0000,0.0000,0.6500,0.9750,1.3000,
     . 1.6250,1.9500,2.2750,2.4250,2.8790,0.7330,1.1000,1.1670,1.3830,
     . 1.3000,1.8270,1.7330,0.0000,0.8740,1.2000,1.3000,0.6750,1.3000,
     . 1.7000,0.9700,1.9000,2.0000,1.1250,2.2000,1.7000,1.5500,1.8500,
     . 1.8900,2.0700,2.1310,0.0000,0.9970,1.2140,0.0000,1.7760,1.8500,
     . 1.9000,1.9840,2.0400,2.1000,2.1520,0.0000,0.0000,1.6770,1.8200,
     . 1.9990,2.1600,2.3220,0.0000,1.0600,0.0000,2.0800,0.0000,0.0000,
     . 0.0000,0.0000,1.4000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000/
C                                YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (EXPPS(I),I=70,103) /1.5400,1.6660,0.0000,2.2410,2.3090,
     . 2.3720,2.4290,2.2000,2.5540,2.5840,2.6310,1.6000,2.0600,2.0720,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,1.8340,0.0000,1.9140,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000/
C
C
C
C      p double zeta exponent #1
C
C                               H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (EXPPD1(I),I=1,69) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 2.7300,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,2.3380,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000/
C                                 YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (EXPPD1(I),I=70,103) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000/
C
C
C
C      p double zeta exponent #2
C
C                               H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (EXPPD2(I),I=1,69) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 1.2570,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,1.3330,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000/
C                                 YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (EXPPD2(I),I=70,103) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000/
C
C
C
C      p double zeta coefficient #1
C
C                            H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (CPD1(I),I=1,69) /0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.25950,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.52120,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000/
C                              YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (CPD1(I),I=70,103) /0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000/
C
C
C
C      p double zeta coefficient #2
C
C                            H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (CPD2(I),I=1,69) /0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.80250,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.54430,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000/
C                              YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (CPD2(I),I=70,103) /0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000/
C
C
C
C
C ****** d orbitals ******
C
C
C      d single zeta exponent
C
C                              H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (EXPDS(I),I=1,69) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000/
C                                YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (EXPDS(I),I=70,103) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000/
C
C
C
C      d double zeta exponent #1
C
C                               H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (EXPDD1(I),I=1,69) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,4.3500,4.5500,4.7500,
     . 4.9500,5.1500,5.3500,5.5500,5.7500,5.9500,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,3.8350,4.0800,
     . 4.5400,4.9000,5.3800,4.2900,5.9830,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,3.7800,0.0000,0.0000,
     . 0.0000,0.0000,2.7470,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000/
C                                 YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (EXPDD1(I),I=70,103) /2.8100,2.8130,0.0000,4.7620,4.9820,
     . 5.3430,5.5710,5.7960,6.0130,6.1630,6.4360,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,2.4610,0.0000,2.5810,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000/
C
C
C
C      d double zeta exponent #2
C
C                               H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (EXPDD2(I),I=1,69) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,1.7000,1.4000,1.7000,
     . 1.8000,1.7000,2.0000,2.1000,2.0000,2.3000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,1.5050,1.6400,
     . 1.9000,2.0940,2.3000,1.9700,2.6130,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,1.3810,0.0000,0.0000,
     . 0.0000,0.0000,1.2670,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000/
C                                 YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (EXPDD2(I),I=70,103) /1.2160,1.2100,0.0000,1.9380,2.0680,
     . 2.2770,2.4160,2.5570,2.6960,2.7940,3.0320,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,1.1650,0.0000,1.2070,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000/
C
C
C
C      d double zeta coefficient #1
C
C                            H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (CDD1(I),I=1,69) /0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.42280,
     . 0.42060,0.47550,0.50600,0.51390,0.55050,0.56800,0.56830,0.59330,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.62100,0.64010,0.60970,0.57150,0.53400,0.58070,
     . 0.55350,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.77650,0.00000,0.00000,0.00000,0.00000,
     . 0.71840,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000/
C                              YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (CDD1(I),I=70,103) /0.70630,0.70440,0.00000,0.68150,0.69400,
     . 0.66620,0.63720,0.66980,0.63340,0.68510,0.64380,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.76120,
     . 0.00000,0.76080,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000/
C
C
C
C      d double zeta coefficient #2
C
C                            H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (CDD2(I),I=1,69) /0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.72760,
     . 0.78390,0.70520,0.67500,0.69290,0.62600,0.60600,0.62920,0.57440,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.57690,0.55160,0.60970,0.60120,0.63650,0.56850,
     . 0.67010,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.45860,0.00000,0.00000,0.00000,0.00000,
     . 0.44470,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000/
C                              YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (CDD2(I),I=70,103) /0.48340,0.48800,0.00000,0.68150,0.56310,
     . 0.59100,0.55980,0.58600,0.55130,0.56960,0.52150,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.40710,
     . 0.00000,0.41260,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000/
C
C
C
C
C ****** f orbitals ******
C
C
C      f single zeta exponent
C
C                              H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (EXPFS(I),I=1,69) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000/
C                                YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (EXPFS(I),I=70,103) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000/
C
C
C
C      f double zeta exponent #1
C
C                               H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (EXPFD1(I),I=1,69) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,6.9070,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000/
C                                 YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (EXPFD1(I),I=70,103) /8.6290,9.1360,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,4.4770,0.0000,4.9430,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000/
C
C
C
C      f double zeta exponent #2
C
C                               H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (EXPFD2(I),I=1,69) /0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,2.6390,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000/
C                                 YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (EXPFD2(I),I=70,103) /3.1980,3.6660,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,1.8370,0.0000,2.1060,
     . 0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,0.0000,
     . 0.0000,0.0000/
C
C
C
C      f double zeta coefficient #1
C
C                            H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (CFD1(I),I=1,69) /0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.73540,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000/
C                              YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (CFD1(I),I=70,103) /0.74600,0.73300,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.76820,
     . 0.00000,0.78440,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000/
C
C
C
C      f double zeta coefficient #2
C
C                            H       HE      LI      BE      B
C      C       N       O       F       NE      NA      MG      AL
C      SI      P       S       CL      AR      K       CA      SC
C      TI      V       CR      MN      FE      CO      NI      CU
C      ZN      GA      GE      AS      SE      BR      KR      RB
C      SR      Y       ZR      NB      MO      TC      RU      RH
C      PD      AG      CD      IN      SN      SB      TE      I
C      XE      CS      BA      LA      CE      PR      ND      PM
C      SM      EU      GD      TB      DY      HO      ER      TM
      DATA (CFD2(I),I=1,69) /0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.45970,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000/
C                              YB      LU      HF      TA
C      W       RE      OS      IR      PT      AU      HG      TL
C      PB      BI      PO      AT      RN      FR      RA      AC
C      TH      PA      U       NP      PU      AM      CM      BK
C      CF      ES      FM      MD      NO      LR
      DATA (CFD2(I),I=70,103) /0.45640,0.44590,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,0.42670,
     . 0.00000,0.39080,0.00000,0.00000,0.00000,0.00000,0.00000,0.00000,
     . 0.00000,0.00000,0.00000,0.00000,0.00000/

      END
