C ********************************************************************
C * EHMACC - Extended Hueckel Molecular and Crystal Calculations     *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  BSMAT                                                           *
C *                                                                  *
C *  Routine of EHMACC                                               *
C *                                                                  *
C *  Usage......: Computes a matrix  b  such that:                   *
C *               Real(b) = sum(r) <dcos(k.r)*(a(r)+a(-r))>,         *
C *               Im(b) = sum(r) <dsin(k.r)*(-a(r)+a(-r))>,          *
C *               where  r  is a reciprocal lattice vector, and the  *
C *               sum is over significant nearest neighbors.         *
C *                                                                  *
C *               The matrix is stored as follows: Diagonal elements *
C *               on the diagonal, real parts of lower triangle in   *
C *               lower triangle, imaginary parts of lower triangle  *
C *               in upper triangle.                                 *
C *                                                                  *
C *               This subroutine also prepares the gradient calcu-  *
C *               lation (file 13). Real parts of dS/dk and dS'/dk   *
C *               are stored in upper triangle of C and DKSEXP, ima- *
C *               ginary parts in lower triangle.                    *
C *                                                                  *
C *               Linear combinations of a(r) and a(-r) have been    *
C *               taken at the end of MOVLAP.                        *
C *                                                                  *
C *  Authors....: M.-H. Whangbo, Dept of Chem, North Carolina State  *
C *               University, Raleigh N.C.,                          *
C *               modified by M. Evain, Dept of Chemistry, North     *
C *               Carolina State University, Raleigh N.C.            *
C *  Date.......: 1981                                               *
C *  Revision...: Dec. 1987, 15.05.92/mbs, 30.09.92/mbs, 18.02.93/mbs*
C *               (Martin Braendle, c/o Calzaferri group, Inst. f.   *
C *               Inorg. and Phys. Chemistry, Freiestr. 3, CH-3012   *
C *               Berne)                                             *
C *  Remarks....: Distance dependent weighted Wolfsberg-Helmholz-    *
C *               formula included. Definition for EHMO calculations *
C *               s. G.Calzaferri et al, J.Phys.Chem. 93(1989), 5366 *
C *                                                                  *
C *  Called from: CRYST                                              *
C *                                                                  *
C *  Calls......: -                                                  *
C *                                                                  *
C ********************************************************************

      SUBROUTINE BSMAT(B,A,C,SEXP,DKSEXP,NDIM,FDIST)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      INCLUDE 'sizes'

      DIMENSION B(NDIM,NDIM),A(NDIM,NDIM),C(NDIM,NDIM),SEXP(NDIM,NDIM),
     .          DKSEXP(NDIM,NDIM)
      INTEGER SORB(NATMMX)
      LOGICAL FDIST

      COMMON /ATOM1/NS(NSYMMX,NAEQMX),NP(NSYMMX),ND(NSYMMX),NF(NSYMMX),
     .              INATOM, ISYM(NATMMX),NELEM
      COMMON /ATOM2/EXPS(NSYMMX,NAEQMX),EXPS2(NSYMMX,NAEQMX),
     .              EXPP(NSYMMX),EXPP2(NSYMMX),
     .              EXPD(NSYMMX),EXPD2(NSYMMX),
     .              EXPF(NSYMMX),EXPF2(NSYMMX),
     .              CS1(NSYMMX,NAEQMX),CS2(NSYMMX,NAEQMX),
     .              CP1(NSYMMX),CP2(NSYMMX),CD1(NSYMMX),CD2(NSYMMX),
     .              CF1(NSYMMX),CF2(NSYMMX),COULS(NSYMMX,NAEQMX),
     .              COULP(NSYMMX),COULD(NSYMMX),COULF(NSYMMX),
     .              X(NATMMX),Y(NATMMX),Z(NATMMX)
      COMMON /ATOMPT/IATMPT(NDIMMX)
      COMMON /CELL/DIST(3,3)
      COMMON /DEX/ADD(3),NB,NE,ISUB,NSUB
      COMMON /DISTK/CKAPPA,CDELTA,AKAPPA(NATMMX,NATMMX),
     .              ADELTA(NATMMX,NATMMX)
      COMMON /ORBRAD/D0(NDIMMX)

      COMMON /INDX/NCRYST,NCEL1,NCEL2,NCEL3,XK(3),WEIGHT,TWOPI,ND1,
     .             NGRAD,NFULL,CEL1,CEL2
      LOGICAL CEL1,CEL2

      REWIND 13
C
C Jump over reading of unit cell overlap matrix elements.
C
      READ(21) (SORB(I),I=1,INATOM),A
      DO 20 I=1,NDIM
        DO 10 J=1,I
          B(J,I)=0.0D0
          B(I,J)=0.0D0
          C(J,I)=0.0D0
          C(I,J)=0.0D0
          SEXP(I,J)=0.0D0
          SEXP(J,I)=0.0D0
          DKSEXP(I,J)=0.0D0
          DKSEXP(J,I)=0.0D0
   10   CONTINUE
   20 CONTINUE
C
C 1D system:
C
      DO 70 I=1,NCEL1
        RI=DBLE(I)
        XMULTI=TWOPI*RI
C
C Inclusion of distance dependent Hij.
C 15.05.92/mbs
C
        IF (FDIST) THEN
          DO 25 J=1,3
            ADD(J)=RI*DIST(1,J)
   25     CONTINUE
        ENDIF
        READ(21) A
        DC=DCOS(RI*XK(1))
        DS=DSIN(RI*XK(1))
        DO 40 M=1,ND1
          M1=M+1
          IATOM1=IATMPT(M)
          DO 30 N=M1,NDIM
C
C Inclusion of distance dependent Hij.
C 15.05.92/mbs
C
            IF (FDIST) THEN
              IATOM2=IATMPT(N)
              ORBSUM=D0(M)+D0(N)

              DELX=X(IATOM1)-X(IATOM2)+ADD(1)
              DELY=Y(IATOM1)-Y(IATOM2)+ADD(2)
              DELZ=Z(IATOM1)-Z(IATOM2)+ADD(3)
              RTU=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)
              DELX=X(IATOM2)-X(IATOM1)+ADD(1)
              DELY=Y(IATOM2)-Y(IATOM1)+ADD(2)
              DELZ=Z(IATOM2)-Z(IATOM1)+ADD(3)
              RUT=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)

              RDIF=RTU-ORBSUM
              DELTA=ADELTA(IATOM1,IATOM2)
              RD2=(RDIF-DABS(RDIF))*DELTA
              EXPTU=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)
              RDIF=RUT-ORBSUM
              DELTA=ADELTA(IATOM2,IATOM1)
              RD2=(RDIF-DABS(RDIF))*DELTA
              EXPUT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)

              STU=0.5D0*(A(N,M)-A(M,N))
              SUT=STU+A(M,N)
              SPLUS =STU*EXPTU+SUT*EXPUT
              SMINUS=STU*EXPTU-SUT*EXPUT
              SEXP(N,M)=SEXP(N,M)+DC*SPLUS
              SEXP(M,N)=SEXP(M,N)+DS*SMINUS
              DKSEXP(N,M)=-DC*XMULTI*SMINUS
              DKSEXP(M,N)=-DS*XMULTI*SPLUS
            ENDIF
            B(N,M)=B(N,M)+DC*A(N,M)
            B(M,N)=B(M,N)-DS*A(M,N)
            C(N,M)=DC*XMULTI*A(M,N)
            C(M,N)=-DS*XMULTI*A(N,M)
   30     CONTINUE
C
C Inclusion of distance dependent Hij.
C 15.05.92/mbs
C
          IF (FDIST) THEN
            DELX=ADD(1)
            DELY=ADD(2)
            DELZ=ADD(3)
            R=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)

            RDIF=R-2.0D0*D0(M)
            DELTA=ADELTA(IATOM1,IATOM1)
            RD2=(RDIF-DABS(RDIF))*DELTA
            EXPFCT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)

            SEXP(M,M)=SEXP(M,M)+DC*A(M,M)*EXPFCT
            DKSEXP(M,M)=-DS*XMULTI*A(M,M)*EXPFCT
          ENDIF
          B(M,M)=B(M,M)+DC*A(M,M)
          C(M,M)=-DS*XMULTI*A(M,M)
   40   CONTINUE

        IF (FDIST) THEN
          IF (NDIM .EQ. 1) THEN
            DELX=ADD(1)
            DELY=ADD(2)
            DELZ=ADD(3)
            R=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)
          ENDIF
          IATOM1=IATMPT(NDIM)

          RDIF=R-2.0D0*D0(NDIM)
          DELTA=ADELTA(IATOM1,IATOM1)
          RD2=(RDIF-DABS(RDIF))*DELTA
          EXPFCT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)

          SEXP(NDIM,NDIM)=SEXP(NDIM,NDIM)+DC*A(NDIM,NDIM)*EXPFCT
          DKSEXP(NDIM,NDIM)=-DS*XMULTI*A(NDIM,NDIM)*EXPFCT
        ENDIF
        B(NDIM,NDIM)=B(NDIM,NDIM)+DC*A(NDIM,NDIM)
        C(NDIM,NDIM)=-DS*XMULTI*A(NDIM,NDIM)

        IF (NGRAD .GT. 0) THEN
          WRITE(13) C
          IF (FDIST) WRITE(13) DKSEXP
        ENDIF
   70 CONTINUE

      IF (NCRYST .EQ. 1) GOTO 350
C
C 2D system:
C
      NCEL11=NCEL1+1
      DO 150 I=1,NCEL11
        RI=DBLE(I-1)
        XMULTI=TWOPI*RI
        DO 140 J=1,NCEL2
          RJ=DBLE(J)
          IF (FDIST) THEN
            DO 75 K=1,3
              ADD(K)=RI*DIST(1,K)+RJ*DIST(2,K)
   75       CONTINUE
          ENDIF
          XMULTJ=TWOPI*RJ
          READ(21) A
          DC=DCOS(RI*XK(1)+RJ*XK(2))
          DS=DSIN(RI*XK(1)+RJ*XK(2))
          DO 90 M=1,ND1
            IATOM1=IATMPT(M)
            M1=M+1
            DO 80 N=M1,NDIM
C
C Inclusion of distance dependent Hij.
C 15.05.92/mbs
C
              IF (FDIST) THEN
                IATOM2=IATMPT(N)
                ORBSUM=D0(M)+D0(N)

                DELX=X(IATOM1)-X(IATOM2)+ADD(1)
                DELY=Y(IATOM1)-Y(IATOM2)+ADD(2)
                DELZ=Z(IATOM1)-Z(IATOM2)+ADD(3)
                RTU=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)
                DELX=X(IATOM2)-X(IATOM1)+ADD(1)
                DELY=Y(IATOM2)-Y(IATOM1)+ADD(2)
                DELZ=Z(IATOM2)-Z(IATOM1)+ADD(3)
                RUT=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)

                RDIF=RTU-ORBSUM
                DELTA=ADELTA(IATOM1,IATOM2)
                RD2=(RDIF-DABS(RDIF))*DELTA
                EXPTU=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)
                RDIF=RUT-ORBSUM
                DELTA=ADELTA(IATOM2,IATOM1)
                RD2=(RDIF-DABS(RDIF))*DELTA
                EXPUT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)

                STU=0.5D0*(A(N,M)-A(M,N))
                SUT=STU+A(M,N)
                SPLUS =STU*EXPTU+SUT*EXPUT
                SMINUS=STU*EXPTU-SUT*EXPUT
                SEXP(N,M)=SEXP(N,M)+DC*SPLUS
                SEXP(M,N)=SEXP(M,N)+DS*SMINUS
                DKSEXP(N,M)=-DC*SMINUS
                DKSEXP(M,N)=-DS*SPLUS
              ENDIF
              B(N,M)=B(N,M)+DC*A(N,M)
              B(M,N)=B(M,N)-DS*A(M,N)
              C(N,M)=DC*A(M,N)
              C(M,N)=-DS*A(N,M)
   80       CONTINUE
C
C Inclusion of distance dependent Hij.
C 15.05.92/mbs
C
            IF (FDIST) THEN
              DELX=ADD(1)
              DELY=ADD(2)
              DELZ=ADD(3)
              R=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)

              RDIF=R-2.0D0*D0(M)
              DELTA=ADELTA(IATOM1,IATOM1)
              RD2=(RDIF-ABS(RDIF))*DELTA
              EXPFCT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)

              SEXP(M,M)=SEXP(M,M)+DC*A(M,M)*EXPFCT
              DKSEXP(M,M)=-DS*A(M,M)*EXPFCT
            ENDIF
            B(M,M)=B(M,M)+DC*A(M,M)
            C(M,M)=-DS*A(M,M)
   90     CONTINUE
C
C Inclusion of distance dependent Hij. 
C 15.05.92/mbs
C
          IF (FDIST) THEN
            IF (NDIM .EQ. 1) THEN
              DELX=ADD(1)
              DELY=ADD(2)
              DELZ=ADD(3)
              R=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)
            ENDIF
            IATOM1=IATMPT(NDIM)

            RDIF=R-2.0D0*D0(NDIM)
            DELTA=ADELTA(IATOM1,IATOM1)
            RD2=(RDIF-DABS(RDIF))*DELTA
            EXPFCT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)
            
            SEXP(NDIM,NDIM)=SEXP(NDIM,NDIM)+DC*A(NDIM,NDIM)*EXPFCT
            DKSEXP(NDIM,NDIM)=-DS*A(NDIM,NDIM)*EXPFCT
          ENDIF
          B(NDIM,NDIM)=B(NDIM,NDIM)+DC*A(NDIM,NDIM)
          C(NDIM,NDIM)=-DS*A(NDIM,NDIM)

          IF (NGRAD .GT. 0) THEN
            DO 110 M=1,NDIM
              DO 100 N=1,NDIM
                A(M,N)=XMULTI*C(M,N)
  100         CONTINUE
  110       CONTINUE
            WRITE(13) A
            IF (FDIST) THEN
              DO 117 M=1,NDIM
                DO 115 N=1,NDIM
                  A(M,N)=XMULTI*DKSEXP(M,N)
  115           CONTINUE
  117         CONTINUE
              WRITE(13) A
            ENDIF
            DO 125 M=1,NDIM
              DO 120 N=1,NDIM
                A(M,N)=XMULTJ*C(M,N)
  120         CONTINUE
  125       CONTINUE
            WRITE(13) A
            IF (FDIST) THEN
              DO 135 M=1,NDIM
                DO 130 N=1,NDIM
                  A(M,N)=XMULTJ*DKSEXP(M,N)
  130           CONTINUE
  135         CONTINUE
              WRITE(13) A
            ENDIF
          ENDIF
  140   CONTINUE
  150 CONTINUE

      DO 230 I=2,NCEL11
        RI=DBLE(I-1)
        XMULTI=TWOPI*RI
        DO 220 J=1,NCEL2
          RJ=-DBLE(J)
          XMULTJ=TWOPI*RJ
          IF (FDIST) THEN
            DO 155 K=1,3
              ADD(K)=RI*DIST(1,K)+RJ*DIST(2,K)
  155       CONTINUE
          ENDIF
          READ(21) A
          DC=DCOS(RI*XK(1)+RJ*XK(2))
          DS=DSIN(RI*XK(1)+RJ*XK(2))
          DO 170 M=1,ND1
            IATOM1=IATMPT(M)
            M1=M+1
            DO 160 N=M1,NDIM
C
C Inclusion of distance dependent Hij.
C 15.05.92/mbs
C
              IF (FDIST) THEN
                IATOM2=IATMPT(N)
                ORBSUM=D0(M)+D0(N)

                DELX=X(IATOM1)-X(IATOM2)+ADD(1)
                DELY=Y(IATOM1)-Y(IATOM2)+ADD(2)
                DELZ=Z(IATOM1)-Z(IATOM2)+ADD(3)
                RTU=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)
                DELX=X(IATOM2)-X(IATOM1)+ADD(1)
                DELY=Y(IATOM2)-Y(IATOM1)+ADD(2)
                DELZ=Z(IATOM2)-Z(IATOM1)+ADD(3)
                RUT=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)

                RDIF=RTU-ORBSUM
                DELTA=ADELTA(IATOM1,IATOM2)
                RD2=(RDIF-DABS(RDIF))*DELTA
                EXPTU=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)
                RDIF=RUT-ORBSUM
                DELTA=ADELTA(IATOM2,IATOM1)
                RD2=(RDIF-DABS(RDIF))*DELTA
                EXPUT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)

                STU=0.5D0*(A(N,M)-A(M,N))
                SUT=STU+A(M,N)
                SPLUS =STU*EXPTU+SUT*EXPUT
                SMINUS=STU*EXPTU-SUT*EXPUT
                SEXP(N,M)=SEXP(N,M)+DC*SPLUS
                SEXP(M,N)=SEXP(M,N)+DS*SMINUS
                DKSEXP(N,M)=-DC*SMINUS
                DKSEXP(M,N)=-DS*SPLUS
              ENDIF
              B(N,M)=B(N,M)+DC*A(N,M)
              B(M,N)=B(M,N)-DS*A(M,N)
              C(N,M)=DC*A(M,N)
              C(M,N)=-DS*A(N,M)
  160       CONTINUE
C
C Inclusion of distance dependent Hij.
C 15.05.92/mbs
C
            IF (FDIST) THEN
              DELX=ADD(1)
              DELY=ADD(2)
              DELZ=ADD(3)
              R=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)

              RDIF=R-2.0D0*D0(M)
              DELTA=ADELTA(IATOM1,IATOM1)
              RD2=(RDIF-DABS(RDIF))*DELTA
              EXPFCT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)

              SEXP(M,M)=SEXP(M,M)+DC*A(M,M)*EXPFCT
              DKSEXP(M,M)=-DS*A(M,M)*EXPFCT
            ENDIF
            B(M,M)=B(M,M)+DC*A(M,M)
            C(M,M)=-DS*A(M,M)
  170     CONTINUE
C
C Inclusion of distance dependent Hij. 
C 15.05.92/mbs
C
          IF (FDIST) THEN
            IF (NDIM .EQ. 1) THEN
              DELX=ADD(1)
              DELY=ADD(2)
              DELZ=ADD(3)
              R=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)
            ENDIF
            IATOM1=IATMPT(NDIM)

            RDIF=R-2.0D0*D0(NDIM)
            DELTA=ADELTA(IATOM1,IATOM1)
            RD2=(RDIF-DABS(RDIF))*DELTA
            EXPFCT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)

            SEXP(NDIM,NDIM)=SEXP(NDIM,NDIM)+DC*A(NDIM,NDIM)*EXPFCT
            DKSEXP(NDIM,NDIM)=-DS*A(NDIM,NDIM)*EXPFCT
          ENDIF
          B(NDIM,NDIM)=B(NDIM,NDIM)+DC*A(NDIM,NDIM)
          C(NDIM,NDIM)=-DS*A(NDIM,NDIM)

          IF (NGRAD .GT. 0) THEN
            DO 190 M=1,NDIM
              DO 180 N=1,NDIM
                A(M,N)=XMULTI*C(M,N)
  180         CONTINUE
  190       CONTINUE
            WRITE(13) A
            IF (FDIST) THEN
              DO 197 M=1,NDIM
                DO 195 N=1,NDIM
                  A(M,N)=XMULTI*DKSEXP(M,N)
  195           CONTINUE
  197         CONTINUE
              WRITE(13) A
            ENDIF
            DO 205 M=1,NDIM
              DO 200 N=1,NDIM
                A(M,N)=XMULTJ*C(M,N)
  200         CONTINUE
  205       CONTINUE
            WRITE(13) A
            IF (FDIST) THEN
              DO 215 M=1,NDIM
                DO 210 N=1,NDIM
                  A(M,N)=XMULTJ*DKSEXP(M,N)
  210           CONTINUE
  215         CONTINUE
              WRITE(13) A
            ENDIF
          ENDIF
  220   CONTINUE
  230 CONTINUE

      IF (NCRYST .EQ. 2) GOTO 350
C
C 3D system:
C
      NEIBR1=2*NCEL1+1
      NEIBR2=2*NCEL2+1
      DO 340 K=1,NCEL3
        RK=DBLE(K)
        XMULTK=TWOPI*RK
        NI=-NCEL1-1
        DO 330 I=1,NEIBR1
          NI=NI+1
          RI=DBLE(NI)
          XMULTI=TWOPI*RI
          NJ=-NCEL2-1
          DO 320 J=1,NEIBR2
            NJ=NJ+1
            RJ=DBLE(NJ)
            IF (FDIST) THEN
              DO 235 L=1,3
                ADD(L)=RI*DIST(1,L)+RJ*DIST(2,L)+RK*DIST(3,L)
  235         CONTINUE
            ENDIF
            XMULTJ=TWOPI*RJ
            READ(21) A
            DC=DCOS(RI*XK(1)+RJ*XK(2)+RK*XK(3))
            DS=DSIN(RI*XK(1)+RJ*XK(2)+RK*XK(3))
            DO 250 M=1,ND1
              IATOM1=IATMPT(M)
              M1=M+1
              DO 240 N=M1,NDIM
C
C Inclusion of distance dependent Hij.
C 15.05.92/mbs
C
                IF (FDIST) THEN
                  IATOM2=IATMPT(N)
                  ORBSUM=D0(M)+D0(N)

                  DELX=X(IATOM1)-X(IATOM2)+ADD(1)
                  DELY=Y(IATOM1)-Y(IATOM2)+ADD(2)
                  DELZ=Z(IATOM1)-Z(IATOM2)+ADD(3)
                  RTU=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)
                  DELX=X(IATOM2)-X(IATOM1)+ADD(1)
                  DELY=Y(IATOM2)-Y(IATOM1)+ADD(2)
                  DELZ=Z(IATOM2)-Z(IATOM1)+ADD(3)
                  RUT=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)

                  RDIF=RTU-ORBSUM
                  DELTA=ADELTA(IATOM1,IATOM2)
                  RD2=(RDIF-DABS(RDIF))*DELTA
                  EXPTU=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)
                  RDIF=RUT-ORBSUM
                  DELTA=ADELTA(IATOM2,IATOM1)
                  RD2=(RDIF-DABS(RDIF))*DELTA
                  EXPUT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)

                  STU=0.5D0*(A(N,M)-A(M,N))
                  SUT=STU+A(M,N)
                  SPLUS =STU*EXPTU+SUT*EXPUT
                  SMINUS=STU*EXPTU-SUT*EXPUT
                  SEXP(N,M)=SEXP(N,M)+DC*SPLUS
                  SEXP(M,N)=SEXP(M,N)+DS*SMINUS
                  DKSEXP(N,M)=-DC*SMINUS
                  DKSEXP(M,N)=-DS*SPLUS
                ENDIF
                B(N,M)=B(N,M)+DC*A(N,M)
                B(M,N)=B(M,N)-DS*A(M,N)
                C(N,M)=DC*A(M,N)
                C(M,N)=-DS*A(N,M)
  240         CONTINUE
C
C Inclusion of distance dependent Hij.
C 15.05.92/mbs
C
              IF (FDIST) THEN
                DELX=ADD(1)
                DELY=ADD(2)
                DELZ=ADD(3)
                R=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)

                RDIF=R-2.0D0*D0(M)
                DELTA=ADELTA(IATOM1,IATOM1)
                RD2=(RDIF-DABS(RDIF))*DELTA
                EXPFCT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)

                SEXP(M,M)=SEXP(M,M)+DC*A(M,M)*EXPFCT
                DKSEXP(M,M)=-DS*A(M,M)*EXPFCT
              ENDIF
              B(M,M)=B(M,M)+DC*A(M,M)
              C(M,M)=-DS*A(M,M)
  250       CONTINUE
C
C Inclusion of distance dependent Hij. 
C 15.05.92/mbs
C
            IF (FDIST) THEN
              IF (NDIM .EQ. 1) THEN
                DELX=ADD(1)
                DELY=ADD(2)
                DELZ=ADD(3)
                R=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)
              ENDIF
              IATOM1=IATMPT(NDIM)

              RDIF=R-2.0D0*D0(NDIM)
              DELTA=ADELTA(IATOM1,IATOM1)
              RD2=(RDIF-DABS(RDIF))*DELTA
              EXPFCT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)

              SEXP(NDIM,NDIM)=SEXP(NDIM,NDIM)+DC*A(NDIM,NDIM)*EXPFCT
              DKSEXP(NDIM,NDIM)=-DS*A(NDIM,NDIM)*EXPFCT
            ENDIF
            B(NDIM,NDIM)=B(NDIM,NDIM)+DC*A(NDIM,NDIM)
            C(NDIM,NDIM)=-DS*A(NDIM,NDIM)

            IF (NGRAD .GT. 0) THEN
              DO 270 M=1,NDIM
                DO 260 N=1,NDIM
                  A(M,N)=XMULTK*C(M,N)
  260           CONTINUE
  270         CONTINUE
              WRITE(13) A
              IF (FDIST) THEN
                DO 277 M=1,NDIM
                  DO 275 N=1,NDIM
                    A(M,N)=XMULTK*DKSEXP(M,N)
  275             CONTINUE
  277           CONTINUE
                WRITE(13) A
              ENDIF

              DO 290 M=1,NDIM
                DO 280 N=1,NDIM
                  A(M,N)=XMULTI*C(M,N)
  280           CONTINUE
  290         CONTINUE
              WRITE(13) A
              IF (FDIST) THEN
                DO 297 M=1,NDIM
                  DO 295 N=1,NDIM
                    A(M,N)=XMULTI*DKSEXP(M,N)
  295             CONTINUE
  297           CONTINUE
                WRITE(13) A
              ENDIF

              DO 310 M=1,NDIM
                DO 300 N=1,NDIM
                  A(M,N)=XMULTJ*C(M,N)
  300           CONTINUE
  310         CONTINUE
              WRITE(13) A
              IF (FDIST) THEN
                DO 317 M=1,NDIM
                  DO 315 N=1,NDIM
                    A(M,N)=XMULTJ*DKSEXP(M,N)
  315             CONTINUE
  317           CONTINUE
                WRITE(13) A
              ENDIF
            ENDIF
  320     CONTINUE
  330   CONTINUE
  340 CONTINUE

C
C unit cell elements
C
  350 REWIND 21
      READ(21) (SORB(I),I=1,INATOM),A
      DO 370 I=1,NDIM
        IATOM1=IATMPT(I)
        DO 360 J=1,I

C Inclusion of distance dependent Hij.
C 15.05.92/mbs
C
          IF (FDIST .AND. (I .NE. J)) THEN
            IATOM2=IATMPT(J)
            ORBSUM=D0(I)+D0(J)
            DELX=X(IATOM1)-X(IATOM2)
            DELY=Y(IATOM1)-Y(IATOM2)
            DELZ=Z(IATOM1)-Z(IATOM2)
            R=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)

            RDIF=R-ORBSUM
            DELTA=ADELTA(IATOM1,IATOM2)
            RD2=(RDIF-DABS(RDIF))*DELTA
            EXPFCT=DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)

            SEXP(I,J)=SEXP(I,J)+A(I,J)*EXPFCT
          ENDIF
          B(I,J)=B(I,J)+A(I,J)
  360   CONTINUE
  370 CONTINUE
      REWIND 21

      RETURN
      END