C ********************************************************************
C * EHMACC - Extended Hueckel Molecular and Crystal Calculations     *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  CTRED2                                                          *
C *                                                                  *
C *  Routine of EHMACC                                               *
C *                                                                  *
C *  Usage......: Reduces given complex hermitian matrix to a tri-   *
C *               diagonal form.                                     *
C *                                                                  *
C *               Parameters                                         *
C *                                                                  *
C *               n    --- order of the matrix                       *
C *               nd   --- dimension of arrays a and b               *
C *               a    --- given matrix, replaced by real part       *
C *                        of the transformation matrix              *
C *               b    --- imag part of transformation matrix        *
C *               d    --- diagonal part of the triadiagonal matrix  *
C *               e    --- real part of the codiagonal of the        *
C *                        tridiagonal matrix                        *
C *                        (last n-1 locations)                      *
C *               f    --- imag parts of the lower codiagonal.       *
C                                                                    *
C *               the given matrix should be stored in the           *
C *               following way                                      *
C *                                                                  *
C *                    --- diagonal elements in the diagonal         *
C *                    --- real part of the lower triangle in the    *
C *                        lower triangle                            *
C *                    --- imag parts of the lower triangle          *
C *                        in the upper triangle                     *
C *                                                                  *
C *  Author.....: s. CBORIS                                          *
C *  Date.......: 20.06.1974                                         *
C *  Revision...: -                                                  *
C *  Remarks....: -                                                  *
C *                                                                  *
C *  Called from: CBORIS                                             *
C *                                                                  *
C *  Calls......: -                                                  *
C *                                                                  *
C ********************************************************************

      SUBROUTINE CTRED2(N,ND,A,B,D,E,F)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      DIMENSION A(ND,ND),B(ND,ND),D(ND),E(ND),F(ND)

      D(1)=A(1,1)
      IF (N .EQ. 1) GOTO 120
C
C main k loop
C
      DO 110 K=2,N
        L=K-1
C
C     compute norm
C
        ALL=0.
        DO 10 I=K,N
   10   ALL=ALL+A(I,L)*A(I,L)+A(L,I)*A(L,I)
        ALL=DSQRT(ALL)
C
C     compute constants
C
        C=1.0
        S=0.0
        R=DSQRT(A(K,L)*A(K,L)+A(L,K)*A(L,K))
        IF (DABS(R) .LT. 1.0D-37) R=0.0
        IF (R .EQ. 0.0) GOTO 20
        C=A(K,L)/R
        S=A(L,K)/R
   20   ALR=ALL*C
        ALI=ALL*S
        A(L,L)=0.0
C
C     test for superfluous transformation
C
        SM=ALL*(ALL+R)
        IF (DABS(SM) .LT. 1.0D-37) SM=0.0
        IF (SM .EQ. 0.0) GOTO 100
        G=1.0/SM
        A(L,L)=G

        A(K,L)=A(K,L)+ALR
        A(L,K)=A(L,K)+ALI
C
C     now compute u=a*w
C     and store into (e,f)
C
        T=0.0
        DO 70 I=K,N
          C=A(I,I)*A(I,L)
          S=A(I,I)*A(L,I)
          IF (I .EQ. K) GOTO 40
          IA=I-1
          DO 30 J=K,IA
            C=C+A(I,J)*A(J,L)-A(J,I)*A(L,J)
   30     S=S+A(I,J)*A(L,J)+A(J,I)*A(J,L)
   40     IF (I .EQ. N) GOTO 60
          IA=I+1
          DO 50 J=IA,N
            C=C+A(J,I)*A(J,L)+A(I,J)*A(L,J)
   50     S=S+A(J,I)*A(L,J)-A(I,J)*A(J,L)
   60     E(I)=G*C
          F(I)=G*S
   70   T=T+A(I,L)*C+A(L,I)*S
        T=T*G*G
C
C    transform  matrix
C
        DO 90 I=K,N
          A(I,I)=A(I,I)-2.0*(A(I,L)*E(I)+A(L,I)*F(I))+T*(A(I,L)*
     .              A(I,L)+A(L,I)*A(L,I))
          IF (I .EQ. K) GOTO 90
          IA=I-1
          DO 80 J=K,IA
            A(I,J)=A(I,J)-A(I,L)*E(J)-A(L,I)*F(J)-A(J,L)*E(I) -
     .                 A(L,J)*F(I)+T*(A(I,L)*A(J,L)+A(L,I)*A(L,J))
            A(J,I)=A(J,I)-A(L,I)*E(J)+A(I,L)*F(J)+A(L,J)*E(I) -
     .                 A(J,L)*F(I)+T*(A(L,I)*A(J,L)-A(I,L)*A(L,J))
   80     CONTINUE
   90   CONTINUE
C
C     store diagonal and codiagonal elements
C
  100   D(K)=A(K,K)
        E(K)=-ALR
        F(K)=-ALI
  110 CONTINUE
C
C     now accumulate transformations
C
  120 A(N,N)=1.0
      B(N,N)=0.0
      IF (N .EQ. 1) RETURN 
      DO 180 KK=2,N
        K=N-KK+2
        L=K-1
C
C     skip transformation if unit
C
        IF (DABS(A(L,L)) .LT. 1.0D-37) A(L,L)=0.0
        IF (A(L,L) .EQ. 0.0) GOTO 160
C
C     compute product
C
        DO 150 J=K,N
          C=0.0
          S=0.0
          DO 130 I=K,N
            C=C+A(I,L)*A(I,J)+A(L,I)*B(I,J)
  130     S=S+A(I,L)*B(I,J)-A(L,I)*A(I,J)
          C=C*A(L,L)
          S=S*A(L,L)
          DO 140 I=K,N
            A(I,J)=A(I,J)-C*A(I,L)+S*A(L,I)
  140     B(I,J)=B(I,J)-C*A(L,I)-S*A(I,L)
  150   CONTINUE
C
C     make new line
C
  160   DO 170 I=K,N
          A(I,L)=0.0
          A(L,I)=0.0
          B(I,L)=0.0
  170   B(L,I)=0.0
        A(L,L)=1.0
        B(L,L)=0.0
  180 CONTINUE
      RETURN
      END
