C ********************************************************************
C * EHMACC - Extended Hueckel Molecular and Crystal Calculations     *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  ETOT                                                            *
C *                                                                  *
C *  Routine of EHMACC                                               *
C *                                                                  *
C *  Usage......: Integrates total electronic energy EEHMO up to     *
C *               Fermi level and calculates total energy Etot.      *
C *                                                                  *
C *  Author.....: Martin Braendle (mbs)                              *
C *  Available..: Calzaferri group, Institute f. Inorg. + Phys.      *
C *               Chemistry, University of Berne, Freiestr. 3,       *
C *               CH-3012 Berne, Switzerland                         *
C *  Date.......: 24.08.94                                           *
C *  Revision...: 14.11.94/mbs                                       *
C *  Remarks....: Some parts copied from routines of EHPC.           *
C *                                                                  *
C *  Called from: CRYST                                              *
C *                                                                  *
C *  Calls......: -                                                  *
C *                                                                  *
C ********************************************************************
 
      SUBROUTINE ETOT(EAOORB,EREP,NKP,NDIM)
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
 
      INCLUDE 'sizes'
 
      DIMENSION CWRITE(NVARMX)
 
      COMMON /ATOM2/EXPS(NSYMMX,NAEQMX),EXPS2(NSYMMX,NAEQMX),
     .              EXPP(NSYMMX),EXPP2(NSYMMX),
     .              EXPD(NSYMMX),EXPD2(NSYMMX),
     .              EXPF(NSYMMX),EXPF2(NSYMMX),
     .              CS1(NSYMMX,NAEQMX),CS2(NSYMMX,NAEQMX),
     .              CP1(NSYMMX),CP2(NSYMMX),CD1(NSYMMX),CD2(NSYMMX),
     .              CF1(NSYMMX),CF2(NSYMMX),COULS(NSYMMX,NAEQMX),
     .              COULP(NSYMMX),COULD(NSYMMX),COULF(NSYMMX),
     .              C(NATMMX,3)
      COMMON /FRACTC/FC(NATMMX,3)
      COMMON /INTEGR/W(NDKMX),ENDK(NDKMX),D(NDIMMX),ID(NDKMX),IT(NDKMX),
     .               IACC(NKMAX,NSTPMX)
      COMMON /IOUNIT/IIN,IOUT,ISTART(40)
 
      COMMON /KEYWRD/KEYWRD,SLINE
      CHARACTER KEYWRD*320,SLINE*80
 
      COMMON /LATCON/ALAT,BLAT,CLAT,ALPLAT,BETLAT,GAMLAT
      COMMON /OPTV/RHO,FERMI,WSTART,WEND,DISTL,LB,LE,LBR,LER,IOVLB,
     .             IOVLE,ICHARG,NELEC,IDISTN,IEB,IEE,ISB,ISE,IHB,IHE,
     .             IPOPE,JPOPE,IREST,IRESTV
 
      COMMON /VARGEO/VARINC(NVARMX),IVRLIN(NVARMX),ISTPMX(NVARMX),
     .               IVARTP(NVARMX),ISTEPS(NVARMX),IVARY,NVARY,
     .               NVARLN,NNCPL,LCOUPL(NVARMX+1)
      LOGICAL LCOUPL
 
      COMMON /ZMAT/BL(NATMMX),ALPH(NATMMX),BET(NATMMX),IZ(NATMMX,3),NZ
 
C
C Meaning of variables:
C ENDK: Energy levels of all k-points, ordered in one-dimensional array.
C ID:   Pointer to energy levels, sorted.
C W:    Weigths of all energy levels of all k-points, ordered in one-
C       dimensional array.
C IT:   Temporary array.
C D:    Temporary buffer for energies.
C IACC:
 
      NDK=NDIM*NKP
C
C Read energies.
C
      REWIND 20
      DO 20 I=1,NKP
        READ(20) WEIGHT
        DO 10 J=1,NDIM
          READ(20) D(J)
          LOC=J+(I-1)*NDIM
          ENDK(LOC)=D(J)
          W(LOC)=WEIGHT
          ID(LOC)=LOC
10      CONTINUE
20    CONTINUE
C
C Sort energies.
C
      DO 100 IROW=1,NDIM
        DO 90 ICOL=1,NKP
          LOC1=(ICOL-1)*NDIM+IROW
          ID1=ID(LOC1)
          ICOLP1=ICOL+1
          ICOLM1=ICOL-1
          DO 50 JA=ICOLP1,NKP
            DO 40 LA=IROW,NDIM
              LOC2=(JA-1)*NDIM+LA
              ID2=ID(LOC2)
              IF (ENDK(ID2) .GT. ENDK(ID1)) GOTO 50
              ID(LOC2)=ID1
              ID(LOC1)=ID2
              ID1=ID2
              DO 30 K=LA,NDIM-1
                LC1=(JA-1)*NDIM+K
                LC2=LC1+1
                IDD1=ID(LC1)
                IDD2=ID(LC2)
                IF (ENDK(IDD2) .LT. ENDK(IDD1)) THEN
                  ID(LC2)=IDD1
                  ID(LC1)=IDD2
                ENDIF
   30         CONTINUE
   40       CONTINUE
   50     CONTINUE
 
          IF (IROW .LT. NDIM) THEN
            DO 80 JB=1,ICOLM1
              DO 70 LB1=IROW+1,NDIM
                LOC2=(JB-1)*NDIM+LB1
                ID2=ID(LOC2)
                IF (ENDK(ID2) .GT. ENDK(ID1)) GO TO 80
                ID(LOC2)=ID1
                ID(LOC1)=ID2
                ID1=ID2
                DO 60 K=LB1,NDIM-1
                  LC1=(JB-1)*NDIM+K
                  LC2=LC1+1
                  IDD1=ID(LC1)
                  IDD2=ID(LC2)
                  IF (ENDK(IDD2) .LT. ENDK(IDD1)) THEN
                    ID(LC2)=IDD1
                    ID(LC1)=IDD2
                  ENDIF
   60           CONTINUE
   70         CONTINUE
   80       CONTINUE
          ENDIF
 
   90   CONTINUE
  100 CONTINUE
 
      IORD=1
      WRITE(1,110) IORD
  110 FORMAT(I2)
 
      NUM=0
      DO 130 I=1,NDIM
        DO 120 J=1,NKP
          LOC=(J-1)*NDIM+I
          NUM=NUM+1
          IT(NUM)=ID(LOC)
  120   CONTINUE
  130 CONTINUE
 
      DO 150 I=1,NDK
        ID(I)=IT(I)
        WRITE(1,140) ID(I)
  140   FORMAT(I6)
  150 CONTINUE
 
C
C Integrate up to Fermi level.
C
C Number of steps.
C
      NSTEP=INT((DBLE(NELEC-1)+0.01D0)/PSTEP)+1
      DO 170 I=1,NKP
        DO 160 J=1,NSTEP
          IACC(I,J)=0
  160   CONTINUE
  170 CONTINUE
C
C Integration.
C
      IFER=1
      DO 200 IRUN=1,NSTEP
        XFERMI=1.0D0+DBLE(IRUN-1)*PSTEP+1.0D-8
        IF (IRUN .EQ. 1) THEN
          ELEC1=0.0D0
          EEHMO1=0.0D0
        ELSE
          ELEC1=ELEC0
          EEHMO1=EEHMO0
        ENDIF
 
        IF=IFER
        DO 180 I=IF,NDK
          IPOIN1=ID(I)
          IOKP=(IPOIN1-1)/NDIM+1
          IACC(IOKP,IRUN)=IACC(IOKP,IRUN)+1
          WID=W(IPOIN1)*2.0D0
 
          ELEC1=ELEC1+WID
          EEHMO1=EEHMO1+WID*ENDK(IPOIN1)
 
          IF (ELEC1 .GT. XFERMI) THEN
            EFRMI1=ENDK(IPOIN1)
            IF (I .GT. 1) THEN
              IPOIN0=ID(I-1)
              EFRMI0=ENDK(IPOIN0)
              IACC(IOKP,IRUN)=IACC(IOKP,IRUN)-1
            ELSE
              EFRMI0=0.0D0
            ENDIF
            IFER=I
            GOTO 190
          ENDIF
  180   CONTINUE
 
  190   ELEC0=ELEC1-WID
        EEHMO0=EEHMO1-WID*ENDK(IPOIN1)
  200 CONTINUE
C
C Interpolate fermi level and total electronic energy.
C
      EFERMI=EFRMI0+(EFRMI1-EFRMI0)*(DBLE(NELEC)-ELEC0)/(ELEC1-ELEC0)
      EEHMO=EEHMO0+(EEHMO1-EEHMO0)*(DBLE(NELEC)-ELEC0)/(ELEC1-ELEC0)
 
      DEEHMO=EEHMO-EAOORB
      TOTE=DEEHMO+EREP
C
C Write energies.
C
      WRITE(IOUT,210) NELEC,EEHMO
  210 FORMAT(2X,'EEHMO integrated for ',I4,' electrons      = ',F12.5)
      WRITE(IOUT,220) DEEHMO
  220 FORMAT(2X,'Stabilization energy                     = ',F12.5)
      WRITE(IOUT,230) TOTE
  230 FORMAT(2X,'Total energy = stabilization + repulsion = ',F12.5)
      WRITE(IOUT,240) NELEC,EFERMI
  240 FORMAT(/,2X,'Fermi level for ',I4,' electrons           = ',F12.5)
C
C Write coordinates and energies.
C
      IWRITE=0
      DO 250 I=1,NVARLN
        IF (.NOT. LCOUPL(I)) THEN
          ITYPE=IVARTP(I)
          ILINE=IVRLIN(I)
          IWRITE=IWRITE+1
          IF (INDEX(KEYWRD,'ZMAT') .GT. 0) THEN
            IF (ITYPE .EQ. 1) THEN
              CWRITE(IWRITE)=BL(ILINE)
            ELSE IF (ITYPE .EQ. 2) THEN
              CWRITE(IWRITE)=ALPH(ILINE)
            ELSE
              CWRITE(IWRITE)=BET(ILINE)
            ENDIF
          ELSE IF (INDEX(KEYWRD,'XYZ') .GT. 0) THEN
            CWRITE(IWRITE)=C(ILINE,ITYPE)
          ELSE
            IF (ILINE .GT. 0) THEN
              CWRITE(IWRITE)=FC(ILINE,ITYPE)
            ELSE
              IF (ITYPE .EQ. 4) THEN
                CWRITE(IWRITE)=ALAT
              ELSE IF (ITYPE .EQ. 5) THEN
                CWRITE(IWRITE)=BLAT
              ELSE IF (ITYPE .EQ. 6) THEN
                CWRITE(IWRITE)=CLAT
              ELSE IF (ITYPE .EQ. 7) THEN
                CWRITE(IWRITE)=ALPLAT
              ELSE IF (ITYPE .EQ. 8) THEN
                CWRITE(IWRITE)=BETLAT
              ELSE IF (ITYPE .EQ. 9) THEN
                CWRITE(IWRITE)=GAMLAT
              ELSE
              ENDIF
            ENDIF  
          ENDIF
        ENDIF
  250 CONTINUE
 
      WRITE(15,260) (CWRITE(I),I=1,IWRITE),EEHMO,DEEHMO,EREP,TOTE,EFERMI
  260 FORMAT(20F12.5)
 
      RETURN
      END