C ********************************************************************
C * EHMACC - Extended Hueckel Molecular and Crystal Calculations     *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  GAOOCC                                                          *
C *                                                                  *
C *  Routine of EHMACC                                               *
C *                                                                  *
C *  Usage......: Returns atomic occupation numbers AOOCC (COMMON    *
C *               block AELCON).                                     *
C *                                                                  *
C *  Author.....: Martin Braendle (mbs) c/o                          *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Institute for anorg. + phys. Chemistry             *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: 10.06.92                                           *
C *  Revision...: -                                                  *
C *  Remarks....: -                                                  *
C *                                                                  *
C *  Called from: PARAM                                              *
C *                                                                  *
C *  Calls......: WRITEL                                             *
C *                                                                  *
C ********************************************************************

      SUBROUTINE GAOOCC

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      INCLUDE 'sizes'

      DIMENSION SORT(4),ISORT(4),IPOINT(4)
      INTEGER   DEFELC(4,103)

      COMMON /ATOM1/NS(NSYMMX,NAEQMX),NP(NSYMMX),ND(NSYMMX),NF(NSYMMX),
     .              INATOM, ISYM(NATMMX),NELEM
      COMMON /ATOM2/EXPS(NSYMMX,NAEQMX),EXPS2(NSYMMX,NAEQMX),
     .              EXPP(NSYMMX),EXPP2(NSYMMX),
     .              EXPD(NSYMMX),EXPD2(NSYMMX),
     .              EXPF(NSYMMX),EXPF2(NSYMMX),
     .              CS1(NSYMMX,NAEQMX),CS2(NSYMMX,NAEQMX),
     .              CP1(NSYMMX),CP2(NSYMMX),CD1(NSYMMX),CD2(NSYMMX),
     .              CF1(NSYMMX),CF2(NSYMMX),COULS(NSYMMX,NAEQMX),
     .              COULP(NSYMMX),COULD(NSYMMX),COULF(NSYMMX),
     .              X(NATMMX),Y(NATMMX),Z(NATMMX)

      COMMON /BDATA1/IVELD(103)

      COMMON /AELCON/AOOCC(NATMMX,4),USECON(NATMMX)
      LOGICAL USECON

      COMMON /ATO/AC(NATMMX),SYMBOL(NSYMMX)
      CHARACTER AC*7,SYMBOL*2

      COMMON /AVELEC/ZCORE(NATMMX),USECOR(NATMMX)
      LOGICAL USECOR

      COMMON /BDATA2/SYMBD(103)
      CHARACTER SYMBD*2

      COMMON /KEYWRD/KEYWRD,SLINE
      CHARACTER KEYWRD*320,SLINE*80

C
C Period 1
C                 H         He
      DATA DEFELC/1,0,0,0,  2,0,0,0,
C
C Period 2
C                 Li        Be        B         C         N
     .            1,0,0,0,  2,0,0,0,  2,1,0,0,  2,2,0,0,  2,3,0,0,
C                 O         F         Ne
     .            2,4,0,0,  2,5,0,0,  2,6,0,0,
C
C Period 3
C                 Na        Mg        Al        Si        P
     .            1,0,0,0,  2,0,0,0,  2,1,0,0,  2,2,0,0,  2,3,0,0,
C                 S         Cl        Ar
     .            2,4,0,0,  2,5,0,0,  2,6,0,0,
C
C Period 4
C                 K         Ca        Sc        Ti        V
     .            1,0,0,0,  2,0,0,0,  2,0,1,0,  2,0,2,0,  2,0,3,0,
C                 Cr        Mn        Fe        Co        Ni
     .            1,0,5,0,  2,0,5,0,  2,0,6,0,  2,0,7,0,  2,0,8,0,
C                 Cu        Zn        Ga        Ge        As
     .            1,0,10,0, 2,0,10,0, 2,1,10,0, 2,2,10,0, 2,3,10,0,
C                 Se        Br        Kr
     .            2,4,10,0, 2,5,10,0, 2,6,10,0,
C
C Period 5
C                 Rb        Sr        Y         Zr        Nb
     .            1,0,0,0,  2,0,0,0,  2,0,1,0,  2,0,2,0,  1,0,4,0,
C                 Mo        Tc        Ru        Rh        Pd
     .            1,0,5,0,  1,0,6,0,  1,0,7,0,  1,0,8,0,  0,0,10,0,
C                 Ag        Cd        In        Sn        Sb
     .            1,0,10,0, 2,0,10,0, 2,1,10,0, 2,2,10,0, 2,3,10,0,
C                 Te        I         Xe
     .            2,4,10,0, 2,5,10,0, 2,6,10,0,
C
C Period 6
C                 Cs        Ba        La        Ce        Pr
     .            1,0,0,0,  2,0,0,0,  2,0,1,0,  2,0,0,2,  2,0,0,3,
C                 Nd        Pm        Sm        Eu        Gd
     .            2,0,0,4,  2,0,0,5,  2,0,0,6,  2,0,0,7,  2,0,1,7,
C                 Tb        Dy        Ho        Er        Tm
     .            2,0,0,9,  2,0,0,10, 2,0,0,11, 2,0,0,12, 2,0,0,13,
C                 Yb        Lu        Hf        Ta        W
     .            2,0,0,14, 2,0,1,14, 2,0,2,14, 2,0,3,14, 2,0,4,14,
C                 Re        Os        Ir        Pt        Au
     .            2,0,5,14, 2,0,6,14, 2,0,7,14, 1,0,9,14, 1,0,10,14,
C                 Hg        Tl        Pb        Bi        Po
     .            2,0,10,14,2,1,10,14,2,2,10,14,2,3,10,14,2,4,10,14,
C                 At        Rn
     .            2,5,10,14,2,6,10,14,
C
C Period 7
C                 Fr        Ra        Ac        Th        Pa
     .            1,0,0,0,  2,0,0,0,  2,0,1,0,  2,0,2,0,  2,0,1,2,
C                 U         Np        Pu        Am        Cm
     .            2,0,1,3,  2,0,1,4,  2,0,0,6,  2,0,0,7,  2,0,1,7,
C                 Bk        Cf        Es        Fm        Md
     .            2,0,0,9,  2,0,0,10, 2,0,0,11, 2,0,0,12, 2,0,0,13,
C                 No        Lr
     .            2,0,0,14, 2,0,1,14/

C
C Choose method of electron occupation.
C
      IF (INDEX(KEYWRD,'AUFBAU') .GT. 0) THEN
C
C Aufbau principle. Sort energy levels, lowest to highest, by bubble
C sorting technique.
C
        DO 60 I=1,INATOM
          KEYI=ISYM(I)
          DO 10 J=1,4
            AOOCC(I,J)=0.0D0
            SORT(J)=0.0D0
            ISORT(J)=4*J-2
            IPOINT(J)=J
10        CONTINUE
C
C We do NOT want to include the specialty of more than one orbital of the
C same kind (with different principal quantum number) in this place. We
C expect the orbital first specified in the ehi file (STO cards) to be
C occupied.
C 
          IF (NS(KEYI,1) .GT. 0) THEN
            SORT(1)=COULS(KEYI,1)
          ENDIF
          IF (NP(KEYI) .GT. 0) THEN
            SORT(2)=COULP(KEYI)
          ENDIF
          IF (ND(KEYI) .GT. 0) THEN
            SORT(3)=COULD(KEYI)
          ENDIF
          IF (NF(KEYI) .GT. 0) THEN
            SORT(4)=COULF(KEYI)
          ENDIF
          DO 30 J=1,3
            DO 20 K=J+1,4
              IF (SORT(J) .GT. SORT(K)) THEN
                TEMP=SORT(K)
                SORT(K)=SORT(J)
                SORT(J)=TEMP
                ITEMP=ISORT(K)
                ISORT(K)=ISORT(J)
                ISORT(J)=ITEMP
                ITEMP=IPOINT(K)
                IPOINT(K)=IPOINT(J)
                IPOINT(J)=ITEMP
              ENDIF
20          CONTINUE
30        CONTINUE
C
C Search element in order to get the number of valence electrons.
C
          JFOUND=0
          DO 40 J=1,103
            IF (SYMBD(J) .EQ. SYMBOL(KEYI)) THEN
              JFOUND=J
              GOTO 45
            ENDIF
40        CONTINUE
45        IF (JFOUND .EQ. 0) THEN
            SLINE=' Element '//SYMBOL(KEYI)//' not defined.'
            CALL WRITEL(SLINE)
            CALL CLEXIT
          ENDIF
          VELE=DBLE(IVELD(JFOUND))
C
C Occupy levels.
C
          DO 50 J=1,4
            IF (VELE .GT. 0.0D0) THEN
              AOOCC(I,IPOINT(J))=MAX(VELE,DBLE(ISORT(J)))
              VELE=VELE-AOOCC(I,IPOINT(J))
            ENDIF
50        CONTINUE
60      CONTINUE
      ELSE
C
C Use atomic electron configurations and user supplied electron confi-
C gurations.
C
        DO 90 I=1,INATOM
          IF (.NOT. USECON(I)) THEN
            KEYI=ISYM(I)
C
C Search element.
C
            DO 70 J=1,103
              IF (SYMBD(J) .EQ. SYMBOL(KEYI)) THEN
                JFOUND=J
                GOTO 75
              ENDIF
70          CONTINUE
75          IF (JFOUND .EQ. 0) THEN
              SLINE=' Electron configuration of '//SYMBOL(KEYI)//
     .              ' not defined.'
              CALL WRITEL(SLINE)
              CALL CLEXIT
            ENDIF
            DO 80 J=1,4
              AOOCC(I,J)=DBLE(DEFELC(J,JFOUND))
80          CONTINUE
          ENDIF
90      CONTINUE
      ENDIF
C
C Fill core charges for repulsion energy calculation.
C
      DO 110 I=1,INATOM
        IF (.NOT. USECOR(I)) THEN
          KEYI=ISYM(I)
          JFOUND=0
          DO 100 J=1,103
            IF (SYMBD(J) .EQ. SYMBOL(KEYI)) THEN
              JFOUND=J
              GOTO 105
            ENDIF
100       CONTINUE
105       IF (JFOUND .EQ. 0) THEN
            SLINE='Core charge: Element '//SYMBOL(KEYI)//' not defined.'
            CALL WRITEL(SLINE)
            CALL CLEXIT
          ENDIF
          ZCORE(I)=DBLE(IVELD(JFOUND))
        ENDIF
110   CONTINUE


      RETURN
      END
