C ********************************************************************
C * EHMACC - Extended Hueckel Molecular and Crystal Calculations     *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  GETKD                                                           *
C *                                                                  *
C *  Routine of EHMACC                                               *
C *                                                                  *
C *  Usage......: Sets up (kappa,delta) matrices for distance-depen- *
C *               dent weighted Wolfsberg-Helmholz approximation.    *
C *                                                                  *
C *  Author.....: Martin Braendle (mbs)                              *
C *  Available..: Calzaferri group, c/o Prof. G. Calzaferri, Inst.   *
C *               f. Inorg. and Phys. Chemistry, University of Berne,*
C *               Freiestr. 3, CH-3012 Berne                         *
C *  Date.......: 17.02.93                                           *
C *  Revision...: -                                                  *
C *  Remarks....: -                                                  *
C *                                                                  *
C *  Called from: PARAM                                              *
C *                                                                  *
C *  Calls......: READA,READL                                        *
C *                                                                  *
C ********************************************************************

      SUBROUTINE GETKD

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      INCLUDE 'sizes'  

      CHARACTER*7  ACC,ACI1,ACJ1          
      CHARACTER*80 STRING
      DIMENSION    DKAPPA(NATMMX),DDELTA(NATMMX)

      COMMON /ATOM1/NS(NSYMMX,NAEQMX),NP(NSYMMX),ND(NSYMMX),NF(NSYMMX),
     .              INATOM, ISYM(NATMMX),NELEM
      COMMON /DISTK/CKAPPA,CDELTA,AKAPPA(NATMMX,NATMMX),
     .              ADELTA(NATMMX,NATMMX)
      COMMON /IOUNIT/IIN,IOUT,ISTART(40)

      COMMON /ATO/AC(NATMMX),SYMBOL(NSYMMX)
      CHARACTER AC*7,SYMBOL*2
      
      COMMON /KEYWRD/KEYWRD,SLINE
      CHARACTER KEYWRD*320,SLINE*80

C
C Set up (kappa,delta) matrixes with default values
C

      DO 20 I=1,INATOM
        DKAPPA(I)=CKAPPA
        DDELTA(I)=CDELTA
        DO 10 J=1,INATOM
          AKAPPA(I,J)=CKAPPA
          ADELTA(I,J)=CDELTA
   10   CONTINUE
   20 CONTINUE

      IF (INDEX(KEYWRD,'KAPDEL1') .GT. 0) THEN
   30   IF (INDEX(SLINE,'KAPDEL') .EQ. 0) GOTO 90
C
C Get individual (kappa,delta) values
C
        BKAPPA=READA(SLINE,ISTART(2),80)  
        BDELTA=READA(SLINE,ISTART(3),80)
C
C Get name(s) of first atom
C
        IT=0
        CALL GETNAM(5,STRING,IT)
        ACI1=STRING(1:7)
C
C Get name(s) of second atom
C
        IT=0
        CALL GETNAM(7,STRING,IT)
        ACJ1=STRING(1:7)
C
C Compare atom names. If atom names do not match with defined atoms,
C be generous, skip error and leave default (kappa,delta) values.
C
        DO 80 I=1,INATOM
          ACC=AC(I)
          IF (STRING(1:2) .EQ. 'XX') ACI1=AC(I)         
          IF (STRING(4:5) .EQ. 'XX') ACI1(4:5)=ACC(4:5)
          DO 40 K=1,7
            IF (K .GT. 2) THEN
              IF ((ACC(K:K) .NE. ACI1(K:K)) .AND. 
     .            (ACI1(K:K) .NE. ' ')) GOTO 80
            ELSE
              IF (ACC(K:K) .NE. ACI1(K:K)) GOTO 80
            ENDIF
   40     CONTINUE
          DO 70 J=1,INATOM
            ACC=AC(J)
            IF (STRING(1:2) .EQ. 'XX') ACJ1=AC(I)         
            IF (STRING(4:5) .EQ. 'XX') ACJ1(4:5)=ACC(4:5)
            DO 50 K=1,7
              IF (K .GT. 2) THEN
                IF ((ACC(K:K) .NE. ACJ1(K:K)) .AND. 
     .              (ACJ1(K:K) .NE. ' ')) GOTO 70
              ELSE
                IF (ACC(K:K) .NE. ACJ1(K:K)) GOTO 70
              ENDIF
   50       CONTINUE
            AKAPPA(I,J)=BKAPPA
            AKAPPA(J,I)=BKAPPA
            ADELTA(I,J)=BDELTA
            ADELTA(J,I)=BDELTA
   70     CONTINUE
   80   CONTINUE

        CALL READL
        GOTO 30

   90   CONTINUE
      ELSE IF (INDEX(KEYWRD,'KAPDEL2') .GT. 0) THEN
  100   IF (INDEX(SLINE,'KAPDEL') .EQ. 0) GOTO 150
C
C Get individual (kappa,delta) values
C
        BKAPPA=READA(SLINE,ISTART(2),80)  
        BDELTA=READA(SLINE,ISTART(3),80)
C
C Get name(s) of atom
C
        IT=0
        CALL GETNAM(5,STRING,IT)
        ACI1=STRING(1:7)
C
C Compare atom names. If atom names do not match with defined atoms,
C be generous, skip error and leave default (kappa,delta) values.
C
        DO 120 I=1,INATOM
          ACC=AC(I)
          IF (STRING(1:2) .EQ. 'XX') ACI1=AC(I)         
          IF (STRING(4:5) .EQ. 'XX') ACI1(4:5)=ACC(4:5)
          DO 110 K=1,7
            IF (K .GT. 2) THEN
              IF ((ACC(K:K) .NE. ACI1(K:K)) .AND. 
     .            (ACI1(K:K) .NE. ' ')) GOTO 120
            ELSE
              IF (ACC(K:K) .NE. ACI1(K:K)) GOTO 120
            ENDIF
  110     CONTINUE
          DKAPPA(I)=BKAPPA
          DDELTA(I)=BDELTA
  120   CONTINUE

        DO 140 I=1,INATOM
          DO 130 J=1,INATOM
            AKAPPA(I,J)=(DKAPPA(I)+DKAPPA(J))/2.0D0
            ADELTA(I,J)=(DDELTA(I)+DDELTA(J))/2.0D0
  130     CONTINUE
  140   CONTINUE

        CALL READL
        GOTO 100

  150   CONTINUE
      ELSE
      ENDIF

      IF (INDEX(KEYWRD,'KAPDEL') .GT. 0) THEN
        WRITE(IOUT,160)
  160   FORMAT(//,'  Kappa values:')         
        CALL OMATAT(AKAPPA,NATMMX,1,INATOM,1,INATOM) 
        WRITE(IOUT,170)
  170   FORMAT('  Delta values:')         
        CALL OMATAT(ADELTA,NATMMX,1,INATOM,1,INATOM)
      ENDIF     
         
      RETURN   
      END
