C ********************************************************************
C * EHMACC - Extended Hueckel Molecular and Crystal Calculations     *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  GETPER                                                          *
C *                                                                  *
C *  Routine of EHMACC                                               *
C *                                                                  *
C *  Usage......: Evaluates permutation list of atoms for a symmetry *
C *               operation and writes it out.                       *
C *                                                                  *
C *  Author.....: Martin Braendle (mbs)                              *
C *  Available..: Calzaferri group, Institute for Inorganic and Phy- *
C *               sical Chemistry, University of Berne, Freiestr. 3, *
C *               3012 Berne                                         *
C *  Date.......: 29.03.93                                           *
C *  Revision...: -                                                  *
C *  Remarks....: -                                                  *
C *                                                                  *
C *  Called from: GETSYM                                             *
C *                                                                  *
C *  Calls......: MATMUL                                             *
C *                                                                  *
C ********************************************************************

      SUBROUTINE GETPER(ISYMEL)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      INCLUDE 'sizes'

      DIMENSION SYMMOP(3,3),COORD1(3,1),COORD2(3,1),COORDC(3)
      CHARACTER STRING*80

      COMMON /ATO/AC(NATMMX),SYMBOL(NSYMMX)
      CHARACTER AC*7,SYMBOL*2

      COMMON /ATOM1/NS(NSYMMX,NAEQMX),NP(NSYMMX),ND(NSYMMX),NF(NSYMMX),
     .              INATOM, ISYM(NATMMX),NELEM
      COMMON /ATOM2/EXPS(NSYMMX,NAEQMX),EXPS2(NSYMMX,NAEQMX),
     .              EXPP(NSYMMX),EXPP2(NSYMMX),
     .              EXPD(NSYMMX),EXPD2(NSYMMX),
     .              EXPF(NSYMMX),EXPF2(NSYMMX),
     .              CS1(NSYMMX,NAEQMX),CS2(NSYMMX,NAEQMX),
     .              CP1(NSYMMX),CP2(NSYMMX),CD1(NSYMMX),CD2(NSYMMX),
     .              CF1(NSYMMX),CF2(NSYMMX),COULS(NSYMMX,NAEQMX),
     .              COULP(NSYMMX),COULD(NSYMMX),COULF(NSYMMX),
     .              X(NATMMX),Y(NATMMX),Z(NATMMX)
      COMMON /CELL/DIST(3,3)
      COMMON /INDX/NCRYST,NCEL1,NCEL2,NCEL3,XK(3),WEIGHT,TWOPI,ND1,
     .             NGRAD,NFULL,CEL1,CEL2
      LOGICAL CEL1,CEL2

      COMMON /IOUNIT/IIN,IOUT,ISTART(40)

      COMMON/SYMANA/TRANSV(MXSYME,3),SYMOP(MXSYME,3,3),
     .              IPERMU(MXSYME,NATMMX,2),ISYMRE(MXSYME,NDIMMX),
     .              NLINOP(3),IPOINT(3,MXSYME),ILINE(3),NSYMEL,
     .              CSYMEL(MXSYME),FSYMOP(MXSYME),FSYMAN(MXSYME),FSYM
      LOGICAL   FSYMOP,FSYM,FSYMAN
      CHARACTER CSYMEL*2


C
C Parameter DELTA sets accuracy of atom position comparison.
C
      PARAMETER (DELTA=5.0D-4)

C
C Copy symmetry operation.
C
      DO 20 I=1,3
        DO 10 J=1,3
          SYMMOP(I,J)=SYMOP(ISYMEL,I,J)
   10   CONTINUE
   20 CONTINUE

      NPERM=0
      NNPERM=INATOM
     
      DO 110 I=1,INATOM 
C
C Subtract offset.
C
        COORD1(1,1)=X(I)-TRANSV(ISYMEL,1)
        COORD1(2,1)=Y(I)-TRANSV(ISYMEL,2)
        COORD1(3,1)=Z(I)-TRANSV(ISYMEL,3)

C
C Apply symmetry operation.
C
        CALL MATMUL(SYMMOP,COORD1,COORD2,3,3,3,1)
C
C Add offset.
C
        COORD1(1,1)=COORD2(1,1)+TRANSV(ISYMEL,1)
        COORD1(2,1)=COORD2(2,1)+TRANSV(ISYMEL,2)
        COORD1(3,1)=COORD2(3,1)+TRANSV(ISYMEL,3)
C 
C Compare with atom positions. If symmetry operation is misplaced,
C output error message and exit program.
C
        DO 90 J=1,INATOM
          COORDC(1)=0.0D0
          COORDC(2)=0.0D0
          COORDC(3)=0.0D0
          IF (NCRYST .EQ. 3) THEN
            DO 50 K=-1,1
              DO 40 L=-1,1
                DO 30 M=-1,1
                  COORDC(1)=COORD1(1,1)+DBLE(K)*DIST(1,1)+DBLE(L)*
     .                      DIST(2,1)+DBLE(M)*DIST(3,1)
                  COORDC(2)=COORD1(2,1)+DBLE(K)*DIST(1,2)+DBLE(L)*
     .                      DIST(2,2)+DBLE(M)*DIST(3,2)
                  COORDC(3)=COORD1(3,1)+DBLE(K)*DIST(1,3)+DBLE(L)*
     .                      DIST(2,3)+DBLE(M)*DIST(3,3)        
                  IF ((ABS(COORDC(1)-X(J)) .LT. DELTA) .AND.
     .                (ABS(COORDC(2)-Y(J)) .LT. DELTA) .AND.
     .                (ABS(COORDC(3)-Z(J)) .LT. DELTA)) GOTO 100
   30           CONTINUE 
   40         CONTINUE
   50       CONTINUE
          ELSE IF (NCRYST .EQ. 2) THEN
            DO 70 K=-1,1
              DO 60 L=-1,1
                COORDC(1)=COORD1(1,1)+DBLE(K)*DIST(1,1)+DBLE(L)*
     .                    DIST(2,1)
                COORDC(2)=COORD1(2,1)+DBLE(K)*DIST(1,2)+DBLE(L)*
     .                      DIST(2,2)        
                COORDC(3)=COORD1(3,1)+DBLE(K)*DIST(1,3)+DBLE(L)*
     .                      DIST(2,3)                          
                IF ((ABS(COORDC(1)-X(J)) .LT. DELTA) .AND.
     .              (ABS(COORDC(2)-Y(J)) .LT. DELTA) .AND.
     .              (ABS(COORDC(3)-Z(J)) .LT. DELTA)) GOTO 100
   60         CONTINUE
   70       CONTINUE
          ELSE
            DO 80 K=-1,1
              COORDC(1)=COORD1(1,1)+DBLE(K)*DIST(1,1)
              COORDC(2)=COORD1(2,1)+DBLE(K)*DIST(1,2)
              COORDC(3)=COORD1(3,1)+DBLE(K)*DIST(1,3)          
              IF ((ABS(COORDC(1)-X(J)) .LT. DELTA) .AND.
     .            (ABS(COORDC(2)-Y(J)) .LT. DELTA) .AND.
     .            (ABS(COORDC(3)-Z(J)) .LT. DELTA)) GOTO 100
   80       CONTINUE
          ENDIF
   90   CONTINUE

        WRITE(IOUT,95) AC(I)
   95   FORMAT(1X,A7,/)  
        STRING=' Symmetry operation misplaced, atoms do not coincide.'
        CALL WRITEL(STRING)
   
  100   IF (I .NE. J) THEN
          NPERM=NPERM+1
          IPERMU(ISYMEL,NPERM,1)=I
          IPERMU(ISYMEL,NPERM,2)=J
          IF (SYMBOL(ISYM(I)) .NE. SYMBOL(ISYM(J))) THEN
            STRING='Atom '//SYMBOL(ISYM(I))//' and '//SYMBOL(ISYM(J))//
     .             ' are not the same.'
            CALL WRITEL(STRING)
          ENDIF
        ELSE
          IPERMU(ISYMEL,NNPERM,1)=I
          IPERMU(ISYMEL,NNPERM,2)=J
          NNPERM=NNPERM-1 
        ENDIF
  110 CONTINUE
C
C Write permutation list
C
      IF (NPERM .GT. 0) THEN
        WRITE(IOUT,120)
  120   FORMAT(/,'  Atom permutation list:',/)

        DO 140 I=1,NPERM
          WRITE(IOUT,130) I,AC(IPERMU(ISYMEL,I,1)),
     .                    AC(IPERMU(ISYMEL,I,2))
  130     FORMAT(2X,I4,1X,A7,' --> ',A7)
  140   CONTINUE
        WRITE(IOUT,150)
  150   FORMAT(/,'  All other atoms are symmetry invariant.',/)
      ELSE
        WRITE(IOUT,160)
  160   FORMAT(/,'  All atoms are symmetry invariant.',/)
      ENDIF

      RETURN
      END
