C ********************************************************************
C * EHMACC - Extended Hueckel Molecular and Crystal Calculations     *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  HMAT                                                            *
C *                                                                  *
C *  Routine of EHMACC                                               *
C *                                                                  *
C *  Usage......: Calculates the Hij matrix.                         *
C *                                                                  *
C *  Authors....: M.-H. Whangbo, Dept of Chem, North Carolina State  *
C *               University, Raleigh N.C.,                          *
C *               modified by M. Evain, Dept of Chemistry, North     *
C *               Carolina State University, Raleigh N.C.            *
C *  Date.......: 1981                                               *
C *  Revision...: Dec. 1987, 15.05.92/mbs, 18.02.93/mbs (Martin      *
C *               Braendle, c/o Calzaferri group, Inst. f. Inorg.    *
C *               and Phys. Chem., Freiestr. 3, CH-3012 Berne).      *
C *  Remarks....: Slight modification of COMMON blocks.              *
C *               Distance dependent weighted Wolfsberg-Helnholz-    * 
C *               formula included. Definition for EHMO calculations *
C *               s. G.Calzaferri et al, J.Phys.Chem. 93(1989), 5366 *
C *               Individual (kappa,delta) values. 18.02.93/mbs      *
C *                                                                  *
C *  Called from: ARRAYS                                             *
C *                                                                  *
C *  Calls......: ORBRD,OMATT2,TEMPO,UNIQUE                          *
C *                                                                  *
C ********************************************************************
 
      SUBROUTINE HMAT(H,S,C,NATOM,NDIM)
 
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
 
      INCLUDE 'sizes'
 
      INTEGER   SORB(NATMMX),ISS(NATMMX),JND(NATMMX)
      DIMENSION S(NDIM,NDIM),H(NDIM,NDIM),C(NDIM)
      LOGICAL   IDEL(NDIMMX)
 
      COMMON /INDX/NCRYST,NCEL1,NCEL2,NCEL3,XK(3),WEIGHT,TWOPI,ND1,
     .             NGRAD,NFULL,CEL1,CEL2
      LOGICAL CEL1,CEL2
 
      COMMON /ATO/AC(NATMMX),SYMBOL(NSYMMX)
      CHARACTER AC*7,SYMBOL*2
 
      COMMON /KEYWRD/KEYWRD,SLINE
      CHARACTER KEYWRD*320,SLINE*80
 
      COMMON /ATOM1/NS(NSYMMX,NAEQMX),NP(NSYMMX),ND(NSYMMX),NF(NSYMMX),
     .              INATOM, ISYM(NATMMX),NELEM
      COMMON /ATOM2/EXPS(NSYMMX,NAEQMX),EXPS2(NSYMMX,NAEQMX),
     .              EXPP(NSYMMX),EXPP2(NSYMMX),
     .              EXPD(NSYMMX),EXPD2(NSYMMX),
     .              EXPF(NSYMMX),EXPF2(NSYMMX),
     .              CS1(NSYMMX,NAEQMX),CS2(NSYMMX,NAEQMX),
     .              CP1(NSYMMX),CP2(NSYMMX),CD1(NSYMMX),CD2(NSYMMX),
     .              CF1(NSYMMX),CF2(NSYMMX),COULS(NSYMMX,NAEQMX),
     .              COULP(NSYMMX),COULD(NSYMMX),COULF(NSYMMX),
     .              X(NATMMX),Y(NATMMX),Z(NATMMX)

      COMMON /EQS/NAEQS(NATMMX)
      INTEGER NAEQS

C 13.05.92/mbs
      COMMON /ATOMPT/IATMPT(NDIMMX)
      COMMON /DELET/IND(NDIMMX),INDIM,IVAL,NORBE(NATMMX),NDEL
C 12.05.92/mbs, 18.02.93/mbs
      COMMON /DISTK/CKAPPA,CDELTA,AKAPPA(NATMMX,NATMMX),
     .              ADELTA(NATMMX,NATMMX)
      COMMON /IOUNIT/IIN,IOUT,ISTART(40)
      COMMON /OPTV/RHO,FERMI,WSTART,WEND,DISTL,LB,LE,LBR,LER,IOVLB,
     .             IOVLE,ICHARG,NELEC,IDISTN,IEB,IEE,ISB,ISE,IHB,IHE,
     .             IPOPE,JPOPE,IREST,IRESTV
      COMMON /ORBRAD/D0(NDIMMX)
      COMMON /SHOUTP/ISOUT(NDIMMX),IHOUT(NDIMMX),ISKOUT(NDIMMX),
     .               IHKOUT(NDIMMX)

      JSOUT=INDEX(KEYWRD,'SOUT')
      JHOUT=INDEX(KEYWRD,'HOUT')
      IOVLP=INDEX(KEYWRD,'OVLPOP')
      IT=INDEX(KEYWRD,'BAND')
      IH=1
C
C Hii
C
      DO 70 I=1,NATOM
        KEYI=ISYM(I)
        DO 5 KCOUNT=1,NAEQS(KEYI)
          IF (NS(KEYI,KCOUNT) .EQ. 0) GOTO 10
          C(IH)=COULS(KEYI,KCOUNT)
          IH=IH+1
    5   CONTINUE
   10   IF (NP(KEYI) .EQ. 0) GOTO 30
 
        HH=COULP(KEYI)
        DO 20 JH=1,3
          C(IH)=HH
          IH=IH+1
   20   CONTINUE
   30   IF (ND(KEYI) .EQ. 0) GOTO 50
 
        HH=COULD(KEYI)
        DO 40 JH=1,5
          C(IH)=HH
          IH=IH+1
   40   CONTINUE
   50   IF (NF(KEYI) .EQ. 0) GOTO 70
 
        HH=COULF(KEYI)
        DO 60 JH=1,7
          C(IH)=HH
          IH=IH+1
   60   CONTINUE
   70 CONTINUE
 
      REWIND 22
C
C nhij
C
      NHIJ=1
      IF (INDEX(KEYWRD,'UWHIJ') .NE. 0) NHIJ=0
      IF (INDEX(KEYWRD,'DISDEPWH') .NE. 0) NHIJ=2
 
      IF (NHIJ .GT. 0) GOTO 80
      ASSIGN 110 TO IBR1
      ASSIGN 170 TO IBR2
      GOTO 90
   80 CONTINUE
      ASSIGN 100 TO IBR1
      ASSIGN 160 TO IBR2
   90 CONTINUE
 
      CONST=(1.0D0+CKAPPA)/2.0D0
C
C Hij
C
C Calculate orbital radii, if distance-dependent Wolfsberg-Helmholz-
C formula is requested.
C
      IF (NHIJ .EQ. 2) CALL ORBRD

      READ(21) (SORB(I),I=1,NATOM),S
      REWIND 21

      H(1,1)=C(1)
      DO 130 I=2,NDIM
        H(I,I)=C(I)
        I1=I-1
        IATOM1=IATMPT(I)
        DO 120 J=1,I1
          HH=C(I)+C(J)
          GOTO IBR1,(110,100)
  100     ET=(C(I)-C(J))/HH
          ET=ET*ET
          IATOM2=IATMPT(J)
          CON=(1.0D0+AKAPPA(IATOM1,IATOM2))/2.0D0
          CONST=CON+ET/2.0D0+ET*ET*(0.5D0-CON)
C
C Calculation of distance-dependent Hij
C
          IF (NHIJ .EQ. 2) THEN
            DELX=X(IATOM1)-X(IATOM2)
            DELY=Y(IATOM1)-Y(IATOM2)
            DELZ=Z(IATOM1)-Z(IATOM2)
            R=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)

            RDIF=R-D0(I)-D0(J)
            DELTA=ADELTA(IATOM1,IATOM2)
            RD2=(RDIF-ABS(RDIF))*DELTA
            CONST=1.0D0+(2.0D0*CONST-1.0D0)*
     .            DEXP(-DELTA*RDIF)/(1.0+RD2*RD2)
            CONST=CONST/2.0D0
          ENDIF
  110     H(I,J)=CONST*HH*S(I,J)
          H(J,I)=H(I,J)
  120   CONTINUE
  130 CONTINUE
 
      WRITE(22) (SORB(I),I=1,NATOM),H
C
C output Hij
C
      IF (NDEL .EQ. 0) THEN
        IF (JHOUT .NE. 0) THEN
          WRITE(IOUT,140)
  140     FORMAT(//,1X,131('-'),///,5X,'One electron Hamiltonian',
     .           ' matrix (Hij)'/)
          WRITE(IOUT,150)
  150     FORMAT(5X,'in the unit cell',/)
          CALL OMATT2(H,NDIM,IHB,IHE,IHB,IHE,IHOUT,IHOUT,1,1)
        ENDIF
      ENDIF
C
C Store the ratio h/s valid for off diagonal elements. Only if also 
C molecular calculation is selected, distance dependent Wolfsberg-
C Helmholz formula must be considered.
C 18.05.92/mbs 
C 
      DO 190 I=2,NDIM
        IATOM1=IATMPT(I)
        I1=I-1
        DO 180 J=1,I1
          HH=H(I,I)+H(J,J)
          GOTO IBR2,(160,170)
  160     ET=(H(I,I)-H(J,J))/HH
          ET=ET*ET
          IATOM2=IATMPT(J)
          CON=(1.0D0+AKAPPA(IATOM1,IATOM2))/2.0D0
          CONST=CON+ET/2.0D0+ET*ET*(0.5D0-CON)
          IF ((IT .EQ. 0) .AND. (NHIJ .EQ. 2)) THEN
            DELX=X(IATOM1)-X(IATOM2)
            DELY=Y(IATOM1)-Y(IATOM2)
            DELZ=Z(IATOM1)-Z(IATOM2)
            R=DSQRT(DELX*DELX+DELY*DELY+DELZ*DELZ)
            RDIF=R-D0(I)-D0(J)
            DELTA=ADELTA(IATOM1,IATOM2)
            RD2=(RDIF-DABS(RDIF))*DELTA
            CONST=1.0D0+(2.0D0*CONST-1.0D0)*
     .            DEXP(-DELTA*RDIF)/(1.+RD2*RD2)
            CONST=CONST/2.0D0
          ENDIF
  170     H(I,J)=CONST*HH
  180   H(J,I)=H(I,J)
  190 CONTINUE
      DO 200 I=1,NDIM
        IATOM1=IATMPT(I)
        CON=(1.0D0+AKAPPA(IATOM1,IATOM1))/2.0D0
        H(I,I)=H(I,I)*CON*2.0D0
  200 CONTINUE
      WRITE(22) H
      REWIND 22
 
      IF (NDEL .EQ. 0) RETURN
 
      DO 210 I=1,NDIM
        IDEL(I)=(IND(I) .EQ. 1)
  210 CONTINUE
 
      IF (IT .EQ. 0) GOTO 220
 
      NUM=NCEL1
      IF (NCRYST .EQ. 1) GOTO 220
      NUM=NUM+(2*NCEL1+1)*NCEL2
      IF (NCRYST .EQ. 2) GOTO 220
      NUM=NUM+(2*NCEL1+1)*(2*NCEL2+1)*NCEL3
 
  220 CONTINUE
      NLIM=NDIM-NDEL
 
      NATOM1=NATOM-1
      DO 240 I=1,NATOM1
        IORB=SORB(I)
        IORB1=SORB(I+1)-1
        ICUM=0
        DO 230 J=1,NDIM
          IF (IND(J) .EQ. 0) GOTO 230
          IF ((J .GE. IORB) .AND. (J .LE. IORB1)) ICUM=ICUM+1
  230   CONTINUE
        JND(I)=ICUM
  240 CONTINUE
 
      IORB=SORB(NATOM)
      ICUM=0
      DO 250 I=1,NDIM
        IF (IND(I) .EQ. 0) GOTO 250
        IF (I .GE. IORB) ICUM=ICUM+1
  250 CONTINUE
      JND(NATOM)=ICUM
 
      MINUS=0
      DO 260 I=2,NATOM
        MINUS=MINUS+JND(I-1)
        SORB(I)=SORB(I)-MINUS
  260 CONTINUE
C
C in the unit cell
C
      REWIND 23
      READ(21) (ISS(I),I=1,NATOM), S
 
      IS=0
      DO 280 I=1,NDIM
        IF (IDEL(I)) GOTO 280
        IS=IS+1
        JS=0
        DO 270 J=1,NDIM
          IF (IDEL(J)) GOTO 270
          JS=JS+1
          H(IS,JS)=S(I,J)
  270   CONTINUE
  280 CONTINUE
 
      WRITE(23) (SORB(I),I=1,NATOM),((H(I,J),I=1,NLIM),J=1,NLIM)
C
C output Sij
C
      IF (JSOUT .NE. 0) THEN
        WRITE(IOUT,290)
  290   FORMAT(//////,5X,'Overlap matrix (Sij)',/)
        WRITE(IOUT,300)
  300   FORMAT(5X,'in the unit cell',/)
        CALL TEMPO(H,NDIM,S,NLIM,ISB,ISE,ISOUT)
      ENDIF
C
C stop for molecule
C
      IF (IT .EQ. 0) GOTO 450
C
C 1D system
C
      DO 340 I=1,NCEL1
        READ(21) S
        IS=0
        DO 320 M=1,NDIM
          IF (IDEL(M)) GOTO 320
          IS=IS+1
          JS=0
          DO 310 N=1,NDIM
            IF (IDEL(N)) GOTO 310
            JS=JS+1
            H(IS,JS)=S(M,N)
  310     CONTINUE
  320   CONTINUE
        WRITE(23) ((H(IS,JS),IS=1,NLIM),JS=1,NLIM)
 
        IF (I .NE. 1) GOTO 340
        IF (JSOUT .EQ. 0 .AND. IOVLP .EQ. 0) GOTO 340
        CALL UNIQUE(H,NDIM,NLIM,IOVLP)
        IF (JSOUT .NE. 0) THEN
          WRITE(IOUT,330) I, 0, 0
  330     FORMAT(///5X,'between the unit cell and the cell at ',I2,
     .           'x ',I2,'y ',I2,'z '/)
          CALL TEMPO(H,NDIM,S,NLIM,ISB,ISE,ISOUT)
        ENDIF
 
  340 CONTINUE
      IF (NCRYST .EQ. 1) GOTO 450
C
C 2D system
C
      NCEL11=NCEL1+1
      DO 370 I=1,NCEL11
        DO 370 J=1,NCEL2
          READ(21) S
          IS=0
          DO 360 M=1,NDIM
            IF (IDEL(M)) GOTO 360
            IS=IS+1
            JS=0
            DO 350 N=1,NDIM
              IF (IDEL(N)) GOTO 350
              JS=JS+1
              H(IS,JS)=S(M,N)
  350       CONTINUE
  360     CONTINUE
          WRITE(23) ((H(IS,JS),IS=1,NLIM),JS=1,NLIM)
 
          IF (I .GT. 2 .OR. J .NE. 1) GOTO 370
          IF (JSOUT .EQ. 0 .AND. IOVLP .EQ. 0) GOTO 370
          II=I-1
          CALL UNIQUE(H,NDIM,NLIM,IOVLP)
          IF (JSOUT .NE. 0) THEN
            WRITE(IOUT,330) II,J,0
            CALL TEMPO(H,NDIM,S,NLIM,ISB,ISE,ISOUT)
          ENDIF
  370 CONTINUE
 
      DO 400 I=2,NCEL11
        DO 400 J=1,NCEL2
          READ(21) S
          IS=0
          DO 390 M=1,NDIM
            IF (IDEL(M)) GOTO 390
            IS=IS+1
            JS=0
            DO 380 N=1,NDIM
              IF (IDEL(N)) GOTO 380
              JS=JS+1
              H(IS,JS)=S(M,N)
  380       CONTINUE
  390     CONTINUE
          WRITE(23) ((H(IS,JS),IS=1,NLIM),JS=1,NLIM)
 
          IF (I .NE. 2 .OR. J .NE. 1) GOTO 400
          IF (JSOUT .EQ. 0 .AND. IOVLP .EQ. 0) GOTO 400
          II=I-1
          JJ=-J
          CALL UNIQUE(H,NDIM,NLIM,IOVLP)
          IF (JSOUT .NE. 0) THEN
            WRITE(IOUT,330) II,JJ,0
            CALL TEMPO(H,NDIM,S,NLIM,ISB,ISE,ISOUT)
          ENDIF
  400 CONTINUE
 
      IF (NCRYST .EQ. 2) GOTO 450
C
C 3D system
C
      NEIBR1=2*NCEL1+1
      NEIBR2=2*NCEL2+1
      DO 440 K=1,NCEL3
        NI=-NCEL1-1
        DO 430 I=1,NEIBR1
          NI=NI+1
          NJ=-NCEL2-1
          DO 430 J=1,NEIBR2
            NJ=NJ+1
            READ(21) S
            IS=0
            DO 420 M=1,NDIM
              IF (IDEL(M)) GOTO 420
              IS=IS+1
              JS=0
              DO 410 N=1,NDIM
                IF (IDEL(N)) GOTO 410
                JS=JS+1
                H(IS,JS)=S(M,N)
  410         CONTINUE
  420       CONTINUE
            WRITE(23) ((H(IS,JS),IS=1,NLIM),JS=1,NLIM)
 
            IAB=ABS(NI)
            JAB=ABS(NJ)
            IF (IAB .GT. 1 .OR. JAB .GT. 1 .OR. K .NE. 1) GOTO 430
            IF (JSOUT .EQ. 0 .AND. IOVLP .EQ. 0) GOTO 430
            CALL UNIQUE(H,NDIM,NLIM,IOVLP)
            IF (JSOUT .NE. 0) THEN
              WRITE(IOUT,330) NI, NJ, K
              CALL TEMPO(H,NDIM,S,NLIM,ISB,ISE,ISOUT)
            ENDIF
  430   CONTINUE
  440 CONTINUE
 
  450 CONTINUE
 
      READ(22) (ISS(I),I=1,NATOM),S
 
      IS=0
      DO 470 I=1,NDIM
        IF (IDEL(I)) GOTO 470
        IS=IS+1
        JS=0
        DO 460 J=1,NDIM
          IF (IDEL(J)) GOTO 460
          JS=JS+1
          H(IS,JS)=S(I,J)
  460   CONTINUE
  470 CONTINUE
 
      WRITE(23) ((H(IS,JS),IS=1,NLIM),JS=1,NLIM)
 
      READ(22) S
      IS=0
      DO 490 I=1,NDIM
        IF (IDEL(I)) GOTO 490
        IS=IS+1
        JS=0
        DO 480 J=1,NDIM
          IF (IDEL(J)) GOTO 480
          JS=JS+1
          H(IS,JS)=S(I,J)
  480   CONTINUE
  490 CONTINUE
 
      WRITE(23) ((H(I,J),I=1,NLIM),J=1,NLIM)
 
      REWIND 21
      REWIND 22
      REWIND 23
 
      READ(23) (SORB(I),I=1,NATOM),((S(I,J),I=1,NLIM),J=1,NLIM)
      WRITE(21) (SORB(I),I=1,NATOM),((S(I,J),I=1,NLIM),J=1,NLIM)
 
      IF (IT .EQ. 0) GOTO 510
 
      DO 500 IR=1,NUM
        READ(23) ((S(I,J),I=1,NLIM),J=1,NLIM)
        WRITE(21) ((S(I,J),I=1,NLIM),J=1,NLIM)
  500 CONTINUE
 
  510 CONTINUE
 
      READ(23) ((S(I,J),I=1,NLIM),J=1,NLIM)
      WRITE(22) (SORB(I),I=1,NATOM),((S(I,J),I=1,NLIM),J=1,NLIM)
 
      IF (JHOUT .NE. 0) THEN
        WRITE(IOUT,140)
        WRITE(IOUT,150)
        CALL TEMPO(S,NDIM,H,NLIM,ISB,ISE,ISOUT)
      ENDIF
 
      READ(23) ((S(I,J),I=1,NLIM),J=1,NLIM)
      WRITE(22) ((S(I,J),I=1,NLIM),J=1,NLIM)
 
      REWIND 21
      REWIND 22
      REWIND 23
C
C Apply AODELETE option on orbital to atom number pointer IATMPT and
C orbital radii ORBRAD.
C 13.05.92/mbs
C
      IS=0
      DO 520 I=1,NDIM
        IF (.NOT. IDEL(I)) IS=IS+1
        IATMPT(IS)=IATMPT(I)
        D0(IS)=D0(I)
  520 CONTINUE
 
      NDIM=NLIM
 
      RETURN
      END