C ********************************************************************
C * EHMACC - Extended Hueckel Molecular and Crystal Calculations     *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  POBOND                                                          *
C *                                                                  *
C *  Routine of EHMACC                                               *
C *                                                                  *
C *  Usage......: Evaluates bonds (reduced overlap populations).     *
C *                                                                  *
C *  Authors....: M.-H. Whangbo, Dept of Chem, North Carolina State  *
C *               University, Raleigh N.C.,                          *
C *               modified by M. Evain, Dept of Chemistry, North     *
C *               Carolina State University, Raleigh N.C.            *
C *  Date.......: 1981                                               *
C *  Revision...: Dec. 1987, 06.05.92/mbs (Martin Braendle c/o       *
C *               Calzaferri group, Inst. f. Inorg. and Phys. Chem., *
C *               Freiestr. 3, CH-3012 Berne)                        *
C *  Remarks....: Slight modification of COMMON blocks.              *
C *                                                                  *
C *  Called from: BPOP                                               *
C *                                                                  *
C *  Calls......: -                                                  *
C *                                                                  *
C ********************************************************************
 
      SUBROUTINE POBOND(PK,F,P,DEN,NDIM,IT,ID)
 
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
 
      INCLUDE 'sizes'
 
      DIMENSION PK(NBONMX),F(NDIM,NDIM),P(NDIM,NDIM),DEN(NDIM,NDIM)
 
      COMMON /ATOM1/NS(NSYMMX,NAEQMX),NP(NSYMMX),ND(NSYMMX),NF(NSYMMX),
     .              INATOM,ISYM(NATMMX),NELEM
      COMMON /BOND2/IDTR(NBONMX,3),DDX(NBONMX),IDBOND,INEXT(NBONMX),
     .              IFIRST,ITYPE(14)
 
      COMMON /ATO/AC(NATMMX),SYMBOL(NSYMMX)
      CHARACTER AC*7,SYMBOL*2
 
      COMMON /BOND1/IDAT(NBONMX,2)
      CHARACTER*7 IDAT
 
      COMMON /POP/X,Y,SORB
      INTEGER SORB(NATMMX)
 
      IF (IT .EQ. 1) GOTO 150
C
C bonds between cells
C
      IRUN=ITYPE(IT)
      DO 140 IJK=1,IRUN
        DO 10 I=1,INATOM
          IF (IDAT(ID,1) .EQ. AC(I)) GOTO 20
   10   CONTINUE
   20   IST=I
        MA=SORB(IST)
        IF (IST .LT. INATOM) THEN
          NA=SORB(IST+1)-1
        ELSE
          NA=NDIM
        ENDIF
        DO 30 I=1,INATOM
          IF (IDAT(ID,2) .EQ. AC(I)) GOTO 40
   30   CONTINUE
   40   IEN=I
        MB=SORB(IEN)
        IF (IEN .LT. INATOM) THEN
          NB=SORB(IEN+1)-1
        ELSE
          NB=NDIM
        ENDIF
        IF (IEN-IST) 50,70,110
C
C     row > column
C
   50   DO 60 I=MA,NA
          DO 60 J=MB,NB
            P(I,J)=2.0D0*F(I,J)*(X*DEN(I,J)+Y*DEN(J,I))
   60   PK(ID)=PK(ID)+P(I,J)
        GOTO 130
C
C     orig=dest
C
   70   DO 100 I=MA,NA
          DO 80 J=I,NA
            P(I,J)=2.0D0*F(I,J)*(X*DEN(J,I)-DBLE(1-I/J)*Y*DEN(I,J))
   80     PK(ID)=PK(ID)+P(I,J)
          IF (I .EQ. MA) GOTO 100
          I1=I-1
          DO 90 J=MA,I1
            P(I,J)=2.0D0*F(I,J)*(X*DEN(I,J)+Y*DEN(J,I))
   90     PK(ID)=PK(ID)+P(I,J)
  100   CONTINUE
        GOTO 130
C
C     column > row
C
  110   DO 120 I=MA,NA
          DO 120 J=MB,NB
            P(I,J)=2.0D0*F(I,J)*(X*DEN(J,I)-Y*DEN(I,J))
  120   PK(ID)=PK(ID)+P(I,J)
  130   ID=ID+1
  140 CONTINUE
      RETURN
C
C bonds in the unit cell
C
  150 IRUN=ITYPE(IT)
      DO 210 IJK=1,IRUN
        DO 160 I=1,INATOM
          IF (IDAT(ID,1) .EQ. AC(I)) GOTO 170
  160   CONTINUE
  170   IST=I
        MA=SORB(IST)
        IF (IST .LT. INATOM) THEN
          NA=SORB(IST+1)-1
        ELSE
          NA=NDIM
        ENDIF
        DO 180 I=1,INATOM
          IF (IDAT(ID,2) .EQ. AC(I)) GOTO 190
  180   CONTINUE
  190   IEN=I
        MB=SORB(IEN)
        IF (IEN .LT. INATOM) THEN
          NB=SORB(IEN+1)-1
        ELSE
          NB=NDIM
        ENDIF
 
        DO 200 I=MA,NA
          DO 200 J=MB,NB
            P(J,I)=2.0D0*DEN(J,I)*F(J,I)
  200   PK(ID)=PK(ID)+P(J,I)
 
        ID=ID+1
  210 CONTINUE
      RETURN
      END
