C ********************************************************************
C * EHMACC - Extended Hueckel Molecular and Crystal Calculations     *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  SMAT                                                            *
C *                                                                  *
C *  Routine of EHMACC                                               *
C *                                                                  *
C *  Usage......: Calculates the overlap matrix.                     *
C *                                                                  *
C *  Authors....: M.-H. Whangbo, Dept of Chem, North Carolina State  *
C *               University, Raleigh N.C.,                          *
C *               modified by M. Evain, Dept of Chemistry, North     *
C *               Carolina State University, Raleigh N.C.            *
C *  Date.......: 1981                                               *
C *  Revision...: Dec. 1987, 08.05.92/mbs (Martin Braendle, c/o      *
C *               Calzaferri group, Inst. f. Inorg. and Phys. Chem., *
C *               Freiestr. 3, CH-3012 Berne)                        *
C *  Remarks....: Slight modification of COMMON blocks.              *
C *                                                                  *
C *  Called from: ARRAYS                                             *
C *                                                                  *
C *  Calls......: MOVLAP,OMATT2,UNIQUE                               *
C *                                                                  *
C ********************************************************************
 
      SUBROUTINE SMAT(S,MAXS,MAXP,MAXD,SORB,SP,PD,NATOM2,NATOM,NDIM)
 
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
 
      INCLUDE 'sizes'
 
      DIMENSION S(NDIM,NDIM),MAXS(NATOM),MAXP(NATOM),MAXD(NATOM)
      INTEGER   SORB(NATOM2)
      LOGICAL   SP(NATOM),PD(NATOM)
 
      COMMON /ATOM1/NS(NSYMMX,NAEQMX),NP(NSYMMX),ND(NSYMMX),NF(NSYMMX),
     .              INATOM,ISYM(NATMMX),NELEM
      COMMON /ATOM2/EXPS(NSYMMX,NAEQMX),EXPS2(NSYMMX,NAEQMX),
     .              EXPP(NSYMMX),EXPP2(NSYMMX),EXPD(NSYMMX),
     .              EXPD2(NSYMMX),EXPF(NSYMMX),EXPF2(NSYMMX),
     .              CS1(NSYMMX,NAEQMX),CS2(NSYMMX,NAEQMX),
     .              CP1(NSYMMX),CP2(NSYMMX),CD1(NSYMMX),CD2(NSYMMX),
     .              CF1(NSYMMX),CF2(NSYMMX),COULS(NSYMMX,NAEQMX),
     .              COULP(NSYMMX),COULD(NSYMMX),COULF(NSYMMX),X(NATMMX),
     .              Y(NATMMX),Z(NATMMX)
      COMMON /EQS/NAEQS(NATMMX)
      INTEGER NAEQS

      COMMON /CELL/DIST(3,3)
      COMMON /DELET/IND(NDIMMX),INDIM,IVAL,NORBE(NATMMX),NDEL
      COMMON /DEX/ADD(3),NB,NE,ISUB,NSUB
      COMMON /IOUNIT/IIN,IOUT,ISTART(40)
      COMMON /OPTV/RHO,FERMI,WSTART,WEND,DISTL,LB,LE,LBR,LER,IOVLB,
     .             IOVLE,ICHARG,NELEC,IDISTN,IEB,IEE,ISB,ISE,IHB,IHE,
     .             IPOPE,JPOPE,IREST,IRESTV
      COMMON /SHOUTP/ISOUT(NDIMMX),IHOUT(NDIMMX),ISKOUT(NDIMMX),
     .               IHKOUT(NDIMMX)
 
      COMMON /ATO/AC(NATMMX),SYMBOL(NSYMMX)
      CHARACTER AC*7,SYMBOL*2
 
      COMMON /INDX/NCRYST,NCEL1,NCEL2,NCEL3,XK(3),WEIGHT,TWOPI,ND1,
     .             NGRAD,NFULL,CEL1,CEL2
      LOGICAL CEL1,CEL2
 
      COMMON /KEYWRD/KEYWRD,SLINE
      CHARACTER KEYWRD*320,SLINE*80

C CSORB contains just the a copy of the SORB array. The CSORB vector will 
C be used in cryst.f to output a MOBY-like file in oder to calculate oscillator
C strengths.

      COMMON /SORBIT/CSORB(NDIMMX)
      INTEGER CSORB 

      DO 10 I=1,NDIM
        DO 10 J=1,I
          S(I,J)=0.0D0
          S(J,I)=0.0D0
   10 CONTINUE
      IORB=1
C
C prepare the storing area
C
C NATOM2=2*NATOM
C
      DO 20 I=1,NATOM
        KEYI=ISYM(I)
        SORB(I)=IORB
        CSORB(I)=SORB(I) 
        SORB(I+NATOM)=IORB+NDIM
        DO 5 KCOUNT=1,NAEQS(KEYI)
          IF (NS(KEYI,KCOUNT) .NE. 0) IORB=IORB+1
    5   CONTINUE
        MAXD(I)=ND(KEYI)
        IF (NP(KEYI) .NE. 0) IORB=IORB+3
        IF (ND(KEYI) .NE. 0) IORB=IORB+5
        IF (NF(KEYI) .NE. 0) IORB=IORB+7
        MAXP(I)=NP(KEYI)
        MAXS(I)=NS(KEYI,NAEQS(KEYI))
        SP(I)=EXPS(KEYI,NAEQS(KEYI)) .EQ. EXPP(KEYI)
        PD(I)=EXPP(KEYI) .EQ. EXPD(KEYI)
        IF (PD(I)) MAXP(I)=MAX0(MAXP(I),MAXD(I))
        IF (SP(I)) MAXS(I)=MAX0(NS(KEYI,NAEQS(KEYI)),MAXP(I))
   20 CONTINUE
      CSORB(NATOM+1)=IORB
        
C
C prepare the file to store S(i,j)
C
      REWIND 21
C
C calculate S within a unit cell
C
      IF (NATOM .EQ. 1) GOTO 30
      NB=2
      NE=NATOM
      ISUB=0
      NSUB=0
      ADD(1)=0.0D0
      ADD(2)=0.0D0
      ADD(3)=0.0D0
      CALL MOVLAP(S,SORB,NATOM2,NATOM,NDIM)
   30 DO 40 I=1,NDIM
        S(I,I)=1.0D0
        DO 40 J=1,I
          S(I,J)=S(J,I)
   40 CONTINUE
      WRITE(21) (SORB(I),I=1,NATOM),S
C
C output Sij
C
      JSOUT=INDEX(KEYWRD,'SOUT')
      IOVLP=INDEX(KEYWRD,'OVLPOP')
 
      IF (NDEL .EQ. 0) THEN
        IF (JSOUT .NE. 0) THEN
          WRITE(IOUT,50)
   50     FORMAT(//,1X,131('-'),///,5X,'Overlap matrix (Sij)',/)
          WRITE(IOUT,60)
   60     FORMAT(5X,'in the unit cell',/)
          CALL OMATT2(S,NDIM,ISB,ISE,ISB,ISE,ISOUT,ISOUT,1,1)
        ENDIF
      ENDIF
C
C check the dimension of the calculation
C if EH end
C
      IF (INDEX(KEYWRD,'BAND') .EQ. 0) GOTO 170
C
C 1D system
C
      NB=NATOM+1
      NE=NATOM+NATOM
      ISUB=NATOM
      NSUB=NDIM

      DO 90 I=1,NCEL1
        RI=DBLE(I)
        DO 70 L=1,3
   70   ADD(L)=RI*DIST(1,L)
        CALL MOVLAP(S,SORB,NATOM2,NATOM,NDIM)
        WRITE(21) S

C        IF (I .NE. 1) GOTO 90
C        IF (NDEL .NE. 0) GOTO 90
C        IF ((JSOUT .EQ. 0) .AND. (IOVLP .EQ. 0)) GOTO 90

        CALL UNIQUE(S,NDIM,NDIM,IOVLP)
        IF (JSOUT .NE. 0) THEN
          WRITE(IOUT,80) I,0,0
   80     FORMAT(///,5X,'between the unit cell and the cell at',I2,'x ',
     .           I2,'y ',I2,'z ',/)
          CALL OMATT2(S,NDIM,ISB,ISE,ISB,ISE,ISOUT,ISOUT,1,1)
        ENDIF
 
   90 CONTINUE

      IF (NCRYST .EQ. 1) GOTO 170
C
C 2D system
C
      NCEL11=NCEL1+1
      DO 110 I=1,NCEL11
        RI=DBLE(I-1)
        DO 110 J=1,NCEL2
          RJ=DBLE(J)
          DO 100 L=1,3
  100     ADD(L)=RI*DIST(1,L)+RJ*DIST(2,L)
          CALL MOVLAP(S,SORB,NATOM2,NATOM,NDIM)
          WRITE(21) S
C          IF ((I .GT. 2) .OR. (J .NE. 1)) GOTO 110
C          IF (NDEL .NE. 0) GOTO 110
C          IF ((JSOUT .EQ. 0) .AND. (IOVLP .EQ. 0)) GOTO 110
          CALL UNIQUE(S,NDIM,NDIM,IOVLP)
          IF (JSOUT .NE. 0) THEN
            II=I-1
            WRITE(IOUT,80) II,J,0
            CALL OMATT2(S,NDIM,ISB,ISE,ISB,ISE,ISOUT,ISOUT,1,1)
          ENDIF
  110 CONTINUE
 
      DO 130 I=2,NCEL11
        RI=DBLE(I-1)
        DO 130 J=1,NCEL2
          RJ=-DBLE(J)
          DO 120 L=1,3
  120     ADD(L)=RI*DIST(1,L)+RJ*DIST(2,L)
          CALL MOVLAP(S,SORB,NATOM2,NATOM,NDIM)
          WRITE(21) S
C          IF ((I .NE. 2) .OR. (J .NE. 1)) GOTO 130
C          IF (NDEL .NE. 0) GOTO 130
C          IF ((JSOUT .EQ. 0) .AND. (IOVLP .EQ. 0)) GOTO 130
          CALL UNIQUE(S,NDIM,NDIM,IOVLP)
          IF (JSOUT .NE. 0) THEN
            II=I-1
            JJ=-J
            WRITE(IOUT,80) II, JJ, 0
            CALL OMATT2(S,NDIM,ISB,IsE,ISB,ISE,ISOUT,ISOUT,1,1)
          ENDIF
  130 CONTINUE
 
      IF (NCRYST .EQ. 2) GOTO 170
C
C 3D system
C
      NEIBR1=2*NCEL1+1
      NEIBR2=2*NCEL2+1
      DO 160 K=1,NCEL3
        RK=DBLE(K)
        NI=-NCEL1-1
        DO 150 I=1,NEIBR1
          NI=NI+1
          RI=DBLE(NI)
          NJ=-NCEL2-1
          DO 150 J=1,NEIBR2
            NJ=NJ+1
            RJ=DBLE(NJ)
            DO 140 L=1,3
  140       ADD(L)=RI*DIST(1,L)+RJ*DIST(2,L)+RK*DIST(3,L)
            CALL MOVLAP(S,SORB,NATOM2,NATOM,NDIM)
            WRITE(21) S
            IAB=ABS(NI)
            JAB=ABS(NJ)
            IF ((IAB .GT. 1) .OR. (JAB .GT. 1) .OR. (K .NE. 1)) GOTO 150
            IF (NDEL .NE. 0) GOTO 150
            IF ((JSOUT .EQ. 0) .AND. (IOVLP .EQ. 0)) GOTO 150
            CALL UNIQUE(S,NDIM,NDIM,IOVLP)
            IF (JSOUT .NE. 0) THEN
              WRITE(IOUT,80) NI,NJ,K
              CALL OMATT2(S,NDIM,ISB,ISE,ISB,ISE,ISOUT,ISOUT,1,1)
            ENDIF
  150   CONTINUE
  160 CONTINUE
 
  170 CONTINUE
      REWIND 21
 
      RETURN
      END
