C ********************************************************************
C * EHPC - Extended Hueckel properties calculations                  *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  GPOPT                                                           *
C *                                                                  *
C *  Routine of EHPC                                                 *
C *                                                                  *
C *  Usage......: Reads title and keywords.                          *
C *                                                                  *
C *  Authors....: M.-H. Whangbo, Dept of Chem, North Carolina State  *
C *               University, Raleigh N.C.,                          *
C *               modified by M. Evain, Dept of Chemistry, North     *
C *               Carolina State University, Raleigh N.C.            *
C *  Date.......: 1981                                               *
C *  Revision...: Dec. 1987, 16.09.94/mbs (Martin Braendle, c/o      *
C *               Calzaferri group, Institute f. Inorganic and Phy-  *
C *               sical Chemistry, University of Berne, Freiestr. 3, *
C *               CH-3012 Berne)                                     *
C *  Remarks....: Keyword for variation selection added.             *
C *                                                                  *
C *  Called from: EHPC                                               *
C *                                                                  *
C *  Calls......: READL,READA,WRITEL                                 *
C *                                                                  *
C ********************************************************************

      SUBROUTINE GPOPT

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      CHARACTER TITLE*131,SPACE*1

      COMMON /IOUNIT/IIN,IOUT,ISTART(40)
      COMMON /OPTV/DELTA,EMIN,EMAX,STEP,XLIMIT,LEVB,LEVE,NMESH,IVARYS,
     .             IVARYE,NVARY

      COMMON /KEYWRD/KEYWRD,SLINE
      CHARACTER KEYWRD*320,SLINE*80

      DATA SPACE/' '/

      TITLE=' '
      CALL READL
      IF (INDEX(SLINE,'TITLE') .NE. 0) THEN
        TITLE=SLINE
        TITLE(1:5)='     '
        CALL READL
      ENDIF

      KEYWRD=' '
      IP2=1
   10 IF (INDEX(SLINE,'KEYWRD') .EQ. 0) GOTO 40
      DO 20 I=80,ISTART(2),-1
        IF (SLINE(I:I) .NE. SPACE) GOTO 30
   20 CONTINUE
   30 IP1=I+1
      KEYWRD=KEYWRD(1:IP2)//SLINE(ISTART(2):I)//' '
      IP2=IP2+I+2-ISTART(2)
      CALL READL
      GOTO 10
   40 CONTINUE

      WRITE(IOUT,50) TITLE
   50 FORMAT(/' ',A///)
C
C Keywords:
C
      WRITE(IOUT,60)
   60 FORMAT('    Options : '/)

      IF (INDEX(KEYWRD,'IDOS') .NE. 0) WRITE(IOUT,70)
   70 FORMAT(' *  IDOS      ',11X,'- Integrated density of states')
      IF (INDEX(KEYWRD,'IAOPOP') .NE. 0) WRITE(IOUT,80)
   80 FORMAT(' *  IAOPOP    ',11X,'- Integrated AO population')
      IF (INDEX(KEYWRD,'IFMOPOP') .NE. 0) WRITE(IOUT,90)
   90 FORMAT(' *  IFMOPOP   ',11X,'- Integrated FMO population')
      IF (INDEX(KEYWRD,'IOVLP') .NE. 0) WRITE(IOUT,100)
  100 FORMAT(' *  IOVLP     ',11X,'- Integrated overlap population')
C
C Fermi level boundaries
C
      LEVB=0
      LEVE=0
      IP1=INDEX(KEYWRD,'INTEGR=')
      IF (IP1 .NE. 0) THEN
        IP1=IP1+7
        LEVB=INT(READA(KEYWRD,IP1,320))
  110   IP1=IP1+1
        IF (KEYWRD(IP1:IP1+1) .EQ. 'TO') GOTO 120
        IF (IP1 .GT. 319) GOTO 120
        GOTO 110
  120   IP1=IP1+2
        LEVE=INT(READA(KEYWRD,IP1,320))
      ENDIF
      IF (LEVE .LT. LEVB) LEVE=LEVB
      IF (IP1 .NE. 0) WRITE(IOUT,130) LEVB,LEVE
  130 FORMAT(' *  INTEGR=',I3,' to ',I3,'    - Integration boundaries')
C
C step
C
      STEP=0.0D0
      IP1=INDEX(KEYWRD,'STEP=')
      IF (IP1 .NE. 0) THEN
        IP1=IP1+5
        STEP=READA(KEYWRD,IP1,320)
        WRITE(IOUT,140) STEP
  140 FORMAT(' *  STEP  =',F10.3,'    - Step of integration')
      ENDIF

      IF (INDEX(KEYWRD,'SDOS') .NE. 0) WRITE(IOUT,150)
  150 FORMAT(' *  SDOS      ',11X,'- Smoothed density of states')
      IF (INDEX(KEYWRD,'SAOPOP') .NE. 0) WRITE(IOUT,160)
  160 FORMAT(' *  SAOPOP    ',11X,'- Smoothed AO population')
      IF (INDEX(KEYWRD,'SFMOPOP') .NE. 0) WRITE(IOUT,170)
  170 FORMAT(' *  SFMOPOP   ',11X,'- Smoothed FMO population')
      IF (INDEX(KEYWRD,'SOVLP') .NE. 0) WRITE(IOUT,180)
  180 FORMAT(' *  SOVLP     ',11X,'- Smoothed overlap population')
C
C delta
C
      DELTA=0.0D0
      IP1=INDEX(KEYWRD,'DELTA=')
      IF (IP1 .NE. 0) THEN
        IP1=IP1+6
        DELTA=READA(KEYWRD,IP1,320)
        WRITE(IOUT,190) DELTA
  190 FORMAT(' *  DELTA =',F10.3,'    - Smoothing factor')
      ENDIF
C
C Emin
C
      EMIN=0.0D0
      IP1=INDEX(KEYWRD,'EMIN=')
      IF (IP1 .NE. 0) THEN
        IP1=IP1+5
        EMIN=READA(KEYWRD,IP1,320)
        WRITE(IOUT,200) EMIN
  200 FORMAT(' *  EMIN  =',F10.3,'    - Energy to start the smoothing')
      ENDIF
C
C Emax
C
      EMAX=0.0D0
      IP1=INDEX(KEYWRD,'EMAX=')
      IF (IP1 .NE. 0) THEN
        IP1=IP1+5
        EMAX=READA(KEYWRD,IP1,320)
        WRITE(IOUT,210) EMAX
  210 FORMAT(' *  EMAX  =',F10.3,'    - Energy to end the smoothing')
      ENDIF
C
C Nmesh
C
      NMESH=0
      IP1=INDEX(KEYWRD,'NMESH=')
      IF (IP1 .NE. 0) THEN
        IP1=IP1+6
        NMESH=INT(READA(KEYWRD,IP1,320))
        WRITE(IOUT,220) NMESH
  220   FORMAT(' *  NMESH =',I10,'    - Number of mesh points for ',
     .         'the smoothing')
      ENDIF
C
C Limit
C
      XLIMIT=0.0D0
      IP1=INDEX(KEYWRD,'LIMIT=')
      IF (IP1 .NE. 0) THEN
        IP1=IP1+6
        XLIMIT=READA(KEYWRD,IP1,320)
        WRITE(IOUT,230) XLIMIT
  230 FORMAT(' *  LIMIT =',F10.3,'    - Limitation of the gaussian')
      ENDIF
C
C Selection of variation.
C
      IVARYS=1
      IVARYE=1
      READ(1,235) IDUMMY,IDUMMY,IDUMMY,IDUMMY,IDUMMY,NVARY
  235 FORMAT(6I6)
      IF (NVARY .EQ. 0) NVARY=1
      IP1=INDEX(KEYWRD,'VARIATION=')
      IF (IP1 .NE. 0) THEN
        IP1=IP1+10
        IVARYS=INT(READA(KEYWRD,IP1,320))
  240   IP1=IP1+1
        IF (KEYWRD(IP1:IP1+1) .EQ. 'TO') GOTO 250
        IF (IP1 .GT. 319) GOTO 250
        GOTO 240
  250   IP1=IP1+2
        IVARYE=INT(READA(KEYWRD,IP1,320))
      ENDIF
      IF (IVARYE .LT. IVARYS) IVARYE=IVARYS
      IF (IVARYS .GT. NVARY) THEN
        SLINE='Variation start greater than total number of variations.'
        CALL WRITEL(SLINE)
        CALL CLEXIT
      ENDIF
      IF (IVARYE .GT. NVARY) IVARYE=NVARY
      IF (IP1 .NE. 0) THEN
        IF (IVARYS .EQ. IVARYE) THEN
          WRITE(IOUT,260) IVARYS
  260     FORMAT(' *  VARIATION=',I3,8X,'- Select variation, long ',
     .           'output')
        ELSE
          WRITE(IOUT,270) IVARYS,IVARYE
  270     FORMAT(' *  VARIATION=',I3,' to ',I3,' - Select variations,',
     .           ' short output')
          ITEST=INDEX(KEYWRD,'SDOS')+INDEX(KEYWRD,'SAOPOP')+
     .          INDEX(KEYWRD,'SFMOPOP')+INDEX(KEYWRD,'SOVLPOP')
          IF (ITEST .GT. 0) THEN
            SLINE='Multiple variations not possible with smoothed '//
     .            'properties.'
            CALL WRITEL(SLINE)
            CALL CLEXIT
          ENDIF
        ENDIF
      ENDIF
C
C checkfile
C
      IF (INDEX(KEYWRD,'CHECKFILE') .NE. 0) WRITE(IOUT,280)
  280 FORMAT(' *  CHECKFILE ',11X,'- Check the file and stop')

      WRITE(IOUT,290)
  290 FORMAT(//////)

      RETURN
      END
