C ********************************************************************
C * EHPC - Extended Hueckel properties calculations                  *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  INTEGR                                                          *
C *                                                                  *
C *  Routine of EHPC                                                 *
C *                                                                  *
C *  Usage......: Calculates the Fermi level and the total energy as *
C *               a function of electron filling.                    *
C *                                                                  *
C *  Authors....: M.-H. Whangbo, Dept of Chem, North Carolina State  *
C *               University, Raleigh N.C.,                          *
C *               modified by M. Evain, Dept of Chemistry, North     *
C *               Carolina State University, Raleigh N.C.            *
C *  Date.......: 1981                                               *
C *  Revision...: Dec. 1987, 16.11.93/mbs                            *
C *  Remarks....: -                                                  *
C *                                                                  *
C *  Called from: PARRAY                                             *
C *                                                                  *
C *  Calls......: -                                                  *
C *                                                                  *
C ********************************************************************

      SUBROUTINE INTEGR(ENDK,ID,W,IACC,SN0,SN1,SE0,SE1,XL0,XL1,NDIM,
     .                  NKP,NDK,NSTEP,IVARY)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      DIMENSION ENDK(NDK),ID(NDK),W(NDK),IACC(NKP,NSTEP),SE0(NSTEP),
     .          SE1(NSTEP),SN0(NSTEP),SN1(NSTEP),XL0(NSTEP),XL1(NSTEP)

      COMMON /IOUNIT/IIN,IOUT,ISTART(40)
      COMMON /KEYWRD/KEYWRD,SLINE
      CHARACTER KEYWRD*320,SLINE*80

      COMMON /OPTV/DELTA,EMIN,EMAX,STEP,XLIMIT,LEVB,LEVE,NMESH,IVARYS,
     .             IVARYE,NVARY

      DO 20 I=1,NKP
        DO 10 J=1,NSTEP
          IACC(I,J)=0
   10   CONTINUE
   20 CONTINUE

      IFER=1
      DO 50 IRUN=1,NSTEP
        XFERMI=DBLE(LEVB)+DBLE(IRUN-1)*STEP+1.0D-8
        IF (IRUN .EQ. 1) THEN
          SN1(IRUN)=0.0D0
          SE1(IRUN)=0.0D0
        ELSE
          SN1(IRUN)=SN0(IRUN-1)
          SE1(IRUN)=SE0(IRUN-1)
        ENDIF

        IF=IFER
        DO 30 I=IF,NDK
          II=ID(I)
          IOKP=(II-1)/NDIM+1
          IACC(IOKP,IRUN)=IACC(IOKP,IRUN)+1
          WID=W(II)*2.0D0
          SN1(IRUN)=SN1(IRUN)+WID
          SE1(IRUN)=SE1(IRUN)+WID*ENDK(II)
          IF (SN1(IRUN) .GT. XFERMI) THEN
            XL1(IRUN)=ENDK(II)
            IF (I .GT. 1) THEN
              IJ=ID(I-1)
              XL0(IRUN)=ENDK(IJ)
              IACC(IOKP,IRUN)=IACC(IOKP,IRUN)-1
            ELSE
              XL0(IRUN)=0.0D0
            ENDIF
            IFER=I
            GOTO 40
          ENDIF
   30   CONTINUE

   40   SN0(IRUN)=SN1(IRUN)-WID
        SE0(IRUN)=SE1(IRUN)-WID*ENDK(II)
   50 CONTINUE
C
C output of IDOS
C
      IF (INDEX(KEYWRD,'IDOS') .GT. 0) THEN
        IF (IVARYS .EQ. IVARYE) THEN
          WRITE(IOUT,70)
          DO 60 I=1,NSTEP
            WRITE(IOUT,80) I,SN0(I),SN1(I),XL0(I),XL1(I),SE0(I),SE1(I)
   60     CONTINUE
   70     FORMAT(//,5X,'Fermi level and total energy as the function ',
     .           'of the number of electrons',//,1X,'   i',8X,'n0 ',9X,
     .           'n1 ',8X,'ef0',9X,'ef1',11X,'te0',11X,'te1')
   80     FORMAT(1X,I4,4F12.4,2F14.4)
        ELSE
          EFERMI=XL0(NSTEP)+(XL1(NSTEP)-XL0(NSTEP))*
     .           (DBLE(LEVE)-SN0(NSTEP))/(SN1(NSTEP)-SN0(NSTEP))
          EEHMO=SE0(NSTEP)+(SE1(NSTEP)-SE0(NSTEP))*
     .           (DBLE(LEVE)-SN0(NSTEP))/(SN1(NSTEP)-SN0(NSTEP))
          WRITE(IOUT,90) LEVE
   90     FORMAT(//,' Fermi level and total energy for ',I4,
     .              ' electrons',//,
     .              ' Variation #   Fermi level   Total energy')
          WRITE(IOUT,100) IVARY,EFERMI,EEHMO
  100     FORMAT(8X,I4,3X,F11.4,3X,F12.4)
        ENDIF
      ENDIF

      RETURN
      END
