C ********************************************************************
C * EHPC - Extended Hueckel properties calculations                  *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************
C ********************************************************************
C *                                                                  *
C *  PROJT                                                           *
C *                                                                  *
C *  Routine of EHPC                                                 *
C *                                                                  *
C *  Usage......: Does the integration for AO and/or FMO populations *
C *               as a function of electron filling.                 *
C *                                                                  *
C *  Authors....: M.-H. Whangbo, Dept of Chem, North Carolina State  *
C *               University, Raleigh N.C.,                          *
C *               modified by M. Evain, Dept of Chemistry, North     *
C *               Carolina State University, Raleigh N.C.            *
C *  Date.......: 1981                                               *
C *  Revision...: Dec. 1987, 19.09.94/mbs (Martin Braendle c/o       *
C *               Calzaferri group, Institute for Inorganic and Phy- *
C *               sical Chemistry, Freiestr. 3, CH-3012 Berne)       *
C *  Remarks....: Extended for multiple variations of geometry.      *
C *                                                                  *
C *  Called from: PPART                                              *
C *                                                                  *
C *  Calls......: WRITEL                                             *
C *                                                                  *
C ********************************************************************

      SUBROUTINE PROJT(W,IACC,A,B1,B2,B3,B5,B6,NDIM,NKP,NDK,NSTEP,
     .                 IPROJ,NDPR,NPROJ,IVARY,LUNIT)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      INCLUDE 'sizes'

      DIMENSION W(NDK),IACC(NKP,NSTEP),A(NDIM,NDIM),B1(NSTEP),B2(NSTEP),
     .          B3(NSTEP),B5(NSTEP),B6(NSTEP),IPROJ(NDIMMX,NFMOMX),
     .          NDPR(NFMOMX)

      COMMON /IOUNIT/IIN,IOUT,ISTART(40)

      COMMON /KEYWRD/ KEYWRD,SLINE
      CHARACTER KEYWRD*320,SLINE*80

      COMMON /OPTV/DELTA,EMIN,EMAX,STEP,XLIMIT,LEVB,LEVE,NMESH,IVARYS,
     .             IVARYE,NVARY

      IF ((IVARY .EQ. IVARYS) .AND. (IVARYS .GT. 1)) THEN
        DO 50 IVARC=1,IVARYS-1
          DO 40 K=1,NKP
            READ(LUNIT,10) IPOPE
   10       FORMAT(I6)
            DO 30 J=1,NDIM
              READ(LUNIT,20) (A(J,J2),J2=1,IPOPE)
C
C old version files (prior to 30.06.93)/mbs
C
C   20         FORMAT(F10.5)
C
   20         FORMAT(F8.5)
   30       CONTINUE
   40     CONTINUE
   50   CONTINUE
      ENDIF

      DO 200 I=1,NPROJ
        DO 60 IF=1,NSTEP
          B3(IF)=0.0D0
   60   CONTINUE

        REWIND 8
        DO 120 K=1,NKP
          IF (I .EQ. 1) THEN
            READ(LUNIT,10) IPOPE
            WRITE(8,10) IPOPE
            DO 70 J=1,NDIM
              READ(LUNIT,20) (A(J,J2),J2=1,IPOPE)
              WRITE(8,20) (A(J,J2),J2=1,IPOPE)
   70       CONTINUE
          ELSE
            READ(8,10) IPOPE
            DO 80 J=1,NDIM
              READ(8,20) (A(J,J2),J2=1,IPOPE)
   80       CONTINUE
          ENDIF

          IDKP=(K-1)*NDIM+1
          WEI=W(IDKP)
          M1=1
          M2=0
          DO 110 IRUN=1,NSTEP
            IF (IRUN .NE. 1) M1=M1+IACC(K,IRUN-1)
            M2=M2+IACC(K,IRUN)
            DO 100 M=M1,M2
              IF (M .GT. IPOPE) THEN
                IF (LUNIT .EQ. 2) THEN
                  SLINE='The integration requires levels'//
     .                  ' above the limitation AOPOP=m of EHMACC'
                ENDIF
                IF (LUNIT .EQ. 4) THEN
                  SLINE='the integration requires levels'//
     .                  ' above the limitation FMOPOP=m of EHMACC'
                ENDIF
                CALL WRITEL(SLINE)
                CALL CLEXIT
              END IF
              DO 90 N=1,NDPR(I)
                NN=IPROJ(N,I)
                B3(IRUN)=B3(IRUN) + A(NN,M)*WEI
   90         CONTINUE
  100       CONTINUE
  110     CONTINUE
  120   CONTINUE

        DO 130 IR=1,NSTEP
          IF (IR .NE. 1) B3(IR)=B3(IR)+B3(IR-1)
  130   CONTINUE

        IF (IVARYS .EQ. IVARYE) THEN
          IF (LUNIT .EQ. 2) WRITE(IOUT,140) I
  140     FORMAT(//////,5X,'AO population for the projection #',I2,//,
     .           1X,'   i',8X,'n0 ',9X,'n1 ',8X,'ef0',9X,'ef1',9X,'pop')
          IF (LUNIT .EQ. 4) WRITE(IOUT,150) I
  150     FORMAT(//////,5X,'FMO population for the projection #',I2,//,
     .           1X,'   i',8X,'n0 ',9X,'n1 ',8X,'ef0',9X,'ef1',9X,'pop')
          DO 170 IR=1,NSTEP
            WRITE (IOUT,160) IR,B1(IR),B2(IR),B5(IR),B6(IR),B3(IR)
  160       FORMAT(1X,I4,6F12.4)
  170     CONTINUE
        ELSE
          IF (LUNIT .EQ. 2) WRITE (IOUT,180) IVARY,I,LEVE,B3(NSTEP)
  180     FORMAT(/,' Variation #',I4,': AOPROJ',I2,' for ',I3,
     .           ' electrons: ',F10.5)
          IF (LUNIT .EQ. 4) WRITE (IOUT,190) IVARY,I,LEVE,B3(NSTEP)
  190     FORMAT(/,' Variation #',I4,': FMOPROJ',I2,' for ',I3,
     .           ' electrons: ',F10.5)
        ENDIF
  200 CONTINUE
      RETURN
      END
